<?php

namespace App\Exceptions;

use App\Exceptions\Api\AccessDeniedException;
use App\Exceptions\Api\MethodNotAllowed;
use App\Exceptions\Api\NotFound;
use App\Exceptions\Api\PermissionDoesNotExist;
use App\Exceptions\Api\ServerError;
use App\Exceptions\Api\ThrottleRequestsException;
use App\Exceptions\Api\Unauthorized;
use Illuminate\Database\QueryException;
use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Illuminate\Validation\ValidationException;
use Spatie\QueryBuilder\Exceptions\InvalidFilterQuery;
use Spatie\QueryBuilder\Exceptions\InvalidSortQuery;
use Stancl\Tenancy\Exceptions\TenantDatabaseDoesNotExistException;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\HttpKernel\Exception\MethodNotAllowedHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Throwable;

class Handler extends ExceptionHandler
{
    /**
     * A list of the exception types that are not reported.
     *
     * @var array
     */
    protected $dontReport
        = [//
        ];

    /**
     * A list of the inputs that are never flashed for validation exceptions.
     *
     * @var array
     */
    protected $dontFlash
        = [
            'password',
            'password_confirmation',
        ];

    /**
     * Register the exception handling callbacks for the application.
     *
     * @return void
     */
    public function register()
    {
        $this->reportable(
            function (Throwable $e) {
                //
            }
        );

        $this->renderable(
            function (\Spatie\Permission\Exceptions\PermissionDoesNotExist $e, $request) {
                throw new PermissionDoesNotExist();
            }
        );

        $this->renderable(
            function (\Spatie\Permission\Exceptions\PermissionAlreadyExists $e, $request) {
                throw new ServerError('Permission already exists');
            }
        );

        $this->renderable(
            function (TenantDatabaseDoesNotExistException $e, $request) {
                throw new ServerError($e->getMessage());
            }
        );
        $this->renderable(
            function (InvalidFilterQuery $e, $request) {
                throw new ServerError($e->getMessage());
            }
        );
        $this->renderable(
            function (InvalidSortQuery $e, $request) {
                throw new ServerError($e->getMessage());
            }
        );

        $this->renderable(
            function (AccessDeniedHttpException $e, $request) {
                throw new AccessDeniedException($e->getMessage());
            }
        );

        $this->renderable(
            function (NotFoundHttpException $e, $request) {
                throw new NotFound();
            }
        );
        $this->renderable(
            function (\BadMethodCallException $e, $request) {
                throw new NotFound($e->getMessage());
            }
        );
        $this->renderable(
            function (MethodNotAllowedHttpException $e, $request) {
                throw new MethodNotAllowed($e->getMessage());
            }
        );
        $this->renderable(
            function (\Illuminate\Http\Exceptions\ThrottleRequestsException $e, $request) {
                throw new ThrottleRequestsException($e->getMessage());
            }
        );
        $this->renderable(
            function (QueryException $e, $request) {
                throw new ServerError($e->getMessage());
            }
        );
        $this->renderable(
            function (\ErrorException $e, $request) {
                throw new ServerError($e->getMessage());
            }
        );
    }
    /**
     * Convert a validation exception into a JSON response.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Illuminate\Validation\ValidationException  $exception
     * @return \Illuminate\Http\JsonResponse
     */
    protected function invalidJson($request, ValidationException $exception)
    {
        return response()->json([
                                    'message' => __('The given data was invalid.'),
                                    'errors' => $exception->errors(),
                                ], $exception->status);
    }
}
