<?php

namespace App\Http\Controllers;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Requests\CalendarOrderStagesIndexRequest;
use App\Http\Resources\OWSCalendarResource;
use App\Services\OrderWorkStagesService;
use Illuminate\Http\Response;
use App\Models\Order;
use App\Services\CalendarOrderStagesService;

/**
 * @group Calendar
 *
 * APIs for managing calendar
 */
class CalendarOrderStagesController extends Controller
{
    /**
     * Calendar exit stages listing.
     * @queryParam end_date date
     * @queryParam start_date date
     *
     * @return Response
     */
    public function index(CalendarOrderStagesIndexRequest $request)
    {
        if (!$request->user()->can(['calendar.trial_stages.read'])) {
            throw new AccessDeniedException(__('lang_permissions.calendar.trial_stages.read.missing.permission'));
        }

        $validated = $request->validated();
        $orderStages = CalendarOrderStagesService::getExitStages($validated['start_date'], $validated['end_date']);

        return response(OWSCalendarResource::collection($orderStages));
    }

    /**
     * Calendar order stages listing
     *
     * @param  CalendarOrderStagesIndexRequest  $request
     * @param  Order  $order
     *
     * @return \Illuminate\Contracts\Routing\ResponseFactory|Response
     * @throws \App\Exceptions\Api\ValidationException
     */
    public function showFinishedOrToSentOWS(CalendarOrderStagesIndexRequest $request, Order $order)
    {
        return OrderWorkStagesService::showFinishedOrToSentOWS($request, $order);
    }
}
