<?php

namespace App\Http\Controllers;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Requests\DepartmentRequest;
use App\Http\Resources\DepartmentResource;
use App\Models\Department;
use App\Models\User;
use Illuminate\Contracts\Foundation\Application;
use Illuminate\Contracts\Routing\ResponseFactory;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

/**
 * @group Departamente
 *
 * APIs for managing departments
 */
class DepartmentController extends Controller
{
    /**
     * Display a listing of departments.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        // TODO: permissions
        // if (!$request->user()->can(['departments.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.departments.read.missing.permission'));
        // }
        $departments = Department::orderBy('name')->get();
        return response(['data' => DepartmentResource::collection($departments)]);
    }

    /**
     * Store a newly created department.
     *
     * @param  DepartmentRequest  $request
     *
     * @return Application|ResponseFactory|Response
     */
    public function store(DepartmentRequest $request)
    {
        // TODO: permissions
        // if (!$request->user()->can(['departments.create'])) {
        //     throw new AccessDeniedException(__('lang_permissions.departments.create.missing.permission'));
        // }
        $validated = $request->validated();
        $department = Department::create($validated);

        return response(['data' => new DepartmentResource($department)], 201);
    }

    /**
     * Show the specified department.
     * @param  Request  $request
     * @param  Department  $discountType
     *
     * @return Application|ResponseFactory|Response
     */
    public function show(Request $request, Department $department)
    {
        // TODO: permissions
        // if (!$request->user()->can(['departments.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.departments.read.missing.permission'));
        // }
        return response(['data' => new DepartmentResource($department)]);
    }

    /**
     * Update the specified department.
     *
     * @param  DepartmentRequest  $request
     * @param  Department  $discountType
     *
     * @return Application|ResponseFactory|Response
     */
    public function update(DepartmentRequest $request, Department $department)
    {
        // TODO: permissions
        // if (!$request->user()->can(['departments.update'])) {
        //     throw new AccessDeniedException(__('lang_permissions.departments.update.missing.permission'));
        // }
        $validated = $request->validated();
        $department->update($validated);
        return response(['data' => new DepartmentResource($department)]);
    }

    /**
     * Delete the specified department.
     *
     * @param  Request  $request
     * @param  Department  $department
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request, Department $department)
    {
        // TODO: permissions
        // if (!$request->user()->can(['departments.delete'])) {
        //     throw new AccessDeniedException(__('lang_permissions.departments.delete.missing.permission'));
        // }

        User::where('department_id', $department->id)->update(['department_id' => 0]);
        $department->delete();

        return response(['message' => __('Successfully deleted')], 204);
    }
}
