<?php

namespace App\Http\Controllers;

use App\Models\Discount;
use App\Http\Requests\DiscountRequest;
use App\Models\PaymentDocument;
use App\Http\Resources\DiscountResource;
use App\Http\Requests\PDDiscountDestroyRequest;
use App\Exceptions\Api\PossibleUnSyncException;
use App\Services\DiscountService;

/**
 * @group Documente de plata
 *
 * APIs for managing work stages
 */
class DiscountController extends Controller
{

    /**
     * Add discount to payment
     *
     * @param DiscountRequest $request
     * @param PaymentDocument $paymentDocument
     * @return \Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     */
    public function store(DiscountRequest $request, PaymentDocument $paymentDocument)
    {
        DiscountService::canAddDiscount($paymentDocument, true);

        $validated = $request->validated();
        if ($paymentDocument->to_pay < (int)$validated['value']) {
            throw new PossibleUnSyncException(__('Valoarea discountului depaseste restul de plata'));
        }
        $validated['payment_document_id'] = $paymentDocument->id;
        $discount = Discount::create($validated);

        return response(['data' => new DiscountResource($discount)], 201);
    }

    /**
     * Remove discount from payment
     *
     * @param PDDiscountDestroyRequest $request
     * @param PaymentDocument $paymentDocument
     * @return \Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     */
    public function destroy(PDDiscountDestroyRequest $request, PaymentDocument $paymentDocument)
    {
        DiscountService::canRemoveDiscount($paymentDocument, true);

        $validated = $request->validated();
        $discount = Discount::findOrFail($validated['discount_id']);
        $discount->delete();
        return response(['message' => __('Successfully deleted')], 204);
    }
}
