<?php

namespace App\Http\Controllers;

use App\Http\Resources\InvoiceResource;
use App\Models\Invoice;
use App\Services\InvoiceService;
use Illuminate\Http\Request;

/**
 * @group Facturi
 *
 * APIs for managing payment documents
 */
class InvoiceController extends Controller
{
    /**
     * Display list of invoices
     *
     * @param Request $request
     * @return \Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        //TODO permissions
        // if (!$request->user()->can(['invoices.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.invoices.read.missing.permission'));
        // }
        $invoices = Invoice::orderBy('invoices.id', 'DESC')->with(['paymentDocument'])->get();
        return response(['data' => InvoiceResource::collection($invoices)]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Invoice  $invoice
     * @return \Illuminate\Http\Response
     */
    public function show(Request $request, Invoice $invoice)
    {
        //TODO permissions
        // if (!$request->user()->can(['invoices.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.invoices.read.missing.permission'));
        // }
        return response(['data' => new InvoiceResource($invoice)]);
    }

    /**
     * Generate invoice's PDF document.
     *
     * @param Invoice $invoice
     * @return object
     */
    public function generateInvoicePdf(Invoice $invoice): object
    {
        //TODO: permissions
        // if (!$request->user()->can(['invoices.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.invoices.read.missing.permission'));
        // }

        $invoice    = Invoice::where('id', $invoice->id)->where('status', '<>', 'config')->firstOrFail();
        $pdf        = InvoiceService::generateInvoicePdf($invoice);

        return $pdf->stream("Factura {$invoice->invoice_series} {$invoice->invoice_no}.pdf", array("Attachment" => 0));
    }
}
