<?php

namespace App\Http\Controllers;

use App\Http\Requests\DiscountRequest;
use App\Http\Resources\OrderResource;
use App\Models\Order;
use App\Services\Reports\OrderDiscountsService;
use App\Services\Reports\OrdersService;

/**
 * @group Comenzi discounts
 *
 * APIs for managing order additional prices
 */
class OrderDiscountController extends Controller
{
    /**
     * Add discount for order
     *
     */
    public function create(DiscountRequest $request, Order $order)
    {
        $validated = $request->validated();
        \DB::transaction(function () use (&$order, $validated) {
            OrderDiscountsService::addDiscountForOrder($order, $validated);
        });

        return response(['data' => new OrderResource(OrdersService::getOrdersNotCanceled(['order_id' => $order->id])->first())]);
    }

    /**
     * Delete discount of the order
     *
     */
    public function delete(Order $order, int $discountId)
    {
        \DB::transaction(function () use (&$order, $discountId) {
            OrderDiscountsService::deleteDiscountForOrder($order, $discountId);
        });

        return response([],204);
    }
}
