<?php

namespace App\Http\Controllers;

use App\Exceptions\Api\ValidationException;
use App\Http\Requests\OrderFileUploadRequest;
use App\Models\Order;
use App\Models\OrderFiles;
use App\Services\OrderService;
use App\Services\UploadService;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

/**
 * @group Comenzi fisiere
 *
 * APIs for managing order`s files
 */
class OrderFilesController extends Controller
{


    /**
     * Order file listing.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Order $order)
    {
        return response(['data' => $order->files]);
    }

    /**
     * Add file to a order.
     *
     * @param  \Illuminate\Http\Request  $request
     *
     * @return \Illuminate\Http\Response
     */
    public function store(OrderFileUploadRequest $request)
    {
        $validated = $request->validated();
        $orderId = (int)$validated['order_id'];
        $order = Order::findOrFail($orderId);

        if ($order === null) {
            throw new ValidationException(__('Order with id :orderId does not exist.', ['orderId' => $orderId]));
        }

        OrderService::orderCanBeUpdated($order);

        $fileName = $validated['file_name'] ?? null;
        (new UploadService())->savefile(
            $order,
            $request->file('file'),
            Order::ORDER_FILES_COLLECTION_NAME,
            UploadService::PRIVATE_UPLOAD_PATH,
            $fileName
        );
        $order ->refresh();

        return response(['data' => $order->files]);
    }

    /**
     * Download a order file
     *
     * @param  Request  $request
     * @param $mediaUUID
     *
     * @return \Symfony\Component\HttpFoundation\BinaryFileResponse
     */
    public function downloadFile(Request $request, $mediaUUID)
    {
        //TODO permissions?
        $file = Media::where('uuid', $mediaUUID)->firstOrFail();
        return response()->download($file->getPath(), $file->file_name);
    }

    /**
     * Delete a order file.
     *
     * @param  \App\Models\OrderFiles  $orderFiles
     *
     * @return \Illuminate\Http\Response
     */
    public function deleteFile(Request $request, $mediaUUID)
    {
        $file = Media::where('uuid', $mediaUUID)->firstOrFail();
        Media::destroy([$file->id]);
        return response(['data' => __('File deleted successfully')], 204);
    }

}
