<?php

namespace App\Http\Controllers;

use App\Http\Requests\PaymentDocumentAddPaymentRequest;
use App\Http\Resources\OrderResource;
use App\Models\Order;
use App\Services\Reports\OrderPaymentsService;
use App\Services\Reports\OrdersService;
use Illuminate\Contracts\Foundation\Application;
use Illuminate\Contracts\Routing\ResponseFactory;
use Illuminate\Http\Response;

/**
 * @group Comenzi plati
 *
 * APIs for managing order additional prices
 */
class OrderPaymentController extends Controller
{
    /**
     * Add payment for order
     *
     * @param  PaymentDocumentAddPaymentRequest  $request
     * @param  Order  $order
     *
     * @return Application|ResponseFactory|Response
     */
    public function create(PaymentDocumentAddPaymentRequest $request, Order $order)
    {
        $validated = $request->validated();
        \DB::transaction(function () use (&$order, $validated) {
            OrderPaymentsService::addPaymentForOrder($order, $validated);
            $order->refresh();
        });
        return response(['data' => new OrderResource(OrdersService::getOrdersNotCanceled(['order_id' => $order->id])->first())]);
    }

    /**
     * Delete payment of the order
     *
     * @param Order $order
     * @param integer $paymentId
     */
    public function delete(Order $order, int $paymentId)
    {
        \DB::transaction(function () use (&$order, $paymentId) {
            OrderPaymentsService::deletePaymentForOrder($order, $paymentId);
        });
        return response([], 204);
    }
}
