<?php

namespace App\Http\Controllers;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Resources\PermissionDetailedCollection;
use App\Http\Resources\PermissionDetailedResource;
use App\Http\Resources\PermissionsSortedCollection;
use App\Models\Permission;
use Illuminate\Http\Request;
/**
 * @group Roluri
 *
 * APIs for managing roles
 */
class PermissionController extends Controller
{

    /**
     * Permissions detailed listing.
     * @apiResourceCollection App\Http\Resources\PermissionDetailedCollection
     * @apiResourceModel App\Models\Permission
     * @param  Request  $request
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     * @throws AccessDeniedException
     */
    public function indexDetailed(Request $request)
    {
        if (!$request->user()->can(['roles.update'])) {
            throw new AccessDeniedException(__('lang_permissions.roles.update.missing.permission'));
        }
        $permissions = Permission::orderBy('category')->get();

        return response(new PermissionDetailedCollection($permissions));

    }

    /**
     * Permissions detailed listing.
     * @apiResourceCollection App\Http\Resources\PermissionDetailedCollection
     * @apiResourceModel App\Models\Permission
     * @param  Request  $request
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     * @throws AccessDeniedException
     */
    public function indexDetailedParsed(Request $request)
    {
        if (!$request->user()->can(['roles.update'])) {
            throw new AccessDeniedException(__('lang_permissions.roles.update.missing.permission'));
        }
        $permissions = Permission::orderBy('category')->get();

        return response(new PermissionsSortedCollection($permissions));

    }

    /**
     * Permissions names listing.
     * @response  {"data": ["permissions1","permissions2"]}
     * @param  Request  $request
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     * @throws AccessDeniedException
     */
    public function indexList(Request $request)
    {
        if (!$request->user()->can(['roles.update'])) {
            throw new AccessDeniedException(__('lang_permissions.roles.update.missing.permission'));
        }
        $permissionsNames = Permission::all()->pluck('name');

        return response(['data'=>$permissionsNames]);

    }

    /**
     * Permission detailed.
     * @apiResource App\Http\Resources\PermissionDetailedResource
     * @apiResourceModel App\Models\Permission
     * @param  Request  $request
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\Routing\ResponseFactory|\Illuminate\Http\Response
     * @throws AccessDeniedException
     */
    public function showDetailed(Request $request,$permissionName)
    {
        if (!$request->user()->can(['roles.update'])) {
            throw new AccessDeniedException(__('lang_permissions.roles.update.missing.permission'));
        }
        $permission = Permission::where('name',$permissionName)->firstOrFail();

        return response(['data'=>new PermissionDetailedResource($permission)]);

    }
}
