<?php

namespace App\Http\Controllers;

use App\Http\Resources\ReceiptResource;
use App\Models\Invoice;
use App\Models\Payment;
use App\Models\Receipt;
use App\Services\ReceiptService;

/**
 * @group Chitante
 *
 * APIs for managing receipt series
 */
class ReceiptController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //TODO permissions
        // if (!$request->user()->can(['invoices.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.invoices.read.missing.permission'));
        // }
        $receipts = Receipt::orderBy('receipt_date', 'DESC')->get();
        $invoice = Invoice::find(1);

        ReceiptService::attachInvoiceDetails($receipts, $invoice);

        return response(['data' => ReceiptResource::collection($receipts)]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Receipt  $receipt
     * @return \Illuminate\Http\Response
     */
    public function show(Receipt $receipt)
    {
        //TODO permissions
        // if (!$request->user()->can(['invoices.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.invoices.read.missing.permission'));
        // }
        return response(['data' => new ReceiptResource($receipt)]);
    }

    /**
     *  Generate receipt's PDF document.
     *
     * @param Payment $payment
     * @return object
     */
    public function generateReceiptPdf(Payment $payment): object
    {
        //TODO permissions
        // if (!$request->user()->can(['receipts.read'])) {
        //     throw new AccessDeniedException(__('lang_permissions.receipts.read.missing.permission'));
        // }

        $receipt    = Receipt::where('receipt_series', $payment->receipt_series)->where('receipt_no', $payment->receipt_no)->with(['invoice'])->firstOrFail();
        $pdf        = ReceiptService::generateReceiptPdf($receipt);

        return $pdf->stream("Chitanta {$receipt->receipt_series} {$receipt->receipt_no}.pdf", array("Attachment" => 0));
    }
}
