<?php

namespace App\Http\Controllers;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Requests\RegionRequest;
use App\Http\Resources\RegionCollection;
use App\Http\Resources\RegionResource;
use App\Models\Region;
use Illuminate\Http\Request;

/**
 * @group Judete
 *
 * APIs for managing regions
 */

class RegionController extends Controller
{
    /**
     * Regions listing.
     * @apiResourceCollection App\Http\Resources\RegionCollection
     * @apiResourceModel App\Models\Region
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if (!$request->user()->can(['regions.read'])) {
            throw new AccessDeniedException(__('lang_permissions.regions.read.missing.permission'));
        }

        return response(new RegionCollection(Region::orderBy('title')->get()));
    }

    /**
     * Store a newly created region.
     * @apiResource App\Http\Resources\RegionResource
     * @apiResourceModel App\Models\Region
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(RegionRequest $request)
    {
        if (!$request->user()->can(['regions.create'])) {
            throw new AccessDeniedException(__('lang_permissions.regions.create.missing.permission'));
        }
        // Retrieve the validated input data...
        $validated = $request->validated();

        $region = Region::create($validated);

        return response(['data' => new RegionResource($region)],201);
    }

    /**
     * Display a region.
     * @apiResource App\Http\Resources\RegionResource
     * @apiResourceModel App\Models\Region
     * @urlParam region integer required
     * @param  \App\Models\Region  $region
     * @return \Illuminate\Http\Response
     */
    public function show(Request $request,Region $region)
    {
        if (!$request->user()->can(['regions.read'])) {
            throw new AccessDeniedException(__('lang_permissions.regions.read.missing.permission'));
        }

        return response(['data' => new RegionResource($region)]);
    }

    /**
     * Update  a region.

     * @apiResource App\Http\Resources\RegionResource
     * @apiResourceModel App\Models\Region
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Region  $region
     * @return \Illuminate\Http\Response
     */
    public function update(RegionRequest $request, Region $region)
    {
        if (!$request->user()->can(['regions.update'])) {
            throw new AccessDeniedException(__('lang_permissions.regions.update.missing.permission'));
        }
        // Retrieve the validated input data...
        $validated = $request->validated();

        foreach ($validated as $fieldName => $fieldValue) {
            $region -> $fieldName  = $fieldValue;
        }
        $region -> save();

        return response(['data' => new RegionResource($region)]);

    }
}
