<?php

namespace App\Http\Controllers\Reports;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Controllers\Controller;
use App\Http\Resources\AssignedStagesChartResource;
use App\Models\User;
use App\Services\Reports\AssignedStagesChartService;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;

/**
 * @group Grafice
 *
 * APIs for managing charts
 */
class AssignedStagesChartController extends Controller
{
    /**
     * Ranking of technician's assigned stages value.
     *
     * @param User $user
     * @param integer $numberOfMonths
     * @return AnonymousResourceCollection
     */
    public function getUserTotalPerOrderAssignedWorkStage(Request $request, User $user): AnonymousResourceCollection
    {
        if (!$request->user()->can(['reports.read'])) {
            throw new AccessDeniedException(__('lang_permissions.reports.read.missing.permission'));
        }

        $orderWorkStages = AssignedStagesChartService::calculateUserTotalPerOrderWorkStage($user);

        return AssignedStagesChartResource::collection($orderWorkStages);
    }
}
