<?php

namespace App\Http\Controllers\Reports;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Controllers\Controller;
use App\Http\Requests\TopDebtorsChartRequest;
use App\Http\Resources\TopDebtorsChartResource;
use App\Services\Reports\TopDebtorsChartService;

/**
 * @group Grafice
 *
 * APIs for managing charts
 */
class TopDebtorsChartController extends Controller
{
    /**
     * Retrieve top debtors info for the chart.
     *
     * @param integer $numberOfDebtors
     * @return void
     */
    public function getTopDebtorsChartInfo(int $numberOfDebtors = 4)
    {
        $debtors = collect(TopDebtorsChartService::getDebtorsNamesAndValues());
        $debtors = TopDebtorsChartService::calculateOtherDebtorsTotal($debtors, $numberOfDebtors);

        return TopDebtorsChartResource::collection($debtors);
    }

    /**
     * Listing of top debtors.
     *
     * @param TopDebtorsChartRequest $request
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function getTopDebtorsChartData(TopDebtorsChartRequest $request)
    {
        if (!$request->user()->can(['reports.read'])) {
            throw new AccessDeniedException(__('lang_permissions.reports.read.missing.permission'));
        }

        $validated = $request->validated();

        if (isset($validated['number_of_debtors'])) {
            return $this->getTopDebtorsChartInfo($validated['number_of_debtors']);
        }
        return $this->getTopDebtorsChartInfo();
    }
}
