<?php

namespace App\Http\Controllers\Reports;

use App\Exceptions\Api\AccessDeniedException;
use App\Http\Controllers\Controller;
use App\Http\Requests\TrialStagesChartRequest;
use App\Http\Resources\TrialStagesChartResource;
use App\Services\CalendarOrderStagesService;
use App\Services\Reports\TrialStagesChartService;
use Carbon\Carbon;
use Illuminate\Http\Response;

/**
 * @group Grafice
 *
 * APIs for managing charts
 */
class TrialStagesChartController extends Controller
{
    /**
     * Retrieve the trial stages info for the chart.
     *
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function getTrialStagesChartInfo($numberOfDays = 7)
    {
        $startDate = Carbon::today()->format('Y-m-d');
        $endDate = Carbon::createFromDate($startDate)->addDays($numberOfDays)->format('Y-m-d');

        $trialStages = CalendarOrderStagesService::getExitStages($startDate, $endDate);
        $chartDates = TrialStagesChartService::generateChartDates($trialStages, $startDate, $endDate);

        return response(['data' => (TrialStagesChartResource::collection($chartDates))]);
    }

    /**
     * Listing of stages per days number.
     *
     * @param TrialStagesChartRequest $request
     * @return Response
     */
    public function getTrialStagesChartData(TrialStagesChartRequest $request): Response
    {
        if (!$request->user()->can(['reports.read'])) {
            throw new AccessDeniedException(__('lang_permissions.reports.read.missing.permission'));
        }

        $validated = $request->validated();

        if (isset($validated['number_of_days'])) {
            return $this->getTrialStagesChartInfo($validated['number_of_days']);
        }
        return $this->getTrialStagesChartInfo();
    }
}
