<?php

namespace App\Http\Middleware;

use App\Exceptions\Api\MethodNotAllowed;
use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class GetIdentifierFromToken
{
    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     *
     * @return mixed
     */
    public function handle(Request $request, Closure $next)
    {
        //rule first prevents tenant_identifier overwrites if request has username and password and Authorisation token
        if (//bearer token identifier identification
            ($apiKey = $request->header('Authorization'))
            && //authorisation comes from bearer token
            substr_count($apiKey, 'Bearer')
            && //has only 2 delimiters for identifier identification
            substr_count($apiKey, config('custom.api.token_identifier_delimiter')) == 2
            && //has identifier
            strlen(
                $identifier = Str::between(
                    $request->header('Authorization'),
                    config('custom.api.token_identifier_delimiter'),
                    config('custom.api.token_identifier_delimiter')
                )
            ) > 0
        ) {
            $request->headers->set('tenant_identifier', $identifier);
        }

        return $next($request);
    }
}
