<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class CollaboratorRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize():bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules():array
    {
        return [
            'name' => 'required|string|min:3|unique:collaborators,name,'.($this->collaborator->id??0).',id,deleted_at,NULL',
            'cui' => [
                'nullable',
                'regex:/^(RO|ro|Ro|rO)?[0-9]{4,12}$/',
                'unique:collaborators,cui,'.($this->collaborator->id??0).',id,deleted_at,NULL'
            ],
            'nr_reg_comertului' => [
                'nullable',
                'regex:/^(j|J|f|F|c|C)[0-9]{1,2}\/[0-9]{2,8}\/[0-9]{4}$/',
                'unique:collaborators,nr_reg_comertului,'.($this->collaborator->id??0).',id,deleted_at,NULL'
            ],
            'bank' => 'nullable|string',
            'bank_account' => 'nullable|string',
            'address' => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'region_id' => 'required|integer|exists:regions,id',
            'city' => [
                'bail',
                'nullable',
                'string',
                'regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um'
            ],
            'phone_fax' => 'bail|nullable|string|digits:10',
            'mobile' => 'bail|nullable|string|digits:10',
            'contact_mobile' => 'bail|nullable|string|digits:10',
            'email' => 'nullable|email|unique:collaborators,email,'.($this->collaborator->id??0).',id,deleted_at,NULL',
            'website' => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
                'max:255'
            ]
        ];
    }
}
