<?php

namespace App\Http\Requests;

use Faker\Provider\File;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class LabInvoiceProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'name'              => 'required|string|min:3|unique:lab_invoice_profiles,name,'.($this->lab_invoice_profile->id ?? 0).',id',
            'city'              => ['nullable', 'regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um'],
            'address'           => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'region_id'         => 'required|integer|exists:regions,id',
            'phone_fax'         => 'bail|nullable|string|digits:10',
            'mobile1'           => 'bail|nullable|string|digits:10',
            'mobile2'           => 'bail|nullable|string|digits:10',
            'email1'            => 'nullable|email',
            'email2'            => 'nullable|email',
            'website'           => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
                'max:255'
            ],
            'cui'               => [
                'required',
                'regex:/^(RO|ro|Ro|rO)?[0-9]{4,12}$/',
                'unique:lab_invoice_profiles,cui,'.($this->lab_invoice_profile->id ?? 0).',id'
            ],
            'nr_reg_comertului' => [
                'nullable',
                'regex:/^(j|J|f|F|c|C)[0-9]{1,2}\/[0-9]{2,8}\/[0-9]{4}$/',
                'unique:lab_invoice_profiles,nr_reg_comertului,'.($this->lab_invoice_profile->id ?? 0).',id'
            ],
            'proforma_start_no'    => 'required|integer',
            'proforma_series'      => 'required|string',
            'bank'              => 'nullable|string',
            'bank_account'      => 'nullable|string',

        ];
    }

    public function bodyParameters()
    {
        return [

        ];
    }
}
