<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class LabProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'name'                                   => 'required|min:3',
            'city'                                   => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'region_id'                              => 'required|integer|exists:regions,id',
            'address'                                => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'phone_fax'                              => 'bail|nullable|string|digits:10',
            'mobile1'                                => 'bail|nullable|string|digits:10',
            'mobile2'                                => 'bail|nullable|string|digits:10',
            'email1'                                 => 'nullable|email',
            'email2'                                 => 'nullable|email',
            'website'                                => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
                'max:255'
            ],
            'facebook'                               => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([a-zA-z-.]*)?((facebook.com)|(fb.com))\/([\w \.-]*)*\/?$/',
                'max:255'
            ],
            'linkedin'                               => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([a-zA-z-.]*)?(linkedin.com)\/(in\/)([\w \.-]*)*\/?$/',
                'max:255'
            ],
            'saturday'                               => 'required|boolean',
            'sunday'                                 => 'required|boolean',
            'users_occupancy_threshold_busy_waiting' => 'required|integer|min:0|max:100',
            'users_occupancy_threshold_busy_working' => 'required|integer|min:0|max:100',
            'users_occupancy_threshold_full_waiting' => 'required|integer|min:0|max:100',
            'users_occupancy_threshold_full_working' => 'required|integer|min:0|max:100'

        ];
    }

    public function bodyParameters()
    {
        return [
            'website'                                => [
                'example' => 'https://yoursite.com',
            ],
            'facebook'                               => [
                'example' => 'https://www.facebook.com/xxxxx | https://fb.com/xxxx',
            ],
            'linkedin'                               => [
                'example' => 'https://www.linkedin.com/in/xxxxxxx',
            ],
            'users_occupancy_threshold_busy_working' => [
                'description' => 'Min value 0.',
                'example'     => '',
            ],
            'users_occupancy_threshold_full_waiting' => [
                'description' => 'Min value 0.',
            ],
            'users_occupancy_threshold_full_working' => [
                'description' => 'Min value 0.',
            ],
        ];
    }
}
