<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class OrdersReportRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'filters'                                          => ['nullable', 'bail', 'array', 'min:1'],
            'filters.order_id'                                 => [
                'nullable',
                'bail',
                'bail',
                'integer',
                'exists:orders,id,deleted_at,NULL'
            ],
            'filters.dentist_id'                               => [
                'nullable',
                'bail',
                'bail',
                'integer',
                'exists:dentists,id,deleted_at,NULL'
            ],
            'filters.date_filtering'                           => ['nullable', 'bail', 'array'],
            'filters.date_filtering.start_date.interval_start' => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.start_date.interval_end',
            ],
            'filters.date_filtering.start_date.interval_end'   => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.start_date.interval_start'
            ],
            'filters.date_filtering.end_date.interval_start'   => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.end_date.interval_end',
            ],
            'filters.date_filtering.end_date.interval_end'     => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.end_date.interval_start',
            ],
            'filters.status'                                   => ['nullable', 'bail', 'array', 'min:1'],
            'filters.status.is_complete'                       => ['nullable', 'bail', 'boolean'],
            'filters.invoice'                                  => ['nullable', 'bail', 'array'],
            'filters.invoice.only_fiscal'                      => ['nullable', 'bail', 'boolean'],
            'filters.invoice.only_proforma'                    => ['nullable', 'bail', 'boolean'],
            'filters.invoice.only_no_invoice'                  => ['nullable', 'bail', 'boolean'],
            'filters.is_paid_fully'                            => ['nullable', 'bail', 'boolean'],
            'filters.zero_value_orders'                        => ['nullable', 'bail', 'boolean'],

        ];
    }
}
