<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
/*
 * @queryParams filters.date_filtering array
 * @queryParams filters.date_filtering.type string
 * @queryParams filters.date_filtering.start_date string
 * @queryParams filters.date_filtering.end_date string
 * @queryParams filters.collaborator_filtering array
 * @queryParams filters.collaborator_filtering.collaborator_name string
 * @queryParams filters.dentist_filtering array
 * @queryParams filters.dentist_filtering.dentist_name string
 * @queryParams detailed
 *
 * */
class PDAvailableOrdersRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
//        dd($this->detailed);
        return [
            'filters' => [
                'nullable',
                'bail',
                'array',
                'required_with:filters.date_filtering',
            ],
            'filters.patient_filtering' => [
                'nullable',
                'bail',
                'array',
                'required_with:filters.patient_filtering.patient_name',
                'size:1'
            ],
            'filters.patient_filtering.patient_name' => [
                'nullable',
                'bail',
                'string',
                'required_with:filters.patient_filtering',
                'min:2',
            ],
            'filters.dentist_filtering' => [
                'nullable',
                'bail',
                'array',
                'required_with:filters.dentist_filtering.dentist_name',
                'size:1'
            ],
            'filters.dentist_filtering.dentist_name' => [
                'nullable',
                'bail',
                'string',
                'required_with:filters.dentist_filtering',
                'min:2',
            ],
            'filters.date_filtering.start_date' => [
                'nullable',
                'bail',
                'array',
                'size:2'
            ],
            'filters.date_filtering.end_date' => [
                'nullable',
                'bail',
                'array',
                'size:2'
            ],
            'filters.date_filtering.start_date.interval_start' => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.start_date.interval_end',
            ],
            'filters.date_filtering.start_date.interval_end' => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.start_date.interval_start'
            ],
            'filters.date_filtering.end_date.interval_start' => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.end_date.interval_end',
            ],
            'filters.date_filtering.end_date.interval_end' => [
                'nullable',
                'bail',
                'date_format:d-m-Y',
                'required_with:filters.date_filtering.end_date.interval_start',
            ]
        ];
    }
}
