<?php

namespace App\Http\Requests;

use App\Configuration\LabConfiguration;
use App\Models\User;
use Illuminate\Foundation\Http\FormRequest;

class UserProfileUpdateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'username_suffix'        => [
                'required',
                'min:3',
                'alpha',
                function ($attribute, $value, $fail) {
                    $users = User::where('username', '=', tenant()->id.'.'.$value)->whereNotIn('id', [$this->user->id])->get();
                    if (count($users) != 0) {
                        $fail(__('Username already exists'));
                    }
                },
            ],
            'first_name'      => 'required|min:3',
            'last_name'       => 'required|min:3',
            'department_id'   => 'required|integer|exists:departments,id',
            'phone_fax'       => 'bail|nullable|string|digits:10',
            'mobile'          => 'bail|nullable|string|digits:10',
            'email'           => 'nullable|email',
            'website'         => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
                'max:255'
            ],
            'address'         => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'status'          => 'required|string|in:'.LabConfiguration::configAsString('user_statuses'),
            'use_profile_pic' => 'nullable|boolean',
            'roles_ids'       => 'required|array',
            'roles_ids.*'     => 'required|integer|exists:roles,id',
            'password'        => 'nullable|confirmed|string|min:5',
        ];
    }

    public function bodyParameters()
    {
        return [

        ];
    }
}
