<?php

namespace App\Http\Requests;

use App\Configuration\LabConfiguration;
use App\Models\User;
use Illuminate\Foundation\Http\FormRequest;

class UserSelfProfileUpdateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'first_name'      => 'required|min:3',
            'last_name'       => 'required|min:3',
            'phone_fax'       => 'bail|nullable|string|digits:10',
            'mobile'          => 'bail|nullable|string|digits:10',
            'email'           => 'nullable|email',
            'website'         => [
                'nullable',
                'url',
                'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
                'max:255'
            ],
            'address'         => 'nullable|string|regex:/^[a-zâăîşșţțA-ZĂÂÎŞȘŢȚ0-9 \-\/\ \+\(\)\.,:\/]*$/um',
            'status'          => 'required|string|in:'.LabConfiguration::configAsString('user_statuses'),
            'use_profile_pic' => 'nullable|boolean',
            'password'        => 'nullable|confirmed|string|min:5',
        ];
    }

    public function bodyParameters()
    {
        return [

        ];
    }
}
