<?php

namespace App\Http\Requests;

use App\Configuration\LabConfiguration;
use Illuminate\Foundation\Http\FormRequest;

class WorkStageRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(): array
    {
        return [
            'name'                  => 'required|string|min:3|unique:work_stages,name,'.($this->work_stage->id ?? 0).',id,deleted_at,NULL',
            'type'                  => 'required|string|in:'.LabConfiguration::configAsString('work_stages_types'),
            'price_type'            => 'required|string|in:'.LabConfiguration::configAsString('work_templates_price_types'),
            'min_duration'          => 'required|integer|min:0',
            'cost'                  => [
                'required',
                'numeric',
                'max:999999'
            ],
            'to_send'           => [
                'required',
                'boolean'
            ],
            'remake_cost'           => [
                'required',
                'numeric',
                'max:999999'
            ],
            'special_cost'          => [
                'required',
                'numeric',
                'max:999999'
            ],
            'description'           => [
                'nullable',
                'string',
            ],
            'confirmation_required' => [
                'nullable',
                'bail',
                'boolean',
            ],
            'extra_cost_applied'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.1'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.2'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.3'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.4'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.5'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.6'    => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.7'    => [
                'required',
                'boolean',
            ],
        ];
    }


}
