<?php

namespace App\Http\Requests;

use App\Configuration\LabConfiguration;
use Illuminate\Foundation\Http\FormRequest;

class WorkTemplateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'name'                     => 'required|string|min:3|unique:work_templates,name,'.($this->work_template->id ?? 0)
                .',id,deleted_at,NULL',
            'min_duration'             => 'required|integer|min:0',
            'estimated_duration'       => 'required|integer|min:0',
            'symbol'                   => 'nullable|string|min:0|max:20',
            'cost'                     => [
                'required',
                'numeric',
                'max:999999'
            ],
            'extra_cost'               => [
                'required',
                'numeric',
                'max:999999'
            ],
            'description'              => [
                'nullable',
                'string',
            ],
            'type'                     => [
                'nullable',
                'string',
            ],
            'price_type'               => 'required|string|in:'.LabConfiguration::configAsString('work_templates_price_types'),
            'multi_factor_dentition.1' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.2' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.3' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.4' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.5' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.6' => [
                'required',
                'boolean',
            ],
            'multi_factor_dentition.7' => [
                'required',
                'boolean',
            ],
        ];
    }
}
