<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class WorkTemplateStageUsersUpdateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'work_template_id'                    => [
                'required',
                'integer',
                'exists:work_templates,id,deleted_at,NULL',
                Rule::exists('work_template_stages', 'work_template_id')->where(
                    function ($query) {
                        return $query->where('work_stage_id', $this->work_stage_id);
                    }
                )
            ],
            'work_stage_id'                       => [
                'required',
                'integer',
                'exists:work_stages,id,deleted_at,NULL',
                Rule::exists('work_template_stages', 'work_stage_id')->where(
                    function ($query) {
                        return $query->where('work_template_id', $this->work_template_id);
                    }
                )
            ],
            'work_template_stage_users'           => [
                'required',
                'array'
            ],
            'work_template_stage_users.*.user_id' => [
                'required',
                'integer',
                'exists:users,id,deleted_at,NULL',
                'exists:work_template_stage_users,user_id'
            ],
            'work_template_stage_users.*.price' => [
                'nullable',
                'integer',
                'min:0',
                'max:999999'
            ],
        ];
    }

    /**
     * Get the error messages for the defined validation rules.
     *
     * @return array
     */
    public function messages()
    {
        return [
            'users.*.user_id' => 'Id user required'
        ];
    }
}
