<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;

class OrderResource extends JsonResource
{
    /**
     * @param  \Illuminate\Http\Request  $request
     *
     * @return array
     */
    public function toArray($request)
    {
        return [
            'price_tab'                   => $this->when($this->price_tab !== null, $this->price_tab),
            'additional_prices_tab'       => $this->when($this->additional_prices_tab !== null, $this->additional_prices_tab),
            'order_files_tab'             => $this->when($this->order_files_tab !== null, $this->order_files_tab),
            'order_overview_times'        => $this->when($this->overview_times !== null, $this->overview_times),
            'order_payment_summary'       => $this->when(
                $this->paymentSummary !== null,
                new OrderPaymentSummaryResource($this->paymentSummary)
            ),
            'id'                          => $this->id ?? null,
            'order_no'                    => $this->order_no ?? null,
            'status'                      => $this->status ?? null,
            'date_added'                  => $this->date_added ?? null,
            'start_date'                  => $this->start_date ?? null,
            'finish_date'                 => $this->finish_date ?? null,
            'est_finish_date'             => $this->est_finish_date ?? null,
            'collaborator_id'             => $this->collaborator_id ?? null,
            'dentist_id'                  => $this->dentist_id ?? null,
            'patient_id'                  => $this->patient_id ?? null,
            'value'                       => $this->value ?? null,
            'value_finish_order'          => $this->value_finish_order ?? null,
            'value_external_invoice'      => $this->value_external_invoice ?? null,
            'temp_value'                  => $this->temp_value ?? null,
            'invoice_value'               => $this->invoice_value ?? null,
            'payment_document_id'         => $this->payment_document_id ?? null,
            'invoice_id'                  => $this->invoice_id ?? null,
            'invoice_order'               => $this->invoice_order ?? null,
            'invoice_order_no'            => $this->invoice_order_no ?? null,
            'cancelled'                   => $this->cancelled ?? null,
            'external_invoice'            => $this->external_invoice ?? null,
            'appears_on_payment_document' => $this->appears_on_payment_document ?? null,
            'reason'                      => $this->reason ?? null,
            'remake_id'                   => $this->remake_id ?? null,
            'remake_of'                   => $this->remake_of ?? null,
            'is_remake'                   => (bool)($this->remake_of ?? null),
            'has_remake'                  => (bool)$this->whenLoaded('hasRemake'),
            'order_status'                => $this->order_status ?? null,
            'stage_id'                    => $this->stage_id ?? null,
            'user_id'                     => $this->user_id ?? null,
            'total'                       => $this->total ?? null,
            'finishDate'                  => $this->finishDate ?? null,
            'collaborator'                => new CollaboratorResource($this->whenLoaded('collaborator')),
            'dentist'                     => new DentistResource($this->whenLoaded('dentist')),
            'patient'                     => new PatientResource($this->whenLoaded('patient')),
            'works'                       => OrderWorkTemplateResource::collection($this->whenLoaded('works')),
            'works_name_and_symbol'       => $this->whenLoaded('worksNameAndSymbol'),
            'actions'                     => $this->when($this->actions ?? false, $this->actions),
            'additionalPrices'            => $this->whenLoaded('additionalPrices'),
            'additionalPricesWGS'         => $this->whenLoaded('additionalPricesWithoutGlobalScope'),
            'order_payments'              => PaymentResource::collection($this->whenLoaded('order_payments')),
            'order_discounts'             => DiscountResource::collection($this->whenLoaded('order_discounts')),
            'payment_document'            => new PaymentDocumentResource($this->whenLoaded('payment_document')),
            //            'files'                       => ['detalii files'],
            //            'details'                     => ['detalii details'],
            'details_tab'                 => new OrderDetailsResource($this),
        ];
    }
}
