<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Collaborator extends Model
{
    use HasFactory, SoftDeletes;

    protected $touches = ['templatesPrice'];

    public static $defaultSort = ['name'];

    public static $sortable = [
        'id',
        'name',
        'cui',
        'nr_reg_comertului',
        'bank',
        'bank_account',
        'address',
        'city',
        'phone_fax',
        'mobile',
        'contact_mobile',
        'email',
        'website',
    ];

    public static $filterable = [
        'dentists.id',
        'dentists.last_name',
        'id',
        'name',
        'cui',
        'nr_reg_comertului',
        'bank',
        'bank_account',
        'address',
        'city',
        'phone_fax',
        'mobile',
        'contact_mobile',
        'email',
        'website',
    ];

    public static $searchable = [
        'id',
        'name',
        'cui',
        'address',
        'phone_fax',
        'contact_mobile'
    ];

    protected $fillable = [
        'name',
        'cui',
        'nr_reg_comertului',
        'bank',
        'bank_account',
        'address',
        'region_id',
        'city',
        'phone_fax',
        'mobile',
        'contact_mobile',
        'email',
        'website'
    ];

    protected $casts = [
        "region_id" => "integer"
    ];

    public function dentists()
    {
        return $this->belongsToMany(Dentist::class);
    }

    public function region()
    {
        return $this->belongsTo(Region::class, 'region_id');
    }

    public function templatesPrice()
    {
        return $this->belongsToMany(WorkTemplate::class, 'collaborator_prices')->withPivot(['price', 'locked'])->orderBy("name")
            ->withTimestamps();
    }
}
