<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Dentist extends Model
{
    use HasFactory, SoftDeletes;

    protected $touches = ['templatesPrice'];

    /**
     * Sorting default when we use
     * Spatie\QueryBuilder\QueryBuilder.
     *
     * sort asc ['id'] , sort desc ['-id']
     *
     * @var array
     */
    public static $defaultSort = ['last_name'];

    public static $sortable = [
        'id',
        'first_name',
        'last_name',
        'cnp',
        'email',
        'phone_fax'
    ];

    public static $filterable = [
        'collaborators.id',
        'collaborators.name',
        'id',
        'first_name',
        'last_name',
        'cnp',
        'email',
        'phone_fax'
    ];


    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'first_name',
        'last_name',
        'cnp',
        'email',
        'phone_fax',
        'collaborator_id'
    ];

    public function collaborators()
    {
        return $this -> belongsToMany(Collaborator::class)->orderBy('name');
    }

    public function templatesPrice()
    {
        return $this->belongsToMany(WorkTemplate::class,'dentist_prices')->withPivot(['price','locked'])->orderBy("name")
            ->withTimestamps();
    }
}
