<?php

namespace App\Models;

use App\Services\InvoiceService;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Invoice extends Model
{
    use HasFactory;

    protected $fillable =
    [
        'collaborator_id',
        'status',
        'value',
        'invoice_series_id',
        'invoice_series',
        'invoice_no',
        'invoice_date',
        'collaborator_name',
        'collaborator_cui',
        'collaborator_nr_reg_comertului',
        'collaborator_bank',
        'collaborator_bank_account',
        'collaborator_address',
        'collaborator_region_id',
        'collaborator_city',
        'collaborator_phone_fax',
        'collaborator_mobile',
        'collaborator_contact_mobile',
        'collaborator_email',
        'collaborator_website',
        'lab_invoice_profile_id',
        'lab_invoice_profile_name',
        'lab_invoice_profile_cui',
        'lab_invoice_profile_nr_reg_comertului',
        'lab_invoice_profile_address',
        'lab_invoice_profile_region_id',
        'lab_invoice_profile_city',
        'lab_invoice_profile_phone_fax',
        'lab_invoice_profile_mobile1',
        'lab_invoice_profile_mobile2',
        'lab_invoice_profile_email1',
        'lab_invoice_profile_email2',
        'lab_invoice_profile_website',
        'lab_invoice_profile_bank',
        'lab_invoice_profile_bank_account',
        'json',
    ];

    public function getPaidAttribute()
    {
        return number_format((float) $this->paymentDocument->payed, 2, '.', '');
    }

    public function getToPayAttribute()
    {
        return number_format((float) $this->paymentDocument->to_pay, 2, '.', '');
    }

    public function getPaymentDocumentIssuedDateAttribute()
    {
        return $this->paymentDocument->created_at ? date('Y-m-d', strtotime($this->paymentDocument->created_at)) : null;
    }

    public function getAllReceiptsAreIssuedAttribute()
    {
        $this->relationLoaded('paymentDocument');
        return InvoiceService::allCashPaymentsHaveReceipts($this->paymentDocument);
    }

    public function getInvoiceDateFormattedAttribute()
    {
        return $this->invoice_date ? date('Y-m-d', strtotime($this->invoice_date)) : null;
    }

    public function paymentDocument()
    {
        return $this->hasOne(PaymentDocument::class);
    }

    public function receipts()
    {
        return $this->hasMany(Receipt::class);
    }

    public function invoiceSeries()
    {
        return $this->belongsTo(InvoiceSeries::class);
    }
}
