<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;

class LabInvoiceProfile extends Model implements HasMedia
{
    use HasFactory;
    use InteractsWithMedia;


    protected $fillable
        = [
            'name',
            'cui',
            'nr_reg_comertului',
            'address',
            'region_id',
            'city',
            'phone_fax',
            'mobile1',
            'mobile2',
            'email1',
            'email2',
            'website',
            'invoice_series',
            'invoice_no',
            'receipt_series',
            'receipt_no',
            'bank',
            'bank_account',
            'proforma_start_no',
            'proforma_series',

        ];

    protected $casts
        = [
            "region_id" => "integer"
        ];


    /**
     * Check if is default profile.
     *
     * @return bool
     */
    public function getIsDefaultAttribute()
    {
        $labProfile = LabProfile::with('invoiceProfile')->firstOrFail();
        return ($labProfile->invoiceProfile->id ?? 0) == $this->id;
    }

    public function region()
    {
        return $this->belongsTo('App\Models\Region', 'region_id');
    }

    public function getLogoAttribute()
    {
        $logo = $this->getFirstMedia('logo');
        return $logo !== null ? $logo->getFullUrl() : $logo;
    }

    public function getCoverAttribute()
    {
        $cover = $this->getFirstMedia('cover');
        return $cover !== null ? $cover->getFullUrl() : $cover;
    }

    public function registerMediaCollections(): void
    {
        $this->addMediaCollection('logo')->singleFile();
        $this->addMediaCollection('cover')->singleFile();
    }


}
