<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;

class LabProfile extends Model implements HasMedia
{
    use HasFactory;
    use InteractsWithMedia;

    protected $table = 'lab_profile';

    protected $casts
        = [
            "region_id"                              => "integer",
            "saturday"                               => 'boolean',
            "sunday"                                 => 'boolean',
            "same_user_option"                       => 'boolean',
            "show_dashboard"                         => 'boolean',
            "force_finish_order"                     => 'boolean',
            "show_calendar"                          => 'boolean',
            "users_occupancy_threshold_busy_waiting" => 'integer',
            "users_occupancy_threshold_busy_working" => 'integer',
            "users_occupancy_threshold_full_waiting" => 'integer',
            "users_occupancy_threshold_full_working" => 'integer'
        ];

    protected $fillable
        = [
            'name',
            'address',
            'region_id',
            'city',
            'phone_fax',
            'mobile1',
            'mobile2',
            'email1',
            'email2',
            'website',
            'facebook',
            'linkedin',
            'users_occupancy_threshold_busy_waiting',
            'users_occupancy_threshold_busy_working',
            'users_occupancy_threshold_full_waiting',
            'users_occupancy_threshold_full_working',
            'saturday',
            'sunday',
            'same_user_option',
            'show_dashboard',
            'show_calendar',
            'force_finish_order'
        ];

    public function invoiceProfile()
    {
        return $this->belongsTo(LabInvoiceProfile::class, 'lab_invoice_profile_id');
    }

    public function region()
    {
        return $this->belongsTo('App\Models\Region', 'region_id');
    }

    public function getLogoAttribute()
    {
        $logo = $this->getFirstMedia('logo');
        return $logo !== null ? $logo->getFullUrl() : $logo;
    }

    public function getCoverAttribute()
    {
        $cover = $this->getFirstMedia('cover');
        return $cover !== null ? $cover->getFullUrl() : $cover;
    }


    public function registerMediaCollections(): void
    {
        $this->addMediaCollection('logo')->singleFile();
        $this->addMediaCollection('cover')->singleFile();
    }

}
