<?php

namespace App\Models;

use App\Traits\HasArcadaDentition;
use App\Traits\HasDentition;
use App\Traits\HasMultiFactorDentition;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class OrderWorkTemplate extends Model
{
    use HasFactory;
    use HasMultiFactorDentition;
    use HasArcadaDentition;
    use HasDentition;

    protected $touches = [
        "stages",
        "workStagesOrdered",
    ];
    protected $appends = [
        'multi_factor'
    ];


    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'order_id' => 'integer',
        'work_template_id' => 'integer',
        'min_duration' => 'integer',
        'estimated_duration' => 'integer',
        'preferred_duration' => 'integer',
        'elements' => 'integer',
        'combination_id' => 'integer',
    ];

    public function getArrayDentitionAttribute()
    {
        return $this->dentition_array;
    }

    public function getMultiFactorAttribute()
    {
        if($this->price_type === 'fix'){
            return 1;
        }

        if($this->price_type === 'arcada'){
            $elements = 0;
            if(isset($this->arcada_dentition->upper) && $this->arcada_dentition->upper){
                $elements++;
            }
            if(isset($this->arcada_dentition->lower) && $this->arcada_dentition->lower){
                $elements++;
            }

            return $elements;
        }

        return $this->elements;
    }

    public static function reorder($id)
    {
        // this function just sets the rank column right, in case of delete
        $stages = OrderWorkStage::where('order_work_template_id', $id)->orderBy('rank')->get();

        $rank = 0;
        foreach ($stages as $stage) {
            $stage->rank = $rank++;
            $stage->save();
        }
    }


    public function combinations()
    {
        return $this->hasMany(OrderWorkTemplate::class, 'combination_id');
    }

    public function stages()
    {
        return $this->belongsToMany(WorkStage::class, 'order_work_stages', 'order_work_template_id', 'work_stage_id')->withPivot('id')->withTimestamps();
    }

    public function workStagesOrdered()
    {
        return $this->belongsToMany(WorkStage::class, 'order_work_stages', 'order_work_template_id', 'work_stage_id')->orderBy('order_work_stages.rank')
            ->withPivot(['id', 'rank', 'work_template_id', 'work_stage_id', 'day_number'])->withTimestamps();
    }

    public function stagesWithoutPivot()
    {
        return $this->hasMany(OrderWorkStage::class, 'order_work_template_id')->orderBy('order_work_stages.rank');
    }

    public function order()
    {
        return $this->belongsTo(Order::class)->withTrashed();
    }

    public function workTemplate()
    {
        return $this->belongsTo(WorkTemplate::class)->withTrashed();
    }


    public function remakeStagesPrice(){
        return $this->hasOne(OrderWorkStage::class, 'order_work_template_id')
            ->select('order_work_template_id', \DB::raw('SUM(price * multi_factor) as sum'))
            ->where('remake_id', '<>', 0)
            ->where('collaborator_fault_id', '<>', 0)
            ->where('lab_paying', 0)
            ->groupBy('order_work_template_id');
    }
}
