<?php

namespace App\Models;

use App\Traits\HasMultiFactorDentition;
use App\Traits\MultiFactorDentition;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class WorkStage extends Model
{
    use HasFactory;
    use SoftDeletes;
    use HasMultiFactorDentition;

    public static $searchable
        = [
            'id',
            'name',
            'type',
            'min_duration',
            'cost',
            'remake_cost',
            'special_cost'
        ];

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable
        = [
            'name',
            'type',
            'price_type',
            'min_duration',
            'cost',
            'remake_cost',
            'special_cost',
            'to_send',
            'description',
            'confirmation_required',
            'extra_cost_applied',
            'multi_factor_dentition',
        ];

    protected $casts
        = [
            'to_send'               => 'boolean',
            'confirmation_required' => 'boolean',
            'extra_cost_applied'    => 'boolean',
            'min_duration'          => 'integer',
        ];

    function workStageUsers()
    {
        return $this->hasMany(WorkStageUser::class)->orderBy('rank');
    }

    function workTemplateStageUsers()
    {
        return $this->belongsToMany(User::class, 'work_template_stage_users', 'work_stage_id', 'user_id')->orderBy('rank')->withPivot(
            ['id', 'price', 'rank', 'work_template_id']
        );
    }

    public function users()
    {
        return $this->belongsToMany(User::class, 'work_stage_users', 'work_stage_id', 'user_id')->orderBy('rank')->withPivot(
            ['id', 'price', 'rank']
        );
    }


}
