<?php

namespace App\Rules;

use App\Exceptions\Api\ServerError;
use App\Exceptions\Api\ValidationException;
use App\Models\OrderWorkTemplate;
use App\Services\OrderWorkStagesService;
use Illuminate\Contracts\Validation\Rule;
use phpDocumentor\Reflection\Types\Integer;

class OrderSpecialStageRule implements Rule
{
    var $errorMessage = null;
    var $type = null;
    var $stage_id = 0;

    /**
     * Create a new rule instance.
     *
     * @return void
     */
    public function __construct($type,$orderWorkTemplate,$orderWorkStageId)
    {
        $this -> work_id =  $orderWorkTemplate;
        $this -> stage_id =  $orderWorkStageId;
        $this -> type =  $type;
        $this -> errorMessage = __('Elements incorrect formatted');
    }

    /**
     * Determine if the validation rule passes.
     *
     * @param  string  $attribute
     * @param  mixed  $value
     *
     * @return bool
     */
    public function passes($attribute, $value)
    {
        return $this->isValidSpecialStage($value);
    }

    /**
     * Get the validation error message.
     *
     * @return string
     */
    public function message()
    {
        return $this -> errorMessage;
    }

    public function isValidSpecialStage($value)
    {
        $isValid = false;
        switch ($this -> type){
            case 'fix':
                $isValid = true;
                if(!isset($value['fix']) || !is_bool($value['fix'])){
                    $this ->errorMessage = __('Invalid parameter for fix type');
                    $isValid = false;
                }
                break;

            case 'elemente':
                $isValid = false;
                $work = OrderWorkTemplate::findOrFail($this -> work_id);
                $orderStage = $work->stagesWithoutPivot()->where('id', $this -> stage_id)->firstOrFail();
                $elements = OrderWorkStagesService::getStageDentitionElements($orderStage);
                if(!is_array($value) || (count((array)$elements) !== count($value))){
                    $this ->errorMessage = __('Invalid parameter elements');
                    return $isValid;
                }

                foreach ((array)$elements as $key => $item) {
                    if(!isset($value[$key])){
                        $this ->errorMessage = __('Missing parameter :key on elements',["key"=>$key]);
                        return $isValid;
                    }
                }
                $isValid = true;
                break;

            case 'arcada':
                $isValid = true;
                if(!isset($value['upper']) || !is_bool($value['upper'])){
                    $this ->errorMessage = __('Invalid parameter upper for arcada type');
                    $isValid = false;
                }
                if(!isset($value['lower']) || !is_bool($value['lower'])){
                    $this ->errorMessage = __('Invalid parameter lower for arcada type');
                    $isValid = false;
                }
                break;
            default:
                throw  new ServerError(__('Price type validation is not implemented.'));
                break;
        }

        return $isValid;

    }
}
