<?php


namespace App\Services;

use Illuminate\Support\Facades\DB;

class DentistPriceService
{
    /**
     * List work templates with preferential & locked prices.
     *
     * @param int $dentistId
     * @return object
     */
    public static function getDentistPreferentialPrices(int $dentistId): object
    {
        return DB::table('work_templates')
            ->select(
                'work_templates.id AS work_template_id',
                'work_templates.name AS work_template_name',
                'work_templates.cost AS work_template_cost',
                'work_templates.price_type AS work_template_price_type',
                'preferential_prices.price AS dentist_price',
                'preferential_prices.locked AS dentist_price_locked',
                DB::raw('IF (preferential_prices.price IS NULL, FALSE, TRUE) AS dentist_preferential_price')
            )
            ->leftJoin(
                DB::raw("(SELECT * FROM dentist_prices WHERE dentist_id = {$dentistId}) AS preferential_prices"),
                'work_templates.id',
                '=',
                'preferential_prices.work_template_id'
            )
            ->orderBy('work_templates.id', 'asc')
            ->get();
    }

    /**
     * List collaborators with preferential prices.
     *
     * @param integer $dentistId
     * @return object
     */
    public static function getCollaboratorPreferentialPrices(int $dentistId): object
    {
        return DB::table('dentists')
            ->select(
                'collaborators.id AS collaborator_id',
                'collaborator_prices.work_template_id AS work_template_id',
                'collaborators.name AS collaborator_name',
                'collaborator_prices.price AS collaborator_price',
                DB::raw("IF (collaborator_prices.locked = 0, FALSE, TRUE) AS collaborator_price_locked")
            )
            ->leftJoin(
                'collaborator_dentist',
                'dentists.id',
                '=',
                'collaborator_dentist.dentist_id',
            )
            ->leftJoin(
                'collaborators',
                'collaborators.id',
                '=',
                'collaborator_dentist.collaborator_id',
            )
            ->leftJoin(
                'collaborator_prices',
                'collaborator_prices.collaborator_id',
                '=',
                'collaborators.id'
            )
            ->where('collaborator_dentist.dentist_id', '=', $dentistId)
            ->get();
    }
}
