<?php


namespace App\Services;


use App\Configuration\LabConfiguration;
use App\Exceptions\Api\ValidationException;
use App\Models\OrderWorkStage;
use App\Models\OrderWorkTemplate;

class DentitionService
{
    public static function emptyDentition($asJson = true)
    {
        $options = LabConfiguration::dentition();
        $extraStages = LabConfiguration::getCheckboxStages();
        $dentition = [];

        foreach ($options as $row) {
            $tmp = $row['options'];
            foreach ($tmp as $dent) {
                $dentition[$dent]['form'] = 0;
                $dentition[$dent]['xtra'] = new \stdClass();
                foreach ($extraStages as $extraStage) {
                    $dentition[$dent]['xtra']->$extraStage = false;
                }
            }
        }

        if ($asJson) {
            return json_encode($dentition);
        }

        return $dentition;
    }

    public static function addFieldFormCanBeModifiedToDentition($dentition, $canBeModifiedValue = true)
    {
        foreach ($dentition as $key => $row) {
            $dentition[$key][config('lab_configuration.default_name_for_dentition_tooth_can_be_modified')] = $canBeModifiedValue;
        }

        return $dentition;
    }

    public static function emptyDentitionWithAdditionalFields($asJson = true)
    {
        $emptyDentition = self::emptyDentition(false);
        $emptyDentition = self::addFieldFormCanBeModifiedToDentition(
            $emptyDentition,
            config(
                'lab_configuration.default_value_for_dentition_tooth_can_be_modified'
            )
        );

        if ($asJson) {
            return json_encode($emptyDentition);
        }
        return $emptyDentition;
    }

    public static function reorderDentitionKeys(array $toBeOrdered, array $blueprintDentition)
    {
        $reordered = [];
        foreach ($blueprintDentition as $keyTeeth => $data) {
            if (!isset($toBeOrdered[$keyTeeth])) {
                throw new ValidationException(__("Missing key for dentition:").$keyTeeth);
            }
            $reordered["$keyTeeth"] = $toBeOrdered[$keyTeeth];
        }

        return $reordered;
    }

    /*
    arcada
    -----------------------------------------------------------------------------------------------
     */
    public static function updateWorkArcada(OrderWorkTemplate $work, $arcadaParameters)
    {
        $work->arcada_dentition = json_encode($arcadaParameters);
        $work->save();
        if ($work->isDirty()) {
            $work->refresh();
        }
        $checkboxStages = LabConfiguration::getCheckboxStages();
        $stages = OrderWorkStage::where('order_work_template_id', $work->id)->whereNotIn('type', $checkboxStages)->where(
            'price_type',
            'arcada'
        )->get();


        foreach ($stages as $stage) {
            $stage->arcada_dentition = $work->arcada_dentition;
            $stage->multi_factor = OrderWorkStagesService::calculateMultiFactor(
                $stage['type'],
                $stage['price_type'],
                json_decode($stage->dentition),
                json_decode($stage->arcada_dentition)
            );

            $stage->save();
        }
        return $work;
    }


    /*
    form
    -----------------------------------------------------------------------------------------------
     */
    public static function updateWorkForm(OrderWorkTemplate $work, $dentitionParameters, $throwException = false)
    {
        $dentition = $work->array_dentition;
        $dentitionOptions = config('lab_configuration.dentition');
        $toothCanBeModifiedFieldName = config('lab_configuration.default_name_for_dentition_tooth_can_be_modified');
        $toothCanBeModifiedDefaultValue = config('lab_configuration.default_value_for_dentition_tooth_can_be_modified');

        foreach ($dentitionParameters as $key => $item) {
            //tooth can not be modified
            if ($dentition->$key->$toothCanBeModifiedFieldName !== $toothCanBeModifiedDefaultValue
                && $dentition->$key->form !== $item['form']
            ) {
                if ($throwException) {
                    throw new ValidationException(
                        __(
                            'Tooth :toothNumber can not be modified from :itemValue to :formValue',
                            [
                                'toothNumber' => $key,
                                'itemValue'   => $dentition->$key->form,
                                'formValue'   => $item['form']
                            ]
                        )
                    );
                }
                continue;
            }

            //can update tooth  if
            // is not already in a work
            // or updating comes from the same work
            // or is not sett already (has value 0)
            if (!isset($dentition->$key->work_id) || $dentition->$key->work_id == $work->id || !$dentition->$key->form) {
                $dentition->$key->form = $item['form'];
                $dentition->$key->work_id = $work->id;
                $dentition->$key->work_name = $work->original_name;
                $dentition->$key->work_symbol = $work->symbol;
            }
            //removing work data if no form is selected
            if (!$item['form'] && !$dentition->$key->form) {
                unset($dentition->$key->work_id);
                unset($dentition->$key->work_name);
                unset($dentition->$key->work_symbol);
            }
        }

        // count elements by form
        $elements = 0;
        $arcadaDentition = $work->arcada_dentition_array ?? config('lab_configuration.default_arcada_dentition');
        $multifactorDentition = $work->multi_factor_dentition_array;

        foreach ($dentition as $key => $tmp) {
            if ($tmp->form != 0 && $tmp->work_id == $work->id) {
                $form = $tmp->form;

                if (isset($multifactorDentition->$form) && $multifactorDentition->$form) {
                    $elements++;

                    // arcada dentition
                    if (in_array($key, $dentitionOptions[0]['options'])) {
                        $arcadaDentition->upper = true;
                    }
                    if (in_array($key, $dentitionOptions[1]['options'])) {
                        $arcadaDentition->lower = true;
                    }
                }
            }
        }

        $work->dentition = json_encode($dentition);
        $work->arcada_dentition = json_encode($arcadaDentition);
        $work->elements = $elements;
        $work->save();

        self::updateRegularNoElements($work, $dentition);

        return $work;
    }

    public static function updateRegularNoElements(OrderWorkTemplate $orderWork, $workDentition)
    {
        $checkboxStages = LabConfiguration::getCheckboxStages();
        $dentitionOptions = config('lab_configuration.dentition'); // \SelectOptions::$options['dentition'];

        $stages = OrderWorkStage::where('order_work_template_id', $orderWork->id)->whereNotIn('type', $checkboxStages)->get();

        foreach ($stages as $stage) {
            $dentitionByWork = [];
            $arcadaDentition = config('lab_configuration.default_arcada_dentition');

            if (!is_null($workDentition)) {
                foreach ($workDentition as $key => $dent) {
                    if ($dent->form != 0) {
                        $form = $dent->form;
                        $stageMultiFactorDentition = (array)$stage->multi_factor_dentition_array;
                        if (isset($stageMultiFactorDentition[$form]) && $stageMultiFactorDentition[$form]) {
                            $dentitionByWork[$dent->work_id][$key] = true;

                            // arcada dentition
                            if (in_array($key, $dentitionOptions[0]['options'])) {
                                $arcadaDentition['upper'] = true;
                            }
                            if (in_array($key, $dentitionOptions[1]['options'])) {
                                $arcadaDentition['lower'] = true;
                            }
                        }
                    }
                }
            }

            $stageDent = [];

            $works = json_decode($stage->works);

            foreach ($dentitionByWork as $work => $dentition) {
                if (in_array($work, $works)) {
                    foreach ($dentition as $key => $dent) {
                        $stageDent[$key] = $dent;
                    }
                }
            }

            $stage->dentition = json_encode($stageDent);
            $stage->arcada_dentition = json_encode($arcadaDentition);
            $stage->elements = count($stageDent);

            $stage->multi_factor = OrderWorkStagesService::calculateMultiFactor(
                $stage->type,
                $stage->price_type,
                json_decode($stage->dentition),
                json_decode($stage->arcada_dentition)
            );

            $stage->save();
        }

        return true;
    }

    /*
    xtra
    -----------------------------------------------------------------------------------------------
    */
    public static function updateOrderXtra(OrderWorkTemplate $work, $dentitionParameters)
    {
        $dentition = $work->dentition;
        $dentition = json_decode($dentition);

        foreach ($dentitionParameters as $key => $item) {
            foreach ($item['xtra'] as $extraName => $extraValue) {
                $dentition->$key->xtra->$extraName = $extraValue;
            }
        }

        $work->dentition = json_encode($dentition);
        $work->save();

        DentitionService::updateSpecialElements($work, $dentitionParameters);

        return $work;
    }

    public static function updateSpecialElements(OrderWorkTemplate $work, $dentitionParameters)
    {
        $extraOptionNames = LabConfiguration::getCheckboxStages();
        $dentitionOptions = config('lab_configuration.dentition');
        $stages = OrderWorkStage::where('order_work_template_id', $work->id)->whereIn('type', $extraOptionNames)->where(
            'price_type',
            '=',
            'elemente'
        )->get();

        $workArcadaDentition = $work->arcada_dentition_array;


        foreach ($stages as $stage) {
            $oldDentition = json_decode($stage->dentition, true);
            $arcadaDentition = $stage->arcada_dentition_array;
            $dentition = [];
            $elements = 0;

            foreach ($dentitionParameters as $key => $options) {
                foreach ($options['xtra'] as $name => $value) {
                    //update only on same type
                    if ($name != $stage->type) {
                        continue;
                    }
                    // count no elements
                    //setting stage and work arcada active if necessary
                    if ($value == true) {
                        $dentition[$key] = $oldDentition[$key] ?? false;
                        if ($dentition[$key] == true) {
                            // arcada dentition
                            if (in_array($key, $dentitionOptions[0]['options'])) {
                                $arcadaDentition->upper = $workArcadaDentition->upper = true;
                            }
                            if (in_array($key, $dentitionOptions[1]['options'])) {
                                $arcadaDentition->lower = $workArcadaDentition->lower = true;
                            }

                            $elements++;
                        }
                    }
                }
            }

            $multiFactor = 1;
            if ($stage['price_type'] !== 'fix') {
                $multiFactor = $elements;
            }

            $stage->arcada_dentition = json_encode($arcadaDentition);
            $stage->multi_factor = $multiFactor;
            $stage->dentition = json_encode($dentition);
            $stage->elements = $elements;
            $stage->save();
        }

        $work->arcada_dentition = json_encode($workArcadaDentition);
        $work->save();

        return true;
    }

}
