<?php


namespace App\Services;

use App\Exceptions\Api\AccessDeniedException;
use App\Exceptions\Api\ValidationException;
use App\Models\Discount;
use App\Models\PaymentDocument;

class DiscountService
{
    /**
     * Check if discount can be added to the payment document.
     *
     * @param PaymentDocument $paymentDocument
     * @param boolean $throwException
     * @return boolean
     */
    public static function canAddDiscount(PaymentDocument $paymentDocument, $throwException = false)
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
        }

        $canAddDiscount = true;
        $errorMessage = __('validation.discount_cant_be_added');

        if ($paymentDocument->invoice_id) {
            $canAddDiscount = false;
            $errorMessage = __('validation.invoice_already_generated');
        }

        if ($throwException && !$canAddDiscount) {
            throw new ValidationException($errorMessage);
        }

        return $canAddDiscount;
    }

        /**
     * Check if discount can be removed from the payment document.
     *
     * @param PaymentDocument $paymentDocument
     * @param boolean $throwException
     * @return boolean
     */
    public static function canRemoveDiscount(PaymentDocument $paymentDocument, $throwException = false)
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
        }

        $canAddDiscount = true;
        $errorMessage = __('validation.discount_cant_be_removed');

        if ($paymentDocument->invoice_id) {
            $canAddDiscount = false;
            $errorMessage = __('validation.invoice_already_generated');
        }

        if ($throwException && !$canAddDiscount) {
            throw new ValidationException($errorMessage);
        }

        return $canAddDiscount;
    }

    /**
     * @param  int  $discountId
     */
    public static function deleteDiscount(int $discountId): void
    {
        $discount = Discount::findOrfail($discountId);
        $discount -> delete();
    }
}
