<?php

/**
 * Created by PhpStorm.
 * User: Stefi
 * Date: 15/10/2021
 * Time: 08:45
 */

namespace App\Services;

use App\Models\Collaborator;
use App\Models\Invoice;
use App\Models\InvoiceSeries;
use App\Models\LabInvoiceProfile;
use App\Models\LabProfile;
use App\Models\PaymentDocument;
use Carbon\Carbon;
use PDF;

class InvoiceService
{
    public static function verifyNoInvoiceIssuedAfterSpecifiedDate($issueDate, $seriesId)
    {
        $verify = true;
        $invoicesIssued = Invoice::where('invoice_date', '>', $issueDate)->where('invoice_series_id', $seriesId)->get();
        if (count($invoicesIssued) > 0) {
            $verify = false;
        }
        return $verify;
    }

    public static function generateInvoiceNumberBySeries(InvoiceSeries $invoiceSeries)
    {
        $no = $invoiceSeries->start_no;
        $invoice = Invoice::where('invoice_series', $invoiceSeries->series)
            ->where('invoice_series_id', $invoiceSeries->id)
            ->orderBy('invoice_no', 'DESC')
            ->first();

        if (!is_null($invoice)) {
            $no = $invoice->invoice_no + 1;
        }

        return $no;
    }

    public static function generateInvoice(PaymentDocument $paymentDocument, int $seriesId, int $collaboratorId, $issueDate, array $services)
    {
        $data = [];
        $invoiceSeries = InvoiceSeries::findOrFail($seriesId);
        $data['invoice_series_id'] = $seriesId;
        $data['invoice_series'] = $invoiceSeries->series;
        $data['invoice_no'] = self::generateInvoiceNumberBySeries($invoiceSeries);
        $data['invoice_date'] = $issueDate;

        $labProfile = LabProfile::where('lab_invoice_profile_id', $invoiceSeries->lab_invoice_profile_id)->get()->toArray();
        $invoiceServices['services'] = $services;
        $invoiceServices['lab_profile'] = $labProfile;

        $data['json'] = json_encode($invoiceServices);
        $data['value'] = PaymentDocumentService::calculatePaymentDocumentValue($paymentDocument->id);

        $collaborator = Collaborator::findOrFail($collaboratorId);
        $data['collaborator_id'] = $collaborator->id;
        $data['collaborator_name'] = $collaborator->name;
        $data['collaborator_cui'] = $collaborator->cui;
        $data['collaborator_nr_reg_comertului'] = $collaborator->nr_reg_comertului;
        $data['collaborator_bank'] = $collaborator->bank;
        $data['collaborator_bank_account'] = $collaborator->bank_account;
        $data['collaborator_address'] = $collaborator->address;
        $data['collaborator_region_id'] = $collaborator->region_id;
        $data['collaborator_city'] = $collaborator->city;
        $data['collaborator_phone_fax'] = $collaborator->phone_fax;
        $data['collaborator_mobile'] = $collaborator->mobile;
        $data['collaborator_contact_mobile'] = $collaborator->contact_mobile;
        $data['collaborator_website'] = $collaborator->website;

        $labInvoiceProfile = LabInvoiceProfile::findOrFail($invoiceSeries->lab_invoice_profile_id);
        $data['lab_invoice_profile_id'] = $labInvoiceProfile->id;
        $data['lab_invoice_profile_name'] = $labInvoiceProfile->name;
        $data['lab_invoice_profile_cui'] = $labInvoiceProfile->cui;
        $data['lab_invoice_profile_nr_reg_comertului'] = $labInvoiceProfile->nr_reg_comertului;
        $data['lab_invoice_profile_nr_reg_comertului'] = $labInvoiceProfile->nr_reg_comertului;
        $data['lab_invoice_profile_address'] = $labInvoiceProfile->address;
        $data['lab_invoice_profile_region_id'] = $labInvoiceProfile->region_id;
        $data['lab_invoice_profile_city'] = $labInvoiceProfile->city;
        $data['lab_invoice_profile_phone_fax'] = $labInvoiceProfile->phone_fax;
        $data['lab_invoice_profile_mobile1'] = $labInvoiceProfile->mobile1;
        $data['lab_invoice_profile_mobile2'] = $labInvoiceProfile->mobile2;
        $data['lab_invoice_profile_email1'] = $labInvoiceProfile->email1;
        $data['lab_invoice_profile_email2'] = $labInvoiceProfile->email2;
        $data['lab_invoice_profile_website'] = $labInvoiceProfile->website;
        $data['lab_invoice_profile_bank'] = $labInvoiceProfile->bank;
        $data['lab_invoice_profile_bank_account'] = $labInvoiceProfile->bank_account;

        $invoice = Invoice::create($data);

        $paymentDocument->invoice_id = $invoice->id;
        $paymentDocument->invoice_series = $invoice->invoice_series;
        $paymentDocument->invoice_no = $invoice->invoice_no;
        $paymentDocument->invoice_date = $invoice->invoice_date;
        $paymentDocument->save();

        return $invoice;
    }

    /**
     * Check if all cash payments have receipts.
     *
     * @param mixed $paymentDocument
     * @return boolean
     */
    public static function allCashPaymentsHaveReceipts($paymentDocument)
    {
        return Invoice::whereHas('paymentDocument', function ($q) {
            return $q->whereHas('payments', function ($q) {
                return $q->where('type', 'cash');
            });
        });
    }

    /**
     * Generate the invoice's PDF document.
     *
     * @param Invoice $invoice
     * @return object
     */
    public static function generateInvoicePdf(Invoice $invoice): object
    {
        $discounts = $invoice->paymentDocument->discounts ?? null;
        $invoiceJson =  json_decode($invoice->json);
        $date = new Carbon($invoice->invoice_date);
        $total = 0;

        foreach ($invoiceJson->services as $service) {
            $total += $service->amount * $service->unit_price;
        }

        $pdf = PDF::loadView('pdf.invoice', [
            'invoice'           => $invoice,
            'invoiceJson'       => $invoiceJson,
            'date'              => $date->format('d.m.Y'),
            'discounts'         => $discounts,
            'total'             => $total,
            'vat'               => $invoice->invoiceSeries->vat / 100,
            'i'                 => 0,
        ]);

        return $pdf;
    }
}
