<?php


namespace App\Services;


use App\Http\Controllers\OrderWorkStageController;
use App\Models\Order;
use App\Models\OrderWorkStage;

class OrderCancelService
{
    private $order;
    private $appearsOnPaymentDocument;
    private $reason;
    private $stagesNewCost;

    /**
     * OrderCancelService constructor.
     *
     * @param  int  $orderId
     * @param $reason
     * @param  false  $appearsOnPaymentDocument
     */
    function __construct(int $orderId, $reason, $appearsOnPaymentDocument = false, $costs = [])
    {
        $this->order = Order::findOrFail($orderId);
        $this->appearsOnPaymentDocument = $appearsOnPaymentDocument;
        $this->reason = $reason;
        $this->stagesNewCost = $costs;
    }

    public function getOrder()
    {
        return $this->order;
    }

    public function remake()
    {
        $orderRemake = new OrderRemakeService($this->order);
        $orderCancel = $this;
        \DB::transaction(
            function () use (&$orderRemake, &$orderCancel) {
                $orderRemake->remake();
                $orderCancel->cancelOrder();
            }
        );

        return $orderRemake->getRemake();
    }

    public function isPayed()
    {
        //todo verificare daca este sau nu platit cand se implementeaza platile
        return false;
    }

    public function cancelOrder($withRemake = false)
    {
        // remake order stages
        if($withRemake){
            $orderRemake = new OrderRemakeService($this->order);
            $orderRemake->remake();
        }

        $this->order->appears_on_payment_document = $this->appearsOnPaymentDocument;
        $this->order->reason = $this->reason;
        $this->order->cancelled = 1;

        // finish order
        $this->order->status = 'complete';
        $this->order->finish_date = \DB::raw('now()');

        // update value
        $value = OrderService::calculateTotalPrice($this->order->id);

        $this->order->value_finish_order = $value;
        if ($this->order->payment_document_id == 0) {
            $this->order->value = $value;
        }

        $this->validateNewCostsStagesIds();
        $this->updateOrderWorkStagesCost($this->stagesNewCost);

        $this->order->save();

        return $this->order;
    }

    private function updateOrderWorkStagesCost($newCosts){
        foreach($newCosts as $index => $costStageArr){
            OrderWorkStage::where('id', $costStageArr['stage_id'])
                ->where('order_id', $this->order->id)
                ->update([
                    'cost' => (float)$costStageArr['cost_per_unit']
                ]);
        }
    }

    public function validateNewCostsStagesIds(){
        $owtStages = OrderWorkStage::where('order_id',$this->order->id)->get();
        $owtStagesIds = $owtStages->pluck('id')->toArray();

        //TODO sa mutam metoda 'validateOrderStageIds' in OWSService ca sa nu instantiez aici OrderWorkStageController?
        $owsControlller = new OrderWorkStageController();
        $owsControlller->validateOrderStageIds($this->stagesNewCost, $owtStagesIds);
    }

}
