<?php


namespace App\Services;


use App\Exceptions\Api\ValidationException;
use App\Models\LabProfile;

class OrderDatesCalculatorService
{

    /**
     * @var DateTime
     */
    private $startDate;

    /**
     * @var boolean
     */
    private $workSaturday;

    /**
     * @var boolean
     */
    private $workSunday;

    public function __construct($startDate)
    {
        $seconds = 60;
        //using cache for labProfile
        $labProfile = cache()->store('file')->remember(
            'labProfile'.tenancy()->tenant->id,
            $seconds,
            function () {
                return LabProfile::select(['saturday','sunday'])->firstOrFail();
            }
        );
        $this->startDate = new \DateTime($startDate);
        $this->workSaturday = $labProfile->saturday;
        $this->workSunday = $labProfile->sunday;
    }


    public function getDayNo($days)
    {
        if (!isset($this->startDate)) {
            throw new ValidationException(__('startDate not set for order'));
        }
        if (!isset($this->workSaturday)) {
            throw new ValidationException(__('work saturday not set in lab profile'));
        }
        if (!isset($this->workSunday)) {
            throw new ValidationException(__('work sunday not set in lab profile'));
        }

        $tmp = clone $this->startDate;

        $oneDay = \DateInterval::createfromdatestring('+1 day');

        for ($i = 1; $i <= $days; $i++) {
            $tmp->add($oneDay);

            // check for saturday and sunday
            if ($tmp->format('N') == 6 && !$this->workSaturday) {
                $tmp->add($oneDay);
            }
            if ($tmp->format('N') == 7 && !$this->workSunday) {
                $tmp->add($oneDay);
            }

            if ($tmp->format('N') == 6 && !$this->workSaturday) {
                $tmp->add($oneDay);
            }
            if ($tmp->format('N') == 7 && !$this->workSunday) {
                $tmp->add($oneDay);
            }
        }

        return $tmp;
    }


    public static function calculateDays($startDate, $noOfDays)
    {
        $class = new OrderDatesCalculatorService($startDate);

        $newDate = $class->getDayNo($noOfDays);

        $newDate = $newDate->format('Y-m-d');

        return $newDate;
    }


}
