<?php

namespace App\Services;

use App\Exceptions\Api\AccessDeniedException;
use App\Exceptions\Api\NotFound;
use App\Models\Order;
use App\Models\OrderDiscount;

class OrderDiscountService
{

    /**
     * @param  Order  $order
     * @param  array  $paymentParameters
     *
     * @throws AccessDeniedException
     */
    public static function addDiscount(Order $order, array $paymentParameters): void
    {
        self::canAddDiscount($order, $paymentParameters['value'], true);
        OrderDiscount::create($paymentParameters);
    }

    /**
     * @param  Order  $order
     * @param $value
     * @param  bool  $throwException
     *
     * @return bool
     * @throws AccessDeniedException
     */
    private static function canAddDiscount(Order $order, $value, bool $throwException = true): bool
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            if ($throwException) {
                throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
            }
            return false;
        }

        return true;
    }

    /**
     * @param  Order  $order
     * @param  int  $discountId
     *
     * @return Order
     * @throws AccessDeniedException
     * @throws NotFound
     */
    public static function deleteDiscount(Order $order, int $discountId): Order
    {
        $order->loadMissing('order_discounts');
        self::canDeleteDiscountId($order, $discountId);
        $discount = OrderDiscount::where('order_id',$order->id)->where('id',$discountId)->firstOrFail();
        $discount->delete();
        return $order;
    }

    /**
     * @param  Order  $order
     * @param  int  $discountId
     * @param  bool  $throwException
     *
     * @return bool
     * @throws AccessDeniedException
     * @throws NotFound
     */
    private static function canDeleteDiscountId(Order $order, int $discountId, bool $throwException = true): bool
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            if ($throwException) {
                throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
            }
            return false;
        }

        $discount = $order->order_discounts()->where('id', $discountId)->first();
        if ($discount === null) {
            if ($throwException) {
                throw new NotFound(__('Discount could not be found'));
            }
            return false;
        }

        return true;
    }
}
