<?php


namespace App\Services;


use App\Http\Controllers\OrderController;
use App\Models\Order;

use App\Models\OrderAdditionalPrice;
use function GuzzleHttp\Psr7\_parse_message;
use App\Models\OrderDetail;
use Illuminate\Http\UploadedFile;

class OrderRemakeService
{

    private $order;
    private $remake;
    private $workIds = [];
    private $remakeWorks = [];
    private $remakeStages = [];

    function __construct(Order $order)
    {
        $this->order = $order;
    }

    public function getOrder()
    {
        return $this->order;
    }

    public function getRemake()
    {
        return $this->remake;
    }

    public function getOrderWorks()
    {
        return $this->order->works ?? [];
    }

    public function getOrderStages()
    {
        return $this->order->orderStagesWithoutRemakes ?? [];
    }

    public function remake()
    {
        \DB::transaction(
            function () {
                $this->remakeOrder();
                $this->remakeWorks();
                $this->remakeStages();
                $this->remakeExtraPrices();
                $this->remakeFiles();
                $this->remakeOrderDetails();
                $this->saveRemakeIdOnOrder();
            }
        );
    }

    private function remakeOrder()
    {
        $this->remake = $this->order->replicate();

        $this->remake->order_no = OrderService::getNextOrderNumber();
        $this->remake->status = 'creating';
        $this->remake->value = 0;
        $this->remake->value_finish_order = 0;
        $this->remake->payment_document_id = 0;
        $this->remake->remake_of = $this->order->id;

        $this->remake->save();

        return $this->remake;
    }

    private function remakeWorks()
    {
        $orderWorks = $this->getOrderWorks();
        foreach ($orderWorks as $work) {
            $remakeWork = $work->replicate();

            $remakeWork->order_id = $this->remake->id;

            $remakeWork->save();

            $this->remakeWorks[] = $remakeWork;
            $this->workIds[$work->id] = $remakeWork->id;
        }


        // swap ids
        foreach ($this->remakeWorks as &$work) {
            // update combination id if is set
            if ($work->combination_id) {
                $work->combination_id = $this->getNewWorkId($work->combination_id);
            }

            $dentition = json_decode($work->dentition);

            foreach ($dentition as &$dent) {
                if (isset($dent->work_id) && $dent->work_id) {
                    $dent->work_id = $this->getNewWorkId($dent->work_id);
                }
            }

            $work->dentition = json_encode($dentition);

            $work->save();
        }
    }

    private function remakeStages()
    {
        $orderStages = $this->getOrderStages();
        foreach ($orderStages as $stage) {
            $remakeStage = $stage->replicate();

            // substituting work id in stage works array
            $stageWorksIds = json_decode($stage->works);

            foreach ($stageWorksIds as $key => $workId) {
                $stageWorksIds[$key] = $this->getNewWorkId($workId);
            }

            $stageWorksIds = json_encode($stageWorksIds);

            $remakeStage->order_id = $this->remake->id;
            $remakeStage->order_work_template_id = $this->getNewWorkId($stage->order_work_template_id);
            $remakeStage->status = 'not_ready';
            $remakeStage->finished_time = null;
            $remakeStage->works = $stageWorksIds;
            $remakeStage->started = null;
            $remakeStage->stopped = null;
            $remakeStage->ready_time = null;

            $remakeStage->save();

            $this->remakeStages[] = $remakeStage;
        }
    }

    private function remakeExtraPrices()
    {
        $additionalPrices = OrderAdditionalPrice::where('order_id', $this->order->id)->get();
        foreach($additionalPrices as $additionalPrice){
            $newExtraPrice = $additionalPrice->replicate();
            $newExtraPrice->order_id = $this->remake->id;
            $newExtraPrice->save();
        }
    }

    private function remakeFiles()
    {
        $orderFiles = $this->order->files ?? [];
        foreach($orderFiles as $file){
            $file->copy($this->remake, Order::ORDER_FILES_COLLECTION_NAME);
        }
    }

    private function remakeOrderDetails()
    {
       //todo implementing when order details are defined 04.10.2021
    }

    private function getNewWorkId($oldId)
    {
        return $this->workIds[$oldId] ?? $oldId;
    }

    public function saveRemakeIdOnOrder(): void
    {
        $this->order->remake_id = $this->remake->id;
        $this -> order -> save();
    }
}
