<?php


namespace App\Services;


use App\Exceptions\Api\ValidationException;
use App\Models\OrderWorkStage;
use App\Models\OrderWorkTemplate;
use App\Traits\Dentition;

class OrderWorkTemplateService
{
    use Dentition;
    static function updatePreferedDate(OrderWorkTemplate $orderWorkTemplate, $preferedDuration)
    {
        if ($orderWorkTemplate->min_duration > $preferedDuration) {
            throw new ValidationException(__('Prefered duration is lower then min duration.'));
        }
        if ($orderWorkTemplate->estimated_duration < $preferedDuration) {
            throw new ValidationException(__('Prefered duration is bigger then the estimated duration.'));
        }

        $orderWorkTemplate->preferred_duration = $preferedDuration;
        $orderWorkTemplate->save();

        //todo to be implemented when implementing calendar
//        CalendarLib::updateOrder($work->order_id);

        return OrderWorkStagesService::updateStagesDates($orderWorkTemplate->order_id, $orderWorkTemplate->id);
    }

    static function updateIgnoreExtraPrice(OrderWorkTemplate $orderWorkTemplate, $ignoreExtraPrice)
    {
        $orderWorkTemplate->ignore_extra_price = $ignoreExtraPrice;
        $orderWorkTemplate->save();

        return true;
    }

    public static function reorderStages($orderWorkId)
    {
        $stages = OrderWorkStage::where('order_work_template_id', $orderWorkId)->orderBy('rank')->orderByDesc('created_at')->orderByDesc(
            'id'
        )->get();

        $rank = 1;
        foreach ($stages as $key => $stage) {
            $stage->rank = $rank++;
            $stage->save();
        }
    }

    /**
     * @param  array  $workToReorder
     */
    public static function reorderStagesForOrderWorks(array $orderWorksIdsToReorder): void
    {
        \DB::transaction(function () use ($orderWorksIdsToReorder){
            foreach ($orderWorksIdsToReorder as $workId) {
                static::reorderStages($workId);
            }
        });

    }

    public static function remakeStages($workId, $stageId, array $parametersOfRemake, $throwException = false)
    {
        $existingStages = OrderWorkStage::where('order_work_template_id', $workId)->orderBy('rank')->get();

        $remakeStages = [];
        $startKey = 0;
        $stopKey = 0;

        foreach ($existingStages as $key => $stage) {
            if ($stage->id == $stageId) {
                $startKey = $key;
            }
            if ($stage->status !== 'finished' && $stopKey == 0) {
                $stopKey = $key;
            }
            if ($stage->status === 'working') {
                if ($throwException) {
                    throw new ValidationException(__('Remake is not possible. There is an ongoing stage.'));
                }
                return [
                    'error'   => true,
                    'message' => __('Remake is not possible. There is an ongoing stage.')
                ];
            }
        }

        $rank = 0;

        /* update orders and let room for new remake stages
            - if stopkey has been set, maybe we have finished all the stages
        */
        foreach ($existingStages as $key => $stage) {
            $stage->rank = $rank++;

            if ((!$stopKey || $key < $stopKey) && $key >= $startKey) {
                $remakeStages[] = $stage;
            }

            if ($key >= $stopKey && $stopKey) {
                $stage->status = 'not_ready';
                $stage->rank = $rank + sizeof($remakeStages) - 1;
            }
            $stage->save();
        }

        $existingStages = OrderWorkStage::where('order_work_template_id', $workId)->orderBy('rank')->get();

        $remakeRank = 0;
        // find order for adding
        foreach ($existingStages as $key => $stage) {
            if ($stage->status !== 'finished') {
                break;
            }
            $remakeRank = $stage->rank + 1;
        }

        $labIsPaying = $parametersOfRemake['lab_is_paying'];
        // find collaborator id
        $collaboratorId = 0;
        $userId = 0;
        if (!$labIsPaying){
            if($parametersOfRemake['reason']['fault']==='collaborator') {
                $order = $stage->order()->firstOrFail();
                $collaboratorId = $order->collaborator->id;
            }
            if ($parametersOfRemake['reason']['fault']==='user') {
                $userId = $parametersOfRemake['reason']['user_id'];
            }
        }

        foreach ($remakeStages as $stage) {
            $remakeStage = $stage->replicate();

            // update new stage
            $remakeStage->status = 'not_ready';
            $remakeStage->rank = $remakeRank++;
            $remakeStage->remake_id = 0;
            $remakeStage->collaborator_fault_id = 0;
            $remakeStage->user_fault_id = 0;
            $remakeStage->lab_paying = 0;
            $remakeStage->save();

            //
            $stage->collaborator_fault_id = $collaboratorId;
            $stage->user_fault_id = $userId;
            $stage->lab_paying = $labIsPaying;
            $stage->price = $stage->remake_price;

            $stage->remake_id = $remakeStage->id;
            $stage->save();
        }

        return true;
    }

    public static function updateCombination(OrderWorkTemplate $oldWork, OrderWorkTemplate $newWork): void
    {
        //last added work id is combination_id for all works that are part of combination
        OrderWorkTemplate::where('id', $oldWork->id)->orWhere('combination_id', $oldWork->id)->update(['combination_id' => $newWork->id]);

        if ($oldWork->estimated_duration > $newWork->estimated_duration) {
            $newWork->min_duration = $oldWork->min_duration;
            $newWork->estimated_duration = $oldWork->estimated_duration;
            $newWork->preferred_duration = $oldWork->preferred_duration;
            $newWork->extra_price = $oldWork->extra_price;
        }

        $newWork->name = $oldWork->name.' + '.$newWork->name;

        $newWork->save();
    }

    /**
     * Add to the new work  the combination dentition marked for can not change
     * @param  OrderWorkTemplate  $workTemplate
     * @param $dentition
     *
     * @throws ValidationException
     */
    public static function updateCombinationDentition(OrderWorkTemplate $workTemplate, $dentition): void
    {
        $dentition = (new self()) -> decodeDentition($dentition);
        foreach ($dentition as &$tooth) {
            if($tooth-> form !== 0){
                $propertyName = config('lab_configuration.default_name_for_dentition_tooth_can_be_modified');
                $tooth -> $propertyName = !(config('lab_configuration.default_value_for_dentition_tooth_can_be_modified'));
            }
        }
        unset($tooth);
        $workTemplate->dentition = (new self()) -> encodeObjectDentition($dentition);
        $workTemplate->save();
    }


    /**
     * @param  OrderWorkTemplate  $workTemplate
     * @param $arcadaDentition
     */
    public static function updateCombinationArcadaDentition(OrderWorkTemplate $workTemplate, $arcadaDentition): void
    {
        $workTemplate->arcada_dentition = $arcadaDentition;
        $workTemplate->save();
    }

    public static function moveStages(int $newWorkId, int $oldWorkId)
    {
        $newStages = OrderWorkStage::where('order_work_template_id', $newWorkId)->orderBy('rank')->get();

        $oldStages = OrderWorkStage::where('order_work_template_id', $oldWorkId)->orderBy('rank')->get();

        $duplicates = [];
        foreach ($oldStages as $stage) {
            // delete new work common stages wi
            foreach ($newStages as $nStage) {
                if ($stage->work_stage_id == $nStage->work_stage_id) {
                    $duplicates[] = $nStage->work_stage_id;
                    $nStage->delete();
                }
            }
        }

        $newStages = OrderWorkStage::where('order_work_template_id', $newWorkId)->orderBy('rank')->get();

        $rank = 0;
        foreach ($oldStages as $stage) {
            $stage->order_work_template_id = $newWorkId;
            $stage->rank = $rank++;

            if (in_array($stage->work_stage_id, $duplicates)) {
                $works = $stage->works;
                $works = json_decode($works);

                $works[] = $newWorkId;

                $stage->works = json_encode($works);
            }

            $stage->save();
        }

        foreach ($newStages as $stage) {
            $stage->rank = $rank++;
            $stage->save();
        }
    }

    /**
     * @param  OrderWorkTemplate  $orderWorkTemplate
     * @param  bool  $throwException
     *
     * @return bool
     * @throws ValidationException
     */
    public static function orderWorkCanBeCombined(OrderWorkTemplate $orderWorkTemplate, $throwException = true)
    {
        if ($orderWorkTemplate->combination_id !== 0) {
            if ($throwException) {
                throw new ValidationException(__('The order work is already part of a combination'));
            }
            return false;
        }

        return OrderService::orderIdCanBeUpdated($orderWorkTemplate->order_id,$throwException);
    }

}
