<?php


namespace App\Services;

use App\Exceptions\Api\AccessDeniedException;
use App\Exceptions\Api\ValidationException;
use App\Models\PaymentDocument;
use App\Models\Receipt;

class PaymentService
{
    /**
     * Check if a receipt can be issued.
     *
     * @param object $payment
     * @return boolean
     */
    public static function canIssueReceipt($payment)
    {
        if ($payment->type === 'cash' && !$payment->receipt_series && !$payment->receipt_no) {
            return true;
        }

        return false;
    }

    public static function canAddPayment(PaymentDocument $paymentDocument, $value, $throwException = false)
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
        }

        $canAdd = true;
        $errorMessage = __('validation.cant_add_payment');

        if ($paymentDocument->to_pay < $value) {
            $canAdd = false;
            $errorMessage = __('Valoarea platii depaseste restul de plata');
        }

        if ($throwException && !$canAdd) {
            throw new ValidationException($errorMessage);
        }
        return $canAdd;
    }

    public static function canRemovePayment($paymentId, $throwException = false)
    {
        if (!request()->user()->can(['payment_documents.update'])) {
            throw new AccessDeniedException(__('lang_permissions.payment_documents.update.missing.permission'));
        }

        $canRemove = true;
        $errorMessage = __('validation.cant_remove_payment');
        $receipts = Receipt::where('payment_id', $paymentId)->get();

        if (count($receipts) > 0) {
            $canRemove = false;
            $errorMessage = __('A fost deja emisa chitanta');
        }

        if ($throwException && !$canRemove) {
            throw new ValidationException($errorMessage);
        }
        return $canRemove;
    }
}
