<?php

/**
 * Created by PhpStorm.
 * User: Stefi
 * Date: 28/10/2021
 * Time: 10:05
 */

namespace App\Services;

use App\Models\Receipt;
use App\Models\ReceiptSeries;
use App\Models\Payment;
use App\Models\PaymentDocument;
use App\Models\Invoice;
use Carbon\Carbon;
use PDF;

class ReceiptService
{
    public static function verifyNoReceiptIssuedAfterSpecifiedDate($issueDate, $seriesId)
    {
        $verify = true;
        $receiptsIssued = Receipt::where('receipt_date', '>', $issueDate)->where('receipt_series_id', $seriesId)->get();
        if (count($receiptsIssued) > 0) {
            $verify = false;
        }
        return $verify;
    }

    public static function generateReceiptNumberBySeries($seriesId)
    {
        $receiptSeries = ReceiptSeries::findOrFail($seriesId);
        $no = $receiptSeries->start_no;
        $receipt = Receipt::where('receipt_series', $receiptSeries->series)
            ->where('receipt_series_id', $receiptSeries->id)
            ->orderBy('receipt_no', 'DESC')
            ->first();

        if (!is_null($receipt)) {
            $no = $receipt->receipt_no + 1;
        }

        return $no;
    }

    public static function generateReceipt(PaymentDocument $paymentDocument, $paymentId, int $seriesId, $issueDate)
    {
        $data = [];
        $payment = Payment::findOrFail($paymentId);
        $receiptSeries = ReceiptSeries::findOrFail($seriesId);
        $data['payment_id'] = $paymentId;
        $data['receipt_series_id'] = $seriesId;
        $data['receipt_series'] = $receiptSeries->series;
        $data['receipt_no'] = self::generateReceiptNumberBySeries($seriesId);
        $data['receipt_date'] = $issueDate;
        $data['invoice_id'] = $paymentDocument->invoice_id;
        $data['value'] = $payment->value;

        $receipt = Receipt::create($data);

        $payment->receipt_series = $receipt->receipt_series;
        $payment->receipt_no = $receipt->receipt_no;
        $payment->save();

        return $receipt;
    }

    public static function verifyValidValue($invoiceId, $paymentId)
    {
        $validValue = true;
        $totalReceiptsValue = Receipt::where('invoice_id', $invoiceId)->sum('value');
        $invoiceValue = Invoice::findOrFail($invoiceId);
        $paymentValue = Payment::findOrFail($paymentId);

        if (($totalReceiptsValue + $paymentValue->value) > $invoiceValue->value) {
            $validValue = false;
        }
        return $validValue;
    }

    /**
     * Attach invoice details to receipts.
     *
     * @param object $receipts
     * @param object $invoice
     * @return void
     */
    public static function attachInvoiceDetails(object $receipts, object $invoice): void
    {
        foreach ($receipts as $receipt) {
            $receipt->invoice_no = $invoice->invoice_no;
            $receipt->invoice_series = $invoice->invoice_series;
            $receipt->invoice_date = $invoice->invoice_date;
            $receipt->collaborator_name = $invoice->collaborator_name;
        }
    }

    /**
     * Generate receipt's PDF document.
     *
     * @param Receipt $receipt
     * @return object
     */
    public static function generateReceiptPdf(Receipt $receipt): object
    {
        $receiptDate = new Carbon($receipt->receipt_date);
        $invoiceDate = new Carbon($receipt->invoice_date);

        $pdf = PDF::loadView('pdf.receipt', [
            'receipt'       => $receipt,
            'receiptDate'   => $receiptDate->format('d.m.Y'),
            'invoiceDate'   => $invoiceDate->format('d.m.Y'),
        ]);

        return $pdf;
    }
}
