<?php


namespace App\Services\Reports;

use App\Models\OrderWorkStage;
use App\Models\User;
use Illuminate\Support\Facades\DB;

class AssignedStagesChartService
{
    /**
     * Calculate the user's assigned order work stages total.
     *
     * @param User $user
     * @param integer $numberOfMonths
     * @return object
     */
    public static function calculateUserTotalPerOrderWorkStage(User $user): object
    {

        return OrderWorkStage::select(
            'work_stage_id as id',
            DB::raw('ROUND(SUM(cost * multi_factor), 2) as value'),
            DB::raw('SUM(multi_factor) as multi_factor'),
            DB::raw('MIN(name) as name')
        )
            ->whereNull('finished_time')
            ->where('user_id', $user->id)
            ->groupBy('work_stage_id')
            ->orderBy('value', 'DESC')
            ->whereRaw('( cost * multi_factor ) > 0')
            ->get();
    }
}
