<?php

namespace App\Services\Reports;

use App\Exceptions\Api\AccessDeniedException;
use App\Models\Order;
use App\Models\OrderDiscount;
use App\Services\OrderDiscountService;
use App\Services\PaymentDocumentService;
use Carbon\Carbon;

class OrderDiscountsService
{

    /**
     * @param  Order  $order
     * @param  array  $paymentParameters
     *
     * @return Order
     * @throws AccessDeniedException
     */
    public static function addDiscountForOrder(Order $order, array $paymentParameters): Order
    {
        $order->loadMissing(['payment_document']);
        $paymentParameters['order_id'] = $order->id;
        if ($order->payment_document !== null) {
            $paymentParameters['payment_id'] = $order->id;
            PaymentDocumentService::addDiscount($order->payment_document, $paymentParameters);
        } else {
            OrderDiscountService::addDiscount($order, $paymentParameters);
        }
        return $order;
    }

    public static function deleteDiscountForOrder(Order $order, int $discountId)
    {
        $order->loadMissing('payment_document.discounts', 'order_discounts');
        if ($order->payment_document !== null) {
            PaymentDocumentService::deleteDiscount($order->payment_document, $discountId);
        } else {
            OrderDiscountService::deleteDiscount($order, $discountId);
        }

        return response([], 204);
    }

    /**
     * Move discounts to order discounts.
     *
     * @param Order $order
     * @return void
     */
    public static function moveDiscountsToOrderDiscounts(Order $order)
    {
        $discounts      = $order->discounts();
        $getDiscounts   = $discounts->get();

        if (!$getDiscounts->isEmpty()) {
            foreach ($getDiscounts as $discount) {
                $discountsArray[] = [
                    'discount_type_id'      => $discount->discount_type_id,
                    'order_id'              => $discount->order_id,
                    'name'                  => $discount->name,
                    'value'                 => $discount->value,
                    'created_at'            => Carbon::now()->toDateTimeString(),
                    'updated_at'            => Carbon::now()->toDateTimeString(),
                ];
            }

            OrderDiscount::insert($discountsArray);
            $discounts->delete();
        }
    }
}
