<?php

namespace App\Services\Reports;

use App\Models\Order;
use App\Models\OrderPayment;
use App\Services\OrderPaymentService;
use App\Services\PaymentDocumentService;

class OrderPaymentsService
{

    public static function addPaymentForOrder(Order $order, array $paymentParameters)
    {

        $order->loadMissing(['payment_document', 'order_payments']);
        $paymentParameters['order_id'] = $order->id;
        if ($order->payment_document !== null) {
            $paymentParameters['payment_id'] = $order->id;
            PaymentDocumentService::addPayment($order->payment_document, $paymentParameters);
        } else {
            OrderPaymentService::addPayment($order, $paymentParameters);
        }

        return $order;
    }

    /**
     * Delete payment for order.
     *
     * @param Order $order
     * @param integer $paymentId
     */
    public static function deletePaymentForOrder(Order $order, int $paymentId)
    {
        $order->loadMissing(['payment_document.payments', 'order_payments']);

        if ($order->payment_document !== null) {
            PaymentDocumentService::deletePayment($order->payment_document, $paymentId);
        } else {
            OrderPaymentService::deletePayment($order, $paymentId);
        }

        return response([], 204);
    }

    /**
     * Move payments to order payments.
     *
     * @param Order $order
     * @return void
     */
    public static function movePaymentsToOrderPayments(Order $order)
    {
        $payments       = $order->payments();
        $getPayments    = $payments->get();

        if (!$getPayments->isEmpty()) {
            foreach ($getPayments as $payment) {
                $paymentsArray[] = [
                    'order_id'  => $payment->order_id,
                    'name'      => $payment->name,
                    'value'     => $payment->value,
                    'date'      => $payment->date,
                    'type'      => $payment->type,
                ];
            }

            OrderPayment::insert($paymentsArray);
            $payments->delete();
        }
    }
}
