<?php


namespace App\Services\Reports;

use App\Models\Collaborator;
use App\Models\Order;
use Carbon\Carbon;
use Illuminate\Database\Query\Builder;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;

class OrdersChartService
{
    /**
     * Calculate total value per month.
     *
     * @param Collaborator $collaborator
     * @return Builder
     */
    public static function calculateTotalValuePerMonth(Collaborator $collaborator): Builder
    {
        $tempTable = DB::table('temp_table')
            ->select(
                DB::raw('DATE_FORMAT(`temp_table`.`date`, "%Y-%m") month'),
                DB::raw('IFNULL(orders.value, "0") value')
            );

        $orders = Order::select(DB::raw("DATE_FORMAT(start_date, '%Y-%m') start_date, SUM(temp_value) value"))
            ->where('orders.deleted_at', null)
            ->where('status', '<>', DB::raw("'config'"))
            ->groupBy(DB::raw("DATE_FORMAT(start_date, '%Y-%m')"));

        if ($collaborator->id !== null) {
            $orders->where('collaborator_id', DB::raw("'" . (int)$collaborator->id . "'"));
        }

        $tempTable->leftJoin(DB::raw('(' . $orders->toSql()
            . ') orders'), 'orders.start_date', DB::raw('DATE_FORMAT(`temp_table`.`date`, "%Y-%m")'))
            ->orderBy('temp_table.date');

        return $tempTable;
    }

    /**
     * Calculate collaborator's total for orders chart modal.
     *
     * @param integer $numberOfMonths
     * @return Collection
     */
    public static function calculateOrdersChartCollaboratorsTotal(int $numberOfMonths): Collection
    {
        $endOfCurrentMonth = Carbon::now()->endOfMonth()->format('Y-m-d');
        $startDate = Carbon::now()->addMonth(-$numberOfMonths)->format('Y-m-d');

        return DB::table('orders')
            ->select(
                'orders.collaborator_id as id',
                'collaborators.name as name',
                DB::raw('sum(orders.temp_value) as value'),
            )
            ->leftJoin(
                'collaborators',
                'orders.collaborator_id',
                '=',
                'collaborators.id',
            )
            ->where('orders.deleted_at', null)
            ->where('collaborators.deleted_at', null)
            ->where('orders.status', '<>', 'config')
            ->whereBetween('orders.start_date', [$startDate, $endOfCurrentMonth])
            ->groupBy('orders.collaborator_id')
            ->orderBy('value', 'desc')
            ->get()
            ->where('value', '<>', 0);
    }
}
