<?php


namespace App\Services\Reports;

use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;

class TopDebtorsChartService
{
    /**
     * List work templates with preferential & locked prices.
     *
     * @return void
     */
    public static function getDebtorsNamesAndValues()
    {
        return DB::select(
            DB::raw('SELECT collaborator_id,
                            collaborators.name,
                            pd_id,
                            Sum(total_to_pay) AS value
                    FROM   (SELECT inv.collaborator_id,
                                    inv.invoice_series_id,
                                    inv.invoice_no,
                                    inv.value,
                                    pd.id                               AS pd_id,
                                    pd.invoice_id,
                                    payments.payment_document_id,
                                    Coalesce(payments.total, 0)         AS total_payed,
                                    value - Coalesce(payments.total, 0) AS total_to_pay
                            FROM   `invoices` AS inv
                                    LEFT JOIN payment_documents AS pd
                                        ON inv.id = pd.invoice_id
                                    LEFT JOIN (SELECT payment_document_id,
                                                      Sum(value) AS total 
                                                FROM   payments
                                                WHERE deleted_at IS NULL
                                                GROUP  BY payment_document_id) AS payments
                                            ON payments.payment_document_id = pd.id) AS payment_status
                            LEFT JOIN collaborators
                                    ON payment_status.collaborator_id = collaborators.id
                    GROUP  BY collaborator_id
                    ORDER  BY value DESC; 
            ')
        );
    }

    /**
     * Calculate the total value of the other debtors.
     *
     * @param Collection $collaborators
     * @param integer $debtorsNumber
     * @return array
     */
    public static function calculateOtherDebtorsTotal(Collection $collaborators, int $debtorsNumber): array
    {
        $i = 0;
        $rest = 0;

        $collaborators = $collaborators->filter(function ($collaborator) use (&$i, &$rest, $debtorsNumber) {
            if ($i >= $debtorsNumber) {
                $rest += $collaborator->value;
            }
            if ($collaborator->value > 0 && $i++ < $debtorsNumber)
                return 1;
            return 0;
        })->all();

        $collaborators[] = ['name' => 'Restul', 'total' => $rest];

        return $collaborators;
    }
}
