<?php


namespace App\Services\Reports;

use Carbon\CarbonPeriod;
use Illuminate\Support\Collection;
use stdClass;

class TrialStagesChartService
{

    /**
     * Generates total, trial, external & others fields.
     *
     * @param Collection $workStages
     * @param string $startDate
     * @param string $endDate
     * @return Collection
     */
    public static function generateChartDates(Collection $workStages, string $startDate, string $endDate): Collection
    {
        foreach ($workStages as $workStage) {
            $workStage->total = $workStages->where('date', $workStage->date)
                ->count() ?? 0;
            $workStage->trial = $workStages->where('date', $workStage->date)
                ->where('type', 'trial')
                ->count() ?? 0;
            $workStage->external = $workStages->where('date', $workStage->date)
                ->where('type', 'external')
                ->count() ?? 0;
            $workStage->others = $workStages->where('date', $workStage->date)
                ->where('type', '!=', 'trial')
                ->where('type', '!=', 'external')
                ->count() ?? 0;
        }
        $intervalDatesWithDefaultValues = self::generateIntervalDatesWithDefaultValues($startDate, $endDate, $workStages);

        return collect($intervalDatesWithDefaultValues->merge($workStages->unique('date'))->sortBy('date')->all());
    }

    /**
     * Generate interval dates with default values if work stages dates are not provided.
     *
     * @param string $startDate
     * @param string $endDate
     * @param Collection $workStages
     * @return Collection
     */
    public static function generateIntervalDatesWithDefaultValues(string $startDate, string $endDate, Collection $workStages): Collection
    {
        $period = CarbonPeriod::create($startDate, $endDate);
        $workStagesDates = $workStages->pluck('date')->all();
        $dates = [];

        foreach ($period as $date) {
            $date = $date->format('Y-m-d');
            if (!in_array($date, $workStagesDates)) {
                $dateOfInterval = new stdClass();
                $dateOfInterval->date = $date;
                $dateOfInterval->total = 0;
                $dateOfInterval->trial = 0;
                $dateOfInterval->external = 0;
                $dateOfInterval->others = 0;
        
                $dates[] = $dateOfInterval;
        
                unset($dateOfInterval);
            }
        }

        return collect($dates);
    }
}
