<?php


namespace App\Services\Reports;

use App\Models\Order;
use App\Models\WorkTemplate;
use Carbon\Carbon;
use Illuminate\Database\Query\Builder;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;

class WorksChartService
{
    /**
     * Calculate total value per month.
     *
     * @param WorkTemplate $workTemplate
     * @return Builder
     */
    public static function calculateTotalValuePerMonth(WorkTemplate $workTemplate): Builder
    {
        $tempTable = DB::table('temp_table')
            ->select(
                DB::raw('DATE_FORMAT(`temp_table`.`date`, "%Y-%m") month'),
                DB::raw('IFNULL(orders.orders, 0) orders')
            );

        $orders = Order::select(DB::raw("DATE_FORMAT(start_date, '%Y-%m') start_date, COUNT(order_work_templates.work_template_id) orders"))
            ->leftJoin('order_work_templates', 'orders.id', 'order_work_templates.order_id')
            ->where('orders.deleted_at', null)
            ->where('order_work_templates.deleted_at', null)
            ->where('status', '<>', DB::raw("'config'"))
            ->groupBy(DB::raw("DATE_FORMAT(start_date, '%Y-%m')"));

        if ($workTemplate->id !== null) {
            $orders->where('work_template_id', DB::raw("'" . (int)$workTemplate->id . "'"));
        }

        $tempTable->leftJoin(DB::raw('(' . $orders->toSql()
            . ') orders'), 'orders.start_date', DB::raw('DATE_FORMAT(`temp_table`.`date`, "%Y-%m")'))
            ->orderBy('temp_table.date');

        return $tempTable;
    }

    /**
     * Calculate collaborator's total for works chart.
     *
     * @param integer $numberOfMonths
     * @return Collection
     */
    public static function calculateWorksChartOrdersTotal(int $numberOfMonths)
    {
        $startDate = Carbon::now()->addMonth(-$numberOfMonths)->format('Y-m-d');

        return DB::select(DB::raw("
            SELECT  `order_work_templates`.`work_template_id` AS `id`,
                    `order_work_templates`.`name` AS `name`,
                    count(order_work_templates.work_template_id) AS value
            FROM `orders`
            LEFT JOIN `order_work_templates` ON `orders`.`id` = `order_work_templates`.`order_id`
            WHERE `orders`.`status` <> 'config'
                AND `orders`.`deleted_at` IS NULL
                AND `order_work_templates`.`deleted_at` IS NULL
                AND `orders`.`start_date` BETWEEN {$startDate} AND LAST_DAY(NOW())
            GROUP BY `order_work_templates`.`work_template_id`
            HAVING value <> 0
            ORDER BY `value` DESC;
        "));
    }
}
