<?php


namespace App\Services;

use App\Exceptions\Api\ServerError;
use App\Exceptions\Api\ValidationException;
use Illuminate\Http\UploadedFile;
use Spatie\MediaLibrary\HasMedia;

class UploadService
{

    //filesystem for files that need to be public (accessed by http link)
    public const PUBLIC_UPLOAD_PATH = 'tenants_public_files';
    //filesystem for files that should be downloaded only by user that have permission
    public const PRIVATE_UPLOAD_PATH = 'tenants_hidden_files';

    public function saveFile(HasMedia $model, $file, string $collectionName, $diskName, $customFileName = null)
    {
        if (!is_object($file) || get_class($file) !== UploadedFile::class) {
            throw new ValidationException(__('Please upload a file'));
        }

        try {
            if ($customFileName !== null) {
                $fileName = $customFileName . '.' . $file->guessExtension();
            } else {
                $fileName = $file->hashName();
            }

            $media = $model->addMedia($file->getPathName()); //starting method
            $media->sanitizingFileName(
                function ($fileName) {
                    return strtolower(str_replace(['#', '/', '\\', ' '], '-', $fileName));
                }
            );
            $media->setFileName($fileName)->withCustomProperties(['mime-type' => $file->getMimeType()]) //middle
                ->toMediaCollection($collectionName, $diskName); //finishing method
            return $fileName;
        } catch (\Throwable $e) {
            throw new ServerError(__('Could not upload file') . " -> " . $e->getMessage());
        }
    }
}
