<?php

namespace App\Services;

use App\Exceptions\Api\PossibleUnSyncException;
use App\Http\Resources\OrderWorkStageResource;
use App\Models\Order;
use App\Models\OrderWorkStage;
use App\Models\WorkTemplateStage;
use Illuminate\Http\Request;

class UserSkipService
{
    private $stage;
    private $order;
    private $user; // logged in user
    private $availableUsers;

    function __construct(OrderWorkStage $orderWorkStage)
    {
        $this->user = auth()->user();
        $this->stage = $orderWorkStage;
        $this->order = Order::where('id', $this->stage->order_id)->where('orders.status', '<>', 'config')->joinFirstAvailableStage()
            ->firstOrFail();
        $this->setAvailableUsers();
    }

    public static function skipStageUser(Request $request, OrderWorkStage $orderWorkStage)
    {
        $userSkipService = new self($orderWorkStage);
        UserService::userCanSkipStage($userSkipService->user, $orderWorkStage);

        if (!$userSkipService->checkIfFirstStage()) {
            throw new PossibleUnSyncException(__('Can not skip a order work stage that is not the first'));
        }

        if (empty($userSkipService->availableUsers)) {
            throw new PossibleUnSyncException(__('No default users assigned on this order work stage'));
        }

        $nextUser = $userSkipService->getNextUser();
        // everything set, let's update
        $userSkipService->setNewUser($nextUser);
        $userSkipService->stage->refresh();
        return response(['message' => __('Order work stage successfully skipped')]);
    }

    public function setAvailableUsers(): void
    {
        $this->availableUsers = $this->getStagesFromConfig();;
    }

    /**
     * @return bool
     */
    private function checkIfFirstStage(): bool
    {
        return $this->stage->id === $this->order->stage_id;
    }

    /**
     * @return mixed
     */
    private function getStagesFromConfig()
    {
        return WorkTemplateStage::where('work_template_id', $this->stage->work_template_id)->where(
            'work_stage_id',
            $this->stage->work_stage_id
        )->firstOrFail()->users()->select(
            'users.id as id',
            'work_template_stage_users.price as price',
            \DB::raw('CONCAT_WS(" ", users.first_name, users.last_name) as name')
        )->orderBy('work_template_stage_users.rank')->orderBy('work_template_stage_users.id', 'DESC')->get()->toArray();
    }

    private function getNextUser()
    {
        $startSearching = false;
        // if no user to skip will get the first user available
        $skipToUser = $this->availableUsers[0];
        foreach ($this->availableUsers as $user) {
            if (!$startSearching) {
                if ($this->stage->user_id == $user['pivot']['user_id']) {
                    $startSearching = true;
                    continue;
                }
            }
            $skipToUser = $user;
        }

        return $skipToUser;
    }

    private function setNewUser($user)
    {
        $this->stage->user_id = $user['id'];
        $this->stage->user_name = $user['name'];
        $this->stage->cost = $user['price'];
        $this->stage->save();
    }
}
