# Colaboratori

APIs for managing collaborators

## Import collaborator&#039;s data from Openapi

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/import-collaborator" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"cui":"ad"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/import-collaborator"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "cui": "ad"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-collaborators-import-collaborator" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-collaborators-import-collaborator"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-collaborators-import-collaborator"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-collaborators-import-collaborator" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-collaborators-import-collaborator"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-collaborators-import-collaborator" data-method="POST" data-path="api/v1/ro/collaborators/import-collaborator" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-collaborators-import-collaborator', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-collaborators-import-collaborator" onclick="tryItOut('POSTapi-v1-ro-collaborators-import-collaborator');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-collaborators-import-collaborator" onclick="cancelTryOut('POSTapi-v1-ro-collaborators-import-collaborator');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-collaborators-import-collaborator" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/collaborators/import-collaborator</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-collaborators-import-collaborator" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-collaborators-import-collaborator" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>cui</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="cui" data-endpoint="POSTapi-v1-ro-collaborators-import-collaborator" data-component="body" required  hidden>
<br>

</p>

</form>


## Collaborators listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/collaborators?sort=-id%2Clast_name" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators"
);

let params = {
    "sort": "-id,last_name",
};
Object.keys(params)
    .forEach(key => url.searchParams.append(key, params[key]));

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 266,
            "name": "Chis Group",
            "cui": 12345678,
            "nr_reg_comertului": "3071018354674",
            "bank": "Banca Transilvania",
            "region_id": 25,
            "region": "Ialomița",
            "bank_account": "RO65JQKAI387J0UUY0SUSU02",
            "address": "B-dul. Croitorilor 9\/6, Măcin, Olt, CP 510817",
            "city": "Tecuci",
            "phone_fax": "0362580450",
            "mobile": "0795564943",
            "contact_mobile": "0727450736",
            "email": "cosmin52@example.com",
            "website": "tudor.com"
        },
        {
            "id": 267,
            "name": "Szabo, Nastase and Cosma",
            "cui": 12345678,
            "nr_reg_comertului": "4591116025046",
            "bank": "Banca Transilvania",
            "region_id": 26,
            "region": "Iași",
            "bank_account": "RO73QZZB20T6YZ637302MPHD",
            "address": "P-ța Învățătorului 801, Deta, Vâlcea, CP 279527",
            "city": "Vicovu de Sus",
            "phone_fax": "0244240996",
            "mobile": "0317544094",
            "contact_mobile": "0259047258",
            "email": "aleodor.horvath@example.org",
            "website": "mirea.biz"
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-collaborators" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-collaborators"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-collaborators"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-collaborators" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-collaborators"></code></pre>
</div>
<form id="form-GETapi-v1-ro-collaborators" data-method="GET" data-path="api/v1/ro/collaborators" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-collaborators', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-collaborators" onclick="tryItOut('GETapi-v1-ro-collaborators');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-collaborators" onclick="cancelTryOut('GETapi-v1-ro-collaborators');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-collaborators" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/collaborators</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-collaborators" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-collaborators" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Query Parameters</b></h4>
<p>
<b><code>sort</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="sort" data-endpoint="GETapi-v1-ro-collaborators" data-component="query"  hidden>
<br>
Field to sort by. Sorting ASC id Sorting DESC -id
</p>
<p>
<b><code>filter[dentists.last_name]</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filter[dentists.last_name]" data-endpoint="GETapi-v1-ro-collaborators" data-component="query"  hidden>
<br>
Field to filter by dentist id and/or last_name.
</p>
</form>


## Store a newly created collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/collaborators" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"dolore","cui":{},"nr_reg_comertului":{},"bank":"omnis","bank_account":"quibusdam","address":"rerum","region_id":17,"city":"tempore","phone_fax":"fugit","mobile":"dicta","contact_mobile":"suscipit","email":"jonathan.mcglynn@example.net","website":"http:\/\/abbott.org\/pariatur-veniam-repellat-cupiditate"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "dolore",
    "cui": {},
    "nr_reg_comertului": {},
    "bank": "omnis",
    "bank_account": "quibusdam",
    "address": "rerum",
    "region_id": 17,
    "city": "tempore",
    "phone_fax": "fugit",
    "mobile": "dicta",
    "contact_mobile": "suscipit",
    "email": "jonathan.mcglynn@example.net",
    "website": "http:\/\/abbott.org\/pariatur-veniam-repellat-cupiditate"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 268,
        "name": "Negoita Inc",
        "cui": 12345678,
        "nr_reg_comertului": "2530227277238",
        "bank": "Banca Transilvania",
        "region_id": 25,
        "region": "Ialomița",
        "bank_account": "RO04HNBC1P8WBHWM00X4O378",
        "address": "Splaiul Mihai Viteazul nr. 4, bl. A, sc. C, et. 89, ap. 3, Mun. Solca, Caraș-Severin, CP 825715",
        "city": "Pantelimon",
        "phone_fax": "0718084997",
        "mobile": "0724532763",
        "contact_mobile": "0765441593",
        "email": "razvan.mateescu@example.org",
        "website": "ungureanu.net"
    }
}
```
<div id="execution-results-POSTapi-v1-ro-collaborators" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-collaborators"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-collaborators"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-collaborators" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-collaborators"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-collaborators" data-method="POST" data-path="api/v1/ro/collaborators" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-collaborators', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-collaborators" onclick="tryItOut('POSTapi-v1-ro-collaborators');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-collaborators" onclick="cancelTryOut('POSTapi-v1-ro-collaborators');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-collaborators" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/collaborators</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-collaborators" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-collaborators" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cui</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="cui" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>nr_reg_comertului</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="nr_reg_comertului" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>bank</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="bank" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>bank_account</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="bank_account" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>region_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="region_id" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>city</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="city" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>contact_mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="contact_mobile" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>website</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="website" data-endpoint="POSTapi-v1-ro-collaborators" data-component="body"  hidden>
<br>
The value must be a valid URL.
</p>

</form>


## Display a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/collaborators/10" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/10"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 269,
        "name": "Damian, Vlad and Marcu",
        "cui": 12345678,
        "nr_reg_comertului": "1110509440488",
        "bank": "Banca Transilvania",
        "region_id": 37,
        "region": "Suceava",
        "bank_account": "RO54DAXC7U5570267O33W032",
        "address": "Str. Herculane 3, Rovinari, Timiș, CP 897527",
        "city": "Mun. Țăndărei",
        "phone_fax": "0766064358",
        "mobile": "0333754823",
        "contact_mobile": "0377732966",
        "email": "roxana27@example.net",
        "website": "oltean.com"
    }
}
```
<div id="execution-results-GETapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-collaborators--collaborator-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-collaborators--collaborator-" data-method="GET" data-path="api/v1/ro/collaborators/{collaborator}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-collaborators--collaborator-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-collaborators--collaborator-" onclick="tryItOut('GETapi-v1-ro-collaborators--collaborator-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-collaborators--collaborator-" onclick="cancelTryOut('GETapi-v1-ro-collaborators--collaborator-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-collaborators--collaborator-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/collaborators/{collaborator}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-collaborators--collaborator-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-collaborators--collaborator-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>collaborator</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="collaborator" data-endpoint="GETapi-v1-ro-collaborators--collaborator-" data-component="url"  hidden>
<br>

</p>
</form>


## Update  a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/atque" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"earum","cui":{},"nr_reg_comertului":{},"bank":"deserunt","bank_account":"qui","address":"esse","region_id":5,"city":"soluta","phone_fax":"sed","mobile":"enim","contact_mobile":"ut","email":"paucek.sean@example.net","website":"http:\/\/thompson.net\/"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/atque"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "earum",
    "cui": {},
    "nr_reg_comertului": {},
    "bank": "deserunt",
    "bank_account": "qui",
    "address": "esse",
    "region_id": 5,
    "city": "soluta",
    "phone_fax": "sed",
    "mobile": "enim",
    "contact_mobile": "ut",
    "email": "paucek.sean@example.net",
    "website": "http:\/\/thompson.net\/"
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 270,
        "name": "Balint-Munteanu",
        "cui": 12345678,
        "nr_reg_comertului": "5240402105551",
        "bank": "Banca Transilvania",
        "region_id": 27,
        "region": "Ilfov",
        "bank_account": "RO46LQHASLY3V6F3HF6I87N7",
        "address": "Calea Vlad Țepeș nr. 6\/5, bl. D, et. 2, ap. 0, Curtea de Argeș, Cluj, CP 155482",
        "city": "Băile Olănești",
        "phone_fax": "0773373842",
        "mobile": "0714338139",
        "contact_mobile": "0781556731",
        "email": "bradut74@example.org",
        "website": "stoica.com"
    }
}
```
<div id="execution-results-PUTapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-collaborators--collaborator-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-collaborators--collaborator-" data-method="PUT" data-path="api/v1/ro/collaborators/{collaborator}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-collaborators--collaborator-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-collaborators--collaborator-" onclick="tryItOut('PUTapi-v1-ro-collaborators--collaborator-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-collaborators--collaborator-" onclick="cancelTryOut('PUTapi-v1-ro-collaborators--collaborator-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-collaborators--collaborator-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/collaborators/{collaborator}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/collaborators/{collaborator}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-collaborators--collaborator-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>collaborator</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="collaborator" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cui</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="cui" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>nr_reg_comertului</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="nr_reg_comertului" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>bank</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="bank" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>bank_account</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="bank_account" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>region_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="region_id" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>city</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="city" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>contact_mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="contact_mobile" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>website</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="website" data-endpoint="PUTapi-v1-ro-collaborators--collaborator-" data-component="body"  hidden>
<br>
The value must be a valid URL.
</p>

</form>


## Remove  a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/11" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborators/11"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-collaborators--collaborator-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-collaborators--collaborator-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-collaborators--collaborator-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-collaborators--collaborator-" data-method="DELETE" data-path="api/v1/ro/collaborators/{collaborator}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-collaborators--collaborator-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-collaborators--collaborator-" onclick="tryItOut('DELETEapi-v1-ro-collaborators--collaborator-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-collaborators--collaborator-" onclick="cancelTryOut('DELETEapi-v1-ro-collaborators--collaborator-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-collaborators--collaborator-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/collaborators/{collaborator}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-collaborators--collaborator-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-collaborators--collaborator-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>collaborator</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator" data-endpoint="DELETEapi-v1-ro-collaborators--collaborator-" data-component="url" required  hidden>
<br>

</p>
</form>


## CP List of prices for a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices-listing" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"collaborator_id":7,"work_template_id":14}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices-listing"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "collaborator_id": 7,
    "work_template_id": 14
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-collaborator-prices-listing" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-collaborator-prices-listing"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-collaborator-prices-listing"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-collaborator-prices-listing" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-collaborator-prices-listing"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-collaborator-prices-listing" data-method="POST" data-path="api/v1/ro/collaborator-prices-listing" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-collaborator-prices-listing', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-collaborator-prices-listing" onclick="tryItOut('POSTapi-v1-ro-collaborator-prices-listing');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-collaborator-prices-listing" onclick="cancelTryOut('POSTapi-v1-ro-collaborator-prices-listing');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-collaborator-prices-listing" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/collaborator-prices-listing</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-collaborator-prices-listing" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-collaborator-prices-listing" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="POSTapi-v1-ro-collaborator-prices-listing" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="work_template_id" data-endpoint="POSTapi-v1-ro-collaborator-prices-listing" data-component="body"  hidden>
<br>

</p>

</form>


## CP Add/update  a price to a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"collaborator_id":12,"work_template_id":15,"price":11,"locked":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "collaborator_id": 12,
    "work_template_id": 15,
    "price": 11,
    "locked": false
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-PUTapi-v1-ro-collaborator-prices" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-collaborator-prices"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-collaborator-prices"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-collaborator-prices" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-collaborator-prices"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-collaborator-prices" data-method="PUT" data-path="api/v1/ro/collaborator-prices" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-collaborator-prices', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-collaborator-prices" onclick="tryItOut('PUTapi-v1-ro-collaborator-prices');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-collaborator-prices" onclick="cancelTryOut('PUTapi-v1-ro-collaborator-prices');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-collaborator-prices" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/collaborator-prices</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-collaborator-prices" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template_id" data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>price</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="price" data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>locked</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-collaborator-prices" hidden><input type="radio" name="locked" value="true" data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-collaborator-prices" hidden><input type="radio" name="locked" value="false" data-endpoint="PUTapi-v1-ro-collaborator-prices" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## CP Delete  a price to a collaborator.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"collaborator_id":13,"work_template_id":10}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/collaborator-prices"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "collaborator_id": 13,
    "work_template_id": 10
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-collaborator-prices" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-collaborator-prices"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-collaborator-prices"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-collaborator-prices" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-collaborator-prices"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-collaborator-prices" data-method="DELETE" data-path="api/v1/ro/collaborator-prices" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-collaborator-prices', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-collaborator-prices" onclick="tryItOut('DELETEapi-v1-ro-collaborator-prices');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-collaborator-prices" onclick="cancelTryOut('DELETEapi-v1-ro-collaborator-prices');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-collaborator-prices" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/collaborator-prices</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-collaborator-prices" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-collaborator-prices" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="DELETEapi-v1-ro-collaborator-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template_id" data-endpoint="DELETEapi-v1-ro-collaborator-prices" data-component="body" required  hidden>
<br>

</p>

</form>



