# Comenzi plati

APIs for managing order additional prices

## Add payment for order

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/order-payments/nemo" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"type":"cash","name":"ducimus","value":27.3061315,"order_id":20,"date":"2022-01-12"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/order-payments/nemo"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "type": "cash",
    "name": "ducimus",
    "value": 27.3061315,
    "order_id": 20,
    "date": "2022-01-12"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-order-payments--order-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-order-payments--order-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-order-payments--order-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-order-payments--order-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-order-payments--order-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-order-payments--order-" data-method="POST" data-path="api/v1/ro/order-payments/{order}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-order-payments--order-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-order-payments--order-" onclick="tryItOut('POSTapi-v1-ro-order-payments--order-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-order-payments--order-" onclick="cancelTryOut('POSTapi-v1-ro-order-payments--order-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-order-payments--order-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/order-payments/{order}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-order-payments--order-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>order</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="order" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="type" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="body" required  hidden>
<br>
The value must be one of <code>cash</code> or <code>op</code>.
</p>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>value</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="value" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>order_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="order_id" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>date</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="date" data-endpoint="POSTapi-v1-ro-order-payments--order-" data-component="body" required  hidden>
<br>
The value must be a valid date in the format Y-m-d.
</p>

</form>


## Delete payment of the order

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/order-payments/et/et" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/order-payments/et/et"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (404):

```json
{
    "message": "Resursa nu a fost gasita \/ nu exista"
}
```
<div id="execution-results-DELETEapi-v1-ro-order-payments--order---paymentId-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-order-payments--order---paymentId-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-order-payments--order---paymentId-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-order-payments--order---paymentId-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-order-payments--order---paymentId-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-order-payments--order---paymentId-" data-method="DELETE" data-path="api/v1/ro/order-payments/{order}/{paymentId}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-order-payments--order---paymentId-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-order-payments--order---paymentId-" onclick="tryItOut('DELETEapi-v1-ro-order-payments--order---paymentId-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-order-payments--order---paymentId-" onclick="cancelTryOut('DELETEapi-v1-ro-order-payments--order---paymentId-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-order-payments--order---paymentId-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/order-payments/{order}/{paymentId}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-order-payments--order---paymentId-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-order-payments--order---paymentId-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>order</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="order" data-endpoint="DELETEapi-v1-ro-order-payments--order---paymentId-" data-component="url" required  hidden>
<br>

</p>
<p>
<b><code>paymentId</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="paymentId" data-endpoint="DELETEapi-v1-ro-order-payments--order---paymentId-" data-component="url" required  hidden>
<br>

</p>
</form>



