# Dentisti

APIs for managing Dentists

## Dentists listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/dentists?sort=-id%2Cfirst_name%2Clast_name" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentists"
);

let params = {
    "sort": "-id,first_name,last_name",
};
Object.keys(params)
    .forEach(key => url.searchParams.append(key, params[key]));

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 266,
            "first_name": "Ștefana",
            "last_name": "Serban",
            "cnp": "1741013149442",
            "phone_fax": "0712387540",
            "email": "xenia.mihai@example.org"
        },
        {
            "id": 267,
            "first_name": "Anghel",
            "last_name": "Ionescu",
            "cnp": "3290309460456",
            "phone_fax": "0779239342",
            "email": "david21@example.net"
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-dentists" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-dentists"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-dentists"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-dentists" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-dentists"></code></pre>
</div>
<form id="form-GETapi-v1-ro-dentists" data-method="GET" data-path="api/v1/ro/dentists" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-dentists', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-dentists" onclick="tryItOut('GETapi-v1-ro-dentists');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-dentists" onclick="cancelTryOut('GETapi-v1-ro-dentists');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-dentists" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/dentists</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-dentists" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-dentists" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Query Parameters</b></h4>
<p>
<b><code>sort</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="sort" data-endpoint="GETapi-v1-ro-dentists" data-component="query"  hidden>
<br>
Field to sort by. Sorting ASC id Sorting DESC -id
</p>
<p>
<b><code>filter[collaborators.name]</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filter[collaborators.name]" data-endpoint="GETapi-v1-ro-dentists" data-component="query"  hidden>
<br>
Field to filter by collaborator id and/or name.
</p>
</form>


## Store a newly created dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/dentists" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"first_name":"debitis","last_name":"et","cnp":32865.18107674,"email":"mkrajcik@example.net","phone_fax":"veniam","collaborator_id":15,"order":{}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentists"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "first_name": "debitis",
    "last_name": "et",
    "cnp": 32865.18107674,
    "email": "mkrajcik@example.net",
    "phone_fax": "veniam",
    "collaborator_id": 15,
    "order": {}
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 268,
        "first_name": "Dorel",
        "last_name": "Trifan",
        "cnp": "4221023029120",
        "phone_fax": "0352118781",
        "email": "tmihalcea@example.net"
    }
}
```
<div id="execution-results-POSTapi-v1-ro-dentists" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-dentists"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-dentists"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-dentists" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-dentists"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-dentists" data-method="POST" data-path="api/v1/ro/dentists" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-dentists', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-dentists" onclick="tryItOut('POSTapi-v1-ro-dentists');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-dentists" onclick="cancelTryOut('POSTapi-v1-ro-dentists');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-dentists" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/dentists</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-dentists" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-dentists" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="POSTapi-v1-ro-dentists" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="POSTapi-v1-ro-dentists" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cnp</code></b>&nbsp;&nbsp;<small>number</small>     <i>optional</i> &nbsp;
<input type="number" name="cnp" data-endpoint="POSTapi-v1-ro-dentists" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="POSTapi-v1-ro-dentists" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="POSTapi-v1-ro-dentists" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="collaborator_id" data-endpoint="POSTapi-v1-ro-dentists" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>order</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="order" data-endpoint="POSTapi-v1-ro-dentists" data-component="body"  hidden>
<br>

</p>

</form>


## Display a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/dentists/aut" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentists/aut"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 269,
        "first_name": "Tiberia",
        "last_name": "Farcas",
        "cnp": "3900206145835",
        "phone_fax": "0759251725",
        "email": "mircea.petrica@example.org"
    }
}
```
<div id="execution-results-GETapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-dentists--dentist-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-dentists--dentist-" data-method="GET" data-path="api/v1/ro/dentists/{dentist}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-dentists--dentist-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-dentists--dentist-" onclick="tryItOut('GETapi-v1-ro-dentists--dentist-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-dentists--dentist-" onclick="cancelTryOut('GETapi-v1-ro-dentists--dentist-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-dentists--dentist-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/dentists/{dentist}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-dentists--dentist-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-dentists--dentist-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>dentist</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="dentist" data-endpoint="GETapi-v1-ro-dentists--dentist-" data-component="url" required  hidden>
<br>

</p>
</form>


## Update a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/dentists/eligendi" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"first_name":"ut","last_name":"eligendi","cnp":35694207,"email":"peggie.halvorson@example.com","phone_fax":"reprehenderit","collaborator_id":15,"order":{}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentists/eligendi"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "first_name": "ut",
    "last_name": "eligendi",
    "cnp": 35694207,
    "email": "peggie.halvorson@example.com",
    "phone_fax": "reprehenderit",
    "collaborator_id": 15,
    "order": {}
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 270,
        "first_name": "Leonard",
        "last_name": "Preda",
        "cnp": "4050804523378",
        "phone_fax": "0319126448",
        "email": "victor50@example.net"
    }
}
```
<div id="execution-results-PUTapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-dentists--dentist-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-dentists--dentist-" data-method="PUT" data-path="api/v1/ro/dentists/{dentist}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-dentists--dentist-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-dentists--dentist-" onclick="tryItOut('PUTapi-v1-ro-dentists--dentist-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-dentists--dentist-" onclick="cancelTryOut('PUTapi-v1-ro-dentists--dentist-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-dentists--dentist-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/dentists/{dentist}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/dentists/{dentist}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-dentists--dentist-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>dentist</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="dentist" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cnp</code></b>&nbsp;&nbsp;<small>number</small>     <i>optional</i> &nbsp;
<input type="number" name="cnp" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="collaborator_id" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>order</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="order" data-endpoint="PUTapi-v1-ro-dentists--dentist-" data-component="body"  hidden>
<br>

</p>

</form>


## Remove a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/dentists/qui" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentists/qui"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-dentists--dentist-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-dentists--dentist-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-dentists--dentist-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-dentists--dentist-" data-method="DELETE" data-path="api/v1/ro/dentists/{dentist}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-dentists--dentist-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-dentists--dentist-" onclick="tryItOut('DELETEapi-v1-ro-dentists--dentist-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-dentists--dentist-" onclick="cancelTryOut('DELETEapi-v1-ro-dentists--dentist-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-dentists--dentist-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/dentists/{dentist}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-dentists--dentist-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-dentists--dentist-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>dentist</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="dentist" data-endpoint="DELETEapi-v1-ro-dentists--dentist-" data-component="url" required  hidden>
<br>

</p>
</form>


## DC List of collaborators of a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators-listing" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":3}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators-listing"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 3
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-dentist-collaborators-listing" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-dentist-collaborators-listing"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-dentist-collaborators-listing"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-dentist-collaborators-listing" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-dentist-collaborators-listing"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-dentist-collaborators-listing" data-method="POST" data-path="api/v1/ro/dentist-collaborators-listing" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-dentist-collaborators-listing', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-dentist-collaborators-listing" onclick="tryItOut('POSTapi-v1-ro-dentist-collaborators-listing');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-dentist-collaborators-listing" onclick="cancelTryOut('POSTapi-v1-ro-dentist-collaborators-listing');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-dentist-collaborators-listing" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/dentist-collaborators-listing</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-dentist-collaborators-listing" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-dentist-collaborators-listing" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="POSTapi-v1-ro-dentist-collaborators-listing" data-component="body" required  hidden>
<br>

</p>

</form>


## DC Add  a collaborator to a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":13,"collaborator_id":3}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 13,
    "collaborator_id": 3
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-dentist-collaborators" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-dentist-collaborators"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-dentist-collaborators"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-dentist-collaborators" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-dentist-collaborators"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-dentist-collaborators" data-method="POST" data-path="api/v1/ro/dentist-collaborators" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-dentist-collaborators', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-dentist-collaborators" onclick="tryItOut('POSTapi-v1-ro-dentist-collaborators');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-dentist-collaborators" onclick="cancelTryOut('POSTapi-v1-ro-dentist-collaborators');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-dentist-collaborators" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/dentist-collaborators</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-dentist-collaborators" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-dentist-collaborators" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="POSTapi-v1-ro-dentist-collaborators" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="POSTapi-v1-ro-dentist-collaborators" data-component="body" required  hidden>
<br>

</p>

</form>


## DC Remove  a collaborator from a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":13,"collaborator_id":8}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-collaborators"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 13,
    "collaborator_id": 8
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-dentist-collaborators" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-dentist-collaborators"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-dentist-collaborators"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-dentist-collaborators" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-dentist-collaborators"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-dentist-collaborators" data-method="DELETE" data-path="api/v1/ro/dentist-collaborators" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-dentist-collaborators', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-dentist-collaborators" onclick="tryItOut('DELETEapi-v1-ro-dentist-collaborators');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-dentist-collaborators" onclick="cancelTryOut('DELETEapi-v1-ro-dentist-collaborators');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-dentist-collaborators" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/dentist-collaborators</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-dentist-collaborators" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-dentist-collaborators" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="DELETEapi-v1-ro-dentist-collaborators" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="DELETEapi-v1-ro-dentist-collaborators" data-component="body" required  hidden>
<br>

</p>

</form>


## DP List of prices for a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices-listing" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":2,"work_template_id":9}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices-listing"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 2,
    "work_template_id": 9
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-dentist-prices-listing" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-dentist-prices-listing"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-dentist-prices-listing"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-dentist-prices-listing" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-dentist-prices-listing"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-dentist-prices-listing" data-method="POST" data-path="api/v1/ro/dentist-prices-listing" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-dentist-prices-listing', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-dentist-prices-listing" onclick="tryItOut('POSTapi-v1-ro-dentist-prices-listing');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-dentist-prices-listing" onclick="cancelTryOut('POSTapi-v1-ro-dentist-prices-listing');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-dentist-prices-listing" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/dentist-prices-listing</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-dentist-prices-listing" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-dentist-prices-listing" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="POSTapi-v1-ro-dentist-prices-listing" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="work_template_id" data-endpoint="POSTapi-v1-ro-dentist-prices-listing" data-component="body"  hidden>
<br>

</p>

</form>


## DP Add/update  a price to a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":15,"work_template_id":10,"price":18,"locked":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 15,
    "work_template_id": 10,
    "price": 18,
    "locked": false
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-PUTapi-v1-ro-dentist-prices" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-dentist-prices"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-dentist-prices"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-dentist-prices" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-dentist-prices"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-dentist-prices" data-method="PUT" data-path="api/v1/ro/dentist-prices" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-dentist-prices', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-dentist-prices" onclick="tryItOut('PUTapi-v1-ro-dentist-prices');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-dentist-prices" onclick="cancelTryOut('PUTapi-v1-ro-dentist-prices');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-dentist-prices" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/dentist-prices</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-dentist-prices" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template_id" data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>price</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="price" data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>locked</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-dentist-prices" hidden><input type="radio" name="locked" value="true" data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-dentist-prices" hidden><input type="radio" name="locked" value="false" data-endpoint="PUTapi-v1-ro-dentist-prices" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## DP Delete  a price to a dentist.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"dentist_id":3,"work_template_id":3}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/dentist-prices"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "dentist_id": 3,
    "work_template_id": 3
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-dentist-prices" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-dentist-prices"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-dentist-prices"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-dentist-prices" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-dentist-prices"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-dentist-prices" data-method="DELETE" data-path="api/v1/ro/dentist-prices" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-dentist-prices', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-dentist-prices" onclick="tryItOut('DELETEapi-v1-ro-dentist-prices');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-dentist-prices" onclick="cancelTryOut('DELETEapi-v1-ro-dentist-prices');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-dentist-prices" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/dentist-prices</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-dentist-prices" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-dentist-prices" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="dentist_id" data-endpoint="DELETEapi-v1-ro-dentist-prices" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template_id" data-endpoint="DELETEapi-v1-ro-dentist-prices" data-component="body" required  hidden>
<br>

</p>

</form>



