# Documente de plata

APIs for managing work stages

## Add discount to payment

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/discounts/et" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"discount_type_id":"aut","name":"dicta","value":22245.269}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/discounts/et"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "discount_type_id": "aut",
    "name": "dicta",
    "value": 22245.269
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-discounts--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-discounts--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-discounts--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-discounts--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-discounts--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/discounts/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-discounts--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-discounts--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-discounts--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-discounts--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-discounts--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-discounts--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/discounts/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-discounts--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>discount_type_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="discount_type_id" data-endpoint="POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>value</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="value" data-endpoint="POSTapi-v1-ro-payment-documents-discounts--payment_document-" data-component="body" required  hidden>
<br>

</p>

</form>


## Remove discount from payment

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/discounts/doloribus" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"discount_id":"perspiciatis"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/discounts/doloribus"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "discount_id": "perspiciatis"
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-payment-documents-discounts--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-payment-documents-discounts--payment_document-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-payment-documents-discounts--payment_document-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" data-method="DELETE" data-path="api/v1/ro/payment-documents/discounts/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-payment-documents-discounts--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" onclick="tryItOut('DELETEapi-v1-ro-payment-documents-discounts--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" onclick="cancelTryOut('DELETEapi-v1-ro-payment-documents-discounts--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/payment-documents/discounts/{payment_document}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-payment-documents-discounts--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-payment-documents-discounts--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="DELETEapi-v1-ro-payment-documents-discounts--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>discount_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="discount_id" data-endpoint="DELETEapi-v1-ro-payment-documents-discounts--payment_document-" data-component="body" required  hidden>
<br>

</p>

</form>


## Display a listing of payment documents.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/payment-documents" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-GETapi-v1-ro-payment-documents" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-payment-documents"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-payment-documents"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-payment-documents" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-payment-documents"></code></pre>
</div>
<form id="form-GETapi-v1-ro-payment-documents" data-method="GET" data-path="api/v1/ro/payment-documents" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-payment-documents', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-payment-documents" onclick="tryItOut('GETapi-v1-ro-payment-documents');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-payment-documents" onclick="cancelTryOut('GETapi-v1-ro-payment-documents');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-payment-documents" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/payment-documents</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-payment-documents" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-payment-documents" data-component="header"></label>
</p>
</form>


## Add a new payment document.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"collaborator_id":11,"dentist_id":3,"detailed_payment":false,"lab_invoice_profile_id":"quia"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "collaborator_id": 11,
    "dentist_id": 3,
    "detailed_payment": false,
    "lab_invoice_profile_id": "quia"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents" data-method="POST" data-path="api/v1/ro/payment-documents" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents" onclick="tryItOut('POSTapi-v1-ro-payment-documents');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="collaborator_id" data-endpoint="POSTapi-v1-ro-payment-documents" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="dentist_id" data-endpoint="POSTapi-v1-ro-payment-documents" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>detailed_payment</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-payment-documents" hidden><input type="radio" name="detailed_payment" value="true" data-endpoint="POSTapi-v1-ro-payment-documents" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-payment-documents" hidden><input type="radio" name="detailed_payment" value="false" data-endpoint="POSTapi-v1-ro-payment-documents" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>lab_invoice_profile_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="lab_invoice_profile_id" data-endpoint="POSTapi-v1-ro-payment-documents" data-component="body" required  hidden>
<br>

</p>

</form>


## Display a payment document.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/payment-documents/ut" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/ut"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-GETapi-v1-ro-payment-documents--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-payment-documents--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-payment-documents--payment_document-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-payment-documents--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-payment-documents--payment_document-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-payment-documents--payment_document-" data-method="GET" data-path="api/v1/ro/payment-documents/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-payment-documents--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-payment-documents--payment_document-" onclick="tryItOut('GETapi-v1-ro-payment-documents--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-payment-documents--payment_document-" onclick="cancelTryOut('GETapi-v1-ro-payment-documents--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-payment-documents--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/payment-documents/{payment_document}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-payment-documents--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-payment-documents--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="GETapi-v1-ro-payment-documents--payment_document-" data-component="url" required  hidden>
<br>

</p>
</form>


## Remove a payment document.

<small class="badge badge-darkred">requires authentication</small>

.

> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/ullam" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/ullam"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-payment-documents--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-payment-documents--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-payment-documents--payment_document-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-payment-documents--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-payment-documents--payment_document-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-payment-documents--payment_document-" data-method="DELETE" data-path="api/v1/ro/payment-documents/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-payment-documents--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-payment-documents--payment_document-" onclick="tryItOut('DELETEapi-v1-ro-payment-documents--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-payment-documents--payment_document-" onclick="cancelTryOut('DELETEapi-v1-ro-payment-documents--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-payment-documents--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/payment-documents/{payment_document}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-payment-documents--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-payment-documents--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="DELETEapi-v1-ro-payment-documents--payment_document-" data-component="url" required  hidden>
<br>

</p>
</form>


## Available orders for a payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/available-orders/ad" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"filters":{"patient_filtering":{"patient_name":"et"},"dentist_filtering":{"dentist_name":"eius"},"date_filtering":{"start_date":{"interval_start":"12-01-2022","interval_end":"12-01-2022"},"end_date":{"interval_start":"12-01-2022","interval_end":"12-01-2022"}}}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/available-orders/ad"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "filters": {
        "patient_filtering": {
            "patient_name": "et"
        },
        "dentist_filtering": {
            "dentist_name": "eius"
        },
        "date_filtering": {
            "start_date": {
                "interval_start": "12-01-2022",
                "interval_end": "12-01-2022"
            },
            "end_date": {
                "interval_start": "12-01-2022",
                "interval_end": "12-01-2022"
            }
        }
    }
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-available-orders--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-available-orders--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-available-orders--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/available-orders/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-available-orders--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-available-orders--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-available-orders--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/available-orders/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-available-orders--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<details>
<summary>
<b><code>filters</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<details>
<summary>
<b><code>filters.patient_filtering</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.patient_filtering.patient_name</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.patient_filtering.patient_name" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>

</p>
</details>
</p>

<p>
<details>
<summary>
<b><code>filters.dentist_filtering</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.dentist_filtering.dentist_name</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.dentist_filtering.dentist_name" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>

</p>
</details>
</p>

<p>
<details>
<summary>
<b><code>filters.date_filtering</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<details>
<summary>
<b><code>filters.date_filtering.start_date</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.date_filtering.start_date.interval_start</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.start_date.interval_start" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
<p>
<b><code>filters.date_filtering.start_date.interval_end</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.start_date.interval_end" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
</details>
</p>

<p>
<details>
<summary>
<b><code>filters.date_filtering.end_date</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.date_filtering.end_date.interval_start</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.end_date.interval_start" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
<p>
<b><code>filters.date_filtering.end_date.interval_end</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.end_date.interval_end" data-endpoint="POSTapi-v1-ro-payment-documents-available-orders--payment_document-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
</details>
</p>

</details>
</p>

</details>
</p>

</form>


## Orders detailed works

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/orders-details" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"order_ids":[{"order_id":8}]}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/orders-details"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "order_ids": [
        {
            "order_id": 8
        }
    ]
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-orders-details" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-orders-details"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-orders-details"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-orders-details" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-orders-details"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-orders-details" data-method="POST" data-path="api/v1/ro/payment-documents/orders-details" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-orders-details', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-orders-details" onclick="tryItOut('POSTapi-v1-ro-payment-documents-orders-details');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-orders-details" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-orders-details');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-orders-details" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/orders-details</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-orders-details" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-orders-details" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<details>
<summary>
<b><code>order_ids</code></b>&nbsp;&nbsp;<small>object[]</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>order_ids[].order_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="order_ids.0.order_id" data-endpoint="POSTapi-v1-ro-payment-documents-orders-details" data-component="body" required  hidden>
<br>

</p>
</details>
</p>

</form>


## Add orders to a payment document.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/add-orders/non" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"order_ids_to_be_added":[{"order_id":6}],"detailed_payment":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/add-orders/non"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "order_ids_to_be_added": [
        {
            "order_id": 6
        }
    ],
    "detailed_payment": false
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-add-orders--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-add-orders--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-add-orders--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/add-orders/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-add-orders--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-add-orders--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-add-orders--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/add-orders/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<details>
<summary>
<b><code>order_ids_to_be_added</code></b>&nbsp;&nbsp;<small>object[]</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>order_ids_to_be_added[].order_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="order_ids_to_be_added.0.order_id" data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-component="body" required  hidden>
<br>

</p>
</details>
</p>
<p>
<b><code>detailed_payment</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden><input type="radio" name="detailed_payment" value="true" data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" hidden><input type="radio" name="detailed_payment" value="false" data-endpoint="POSTapi-v1-ro-payment-documents-add-orders--payment_document-" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## Remove order from payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/remove-orders/omnis" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"order_id_to_be_removed":"veritatis","detailed_payment":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/remove-orders/omnis"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "order_id_to_be_removed": "veritatis",
    "detailed_payment": false
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-method="DELETE" data-path="api/v1/ro/payment-documents/remove-orders/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" onclick="tryItOut('DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" onclick="cancelTryOut('DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/payment-documents/remove-orders/{payment_document}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>order_id_to_be_removed</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="order_id_to_be_removed" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>detailed_payment</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden><input type="radio" name="detailed_payment" value="true" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-component="body" required ><code>true</code></label>
<label data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" hidden><input type="radio" name="detailed_payment" value="false" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-orders--payment_document-" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## Lock a payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/lock/sed" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"detailed_payment":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/lock/sed"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "detailed_payment": false
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-lock--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-lock--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-lock--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-lock--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/lock/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-lock--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-lock--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-lock--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-lock--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-lock--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/lock/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>detailed_payment</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden><input type="radio" name="detailed_payment" value="true" data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" hidden><input type="radio" name="detailed_payment" value="false" data-endpoint="POSTapi-v1-ro-payment-documents-lock--payment_document-" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## Mark payment document as paid

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/paid/itaque" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"detailed_payment":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/paid/itaque"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "detailed_payment": false
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-paid--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-paid--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-paid--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-paid--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/paid/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-paid--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-paid--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-paid--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-paid--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-paid--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/paid/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>detailed_payment</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden><input type="radio" name="detailed_payment" value="true" data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" hidden><input type="radio" name="detailed_payment" value="false" data-endpoint="POSTapi-v1-ro-payment-documents-paid--payment_document-" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## Add payment to payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/add-payment/dolor" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"type":"cash","name":"quia","value":1129.33,"order_id":4,"date":"2022-01-12"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/add-payment/dolor"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "type": "cash",
    "name": "quia",
    "value": 1129.33,
    "order_id": 4,
    "date": "2022-01-12"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-add-payment--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-add-payment--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-add-payment--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/add-payment/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-add-payment--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-add-payment--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-add-payment--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/add-payment/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-add-payment--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="type" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="body" required  hidden>
<br>
The value must be one of <code>cash</code> or <code>op</code>.
</p>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>value</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="value" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>order_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="order_id" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>date</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="date" data-endpoint="POSTapi-v1-ro-payment-documents-add-payment--payment_document-" data-component="body" required  hidden>
<br>
The value must be a valid date in the format Y-m-d.
</p>

</form>


## Remove payment from payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/remove-payment/quos" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"order_id":8,"payment_id":18}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/remove-payment/quos"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "order_id": 8,
    "payment_id": 18
}

fetch(url, {
    method: "DELETE",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" data-method="DELETE" data-path="api/v1/ro/payment-documents/remove-payment/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" onclick="tryItOut('DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" onclick="cancelTryOut('DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/payment-documents/remove-payment/{payment_document}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>order_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="order_id" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>payment_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="payment_id" data-endpoint="DELETEapi-v1-ro-payment-documents-remove-payment--payment_document-" data-component="body" required  hidden>
<br>

</p>

</form>


## Get all payments of a payment document

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/payment-documents/payments/occaecati" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/payments/occaecati"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-GETapi-v1-ro-payment-documents-payments--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-payment-documents-payments--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-payment-documents-payments--payment_document-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-payment-documents-payments--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-payment-documents-payments--payment_document-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-payment-documents-payments--payment_document-" data-method="GET" data-path="api/v1/ro/payment-documents/payments/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-payment-documents-payments--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-payment-documents-payments--payment_document-" onclick="tryItOut('GETapi-v1-ro-payment-documents-payments--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-payment-documents-payments--payment_document-" onclick="cancelTryOut('GETapi-v1-ro-payment-documents-payments--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-payment-documents-payments--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/payment-documents/payments/{payment_document}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-payment-documents-payments--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-payment-documents-payments--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="GETapi-v1-ro-payment-documents-payments--payment_document-" data-component="url" required  hidden>
<br>

</p>
</form>


## Generate invoice

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/generate-invoice/minus" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"collaborator_id":"et","invoice_series_id":"et","invoice_date":"2022-01-12","invoice_services":[{"service_name":"est","amount":7,"unit_price":4927}]}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/generate-invoice/minus"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "collaborator_id": "et",
    "invoice_series_id": "et",
    "invoice_date": "2022-01-12",
    "invoice_services": [
        {
            "service_name": "est",
            "amount": 7,
            "unit_price": 4927
        }
    ]
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/generate-invoice/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/generate-invoice/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>collaborator_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="collaborator_id" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>invoice_series_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="invoice_series_id" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>invoice_date</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="invoice_date" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>
The value must be a valid date in the format Y-m-d.
</p>
<p>
<details>
<summary>
<b><code>invoice_services</code></b>&nbsp;&nbsp;<small>object[]</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>invoice_services[].service_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="invoice_services.0.service_name" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>invoice_services[].amount</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="invoice_services.0.amount" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>invoice_services[].unit_price</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="invoice_services.0.unit_price" data-endpoint="POSTapi-v1-ro-payment-documents-generate-invoice--payment_document-" data-component="body" required  hidden>
<br>

</p>
</details>
</p>

</form>


## Generate receipt

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/generate-receipt/explicabo" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"receipt_series_id":"quia","receipt_date":"2022-01-12","payment_id":"rerum"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/payment-documents/generate-receipt/explicabo"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "receipt_series_id": "quia",
    "receipt_date": "2022-01-12",
    "payment_id": "rerum"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-method="POST" data-path="api/v1/ro/payment-documents/generate-receipt/{payment_document}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" onclick="tryItOut('POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" onclick="cancelTryOut('POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/payment-documents/generate-receipt/{payment_document}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>payment_document</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_document" data-endpoint="POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>receipt_series_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="receipt_series_id" data-endpoint="POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>receipt_date</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="receipt_date" data-endpoint="POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-component="body" required  hidden>
<br>
The value must be a valid date in the format Y-m-d.
</p>
<p>
<b><code>payment_id</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="payment_id" data-endpoint="POSTapi-v1-ro-payment-documents-generate-receipt--payment_document-" data-component="body" required  hidden>
<br>

</p>

</form>



