# Etape lucru utilizatori

APIs for managing work stage users

## Store a newly user to a work stage.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"work_stage_id":12,"user_id":7,"price":6.8883}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "work_stage_id": 12,
    "user_id": 7,
    "price": 6.8883
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 346,
        "work_stage_id": 1,
        "user_id": 1,
        "price": 62,
        "rank": 3,
        "user": {
            "id": 1,
            "username": "docs.superadmin",
            "first_name": "Super",
            "last_name": "Admin",
            "status": "active",
            "roles": [
                "superadmin"
            ]
        }
    }
}
```
<div id="execution-results-POSTapi-v1-ro-work-stage-users" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-work-stage-users"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-work-stage-users"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-work-stage-users" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-work-stage-users"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-work-stage-users" data-method="POST" data-path="api/v1/ro/work-stage-users" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-work-stage-users', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-work-stage-users" onclick="tryItOut('POSTapi-v1-ro-work-stage-users');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-work-stage-users" onclick="cancelTryOut('POSTapi-v1-ro-work-stage-users');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-work-stage-users" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/work-stage-users</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-work-stage-users" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-work-stage-users" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>work_stage_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage_id" data-endpoint="POSTapi-v1-ro-work-stage-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>user_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="user_id" data-endpoint="POSTapi-v1-ro-work-stage-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>price</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="price" data-endpoint="POSTapi-v1-ro-work-stage-users" data-component="body" required  hidden>
<br>

</p>

</form>


## Remove a user attached to a work stage.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users/19" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users/19"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-work-stage-users--work_stage_user-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-work-stage-users--work_stage_user-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-work-stage-users--work_stage_user-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-work-stage-users--work_stage_user-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-work-stage-users--work_stage_user-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-work-stage-users--work_stage_user-" data-method="DELETE" data-path="api/v1/ro/work-stage-users/{work_stage_user}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-work-stage-users--work_stage_user-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-work-stage-users--work_stage_user-" onclick="tryItOut('DELETEapi-v1-ro-work-stage-users--work_stage_user-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-work-stage-users--work_stage_user-" onclick="cancelTryOut('DELETEapi-v1-ro-work-stage-users--work_stage_user-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-work-stage-users--work_stage_user-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/work-stage-users/{work_stage_user}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-work-stage-users--work_stage_user-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-work-stage-users--work_stage_user-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_stage_user</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage_user" data-endpoint="DELETEapi-v1-ro-work-stage-users--work_stage_user-" data-component="url" required  hidden>
<br>

</p>
</form>


## Updates work stage users on specified work stage

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"work_stage_id":16,"work_stage_users":"cum"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "work_stage_id": 16,
    "work_stage_users": "cum"
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 347,
            "work_stage_id": 1,
            "user_id": 1,
            "price": 36,
            "rank": 4,
            "user": {
                "id": 1,
                "username": "docs.superadmin",
                "first_name": "Super",
                "last_name": "Admin",
                "status": "active",
                "roles": [
                    "superadmin"
                ]
            }
        },
        {
            "id": 348,
            "work_stage_id": 1,
            "user_id": 1,
            "price": 102,
            "rank": 5,
            "user": {
                "id": 1,
                "username": "docs.superadmin",
                "first_name": "Super",
                "last_name": "Admin",
                "status": "active",
                "roles": [
                    "superadmin"
                ]
            }
        }
    ]
}
```
<div id="execution-results-PUTapi-v1-ro-work-stage-users" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-work-stage-users"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-work-stage-users"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-work-stage-users" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-work-stage-users"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-work-stage-users" data-method="PUT" data-path="api/v1/ro/work-stage-users" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-work-stage-users', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-work-stage-users" onclick="tryItOut('PUTapi-v1-ro-work-stage-users');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-work-stage-users" onclick="cancelTryOut('PUTapi-v1-ro-work-stage-users');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-work-stage-users" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/work-stage-users</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-work-stage-users" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-work-stage-users" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>work_stage_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage_id" data-endpoint="PUTapi-v1-ro-work-stage-users" data-component="body" required  hidden>
<br>

</p>
<p>
<details>
<summary>
<b><code>work_stage_users</code></b>&nbsp;&nbsp;<small>required</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>work_stage_users[].user_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage_users.0.user_id" data-endpoint="PUTapi-v1-ro-work-stage-users" data-component="body" required  hidden>
<br>

</p>
</details>
</p>

</form>


## Display all users attached to a work stage.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/work-stage-users-listing/9" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stage-users-listing/9"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 349,
            "work_stage_id": 1,
            "user_id": 1,
            "price": 4,
            "rank": 1,
            "user": {
                "id": 1,
                "username": "docs.superadmin",
                "first_name": "Super",
                "last_name": "Admin",
                "status": "active",
                "roles": [
                    "superadmin"
                ]
            }
        },
        {
            "id": 350,
            "work_stage_id": 1,
            "user_id": 1,
            "price": 26,
            "rank": 5,
            "user": {
                "id": 1,
                "username": "docs.superadmin",
                "first_name": "Super",
                "last_name": "Admin",
                "status": "active",
                "roles": [
                    "superadmin"
                ]
            }
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-work-stage-users-listing--work_stage-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-work-stage-users-listing--work_stage-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-work-stage-users-listing--work_stage-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-work-stage-users-listing--work_stage-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-work-stage-users-listing--work_stage-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-work-stage-users-listing--work_stage-" data-method="GET" data-path="api/v1/ro/work-stage-users-listing/{work_stage}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-work-stage-users-listing--work_stage-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-work-stage-users-listing--work_stage-" onclick="tryItOut('GETapi-v1-ro-work-stage-users-listing--work_stage-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-work-stage-users-listing--work_stage-" onclick="cancelTryOut('GETapi-v1-ro-work-stage-users-listing--work_stage-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-work-stage-users-listing--work_stage-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/work-stage-users-listing/{work_stage}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-work-stage-users-listing--work_stage-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-work-stage-users-listing--work_stage-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_stage</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage" data-endpoint="GETapi-v1-ro-work-stage-users-listing--work_stage-" data-component="url" required  hidden>
<br>
work stage id
</p>
</form>



