# Etape lucru

APIs for managing work stages

## Work stages listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/work-stages" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 266,
            "name": "Omnis quia quia aut saepe et.",
            "type": "special",
            "price_type": "arcada",
            "min_duration": 89,
            "cost": 4074.18,
            "remake_cost": 8967.41,
            "special_cost": 2472.04,
            "description": "Est odit qui qui sed voluptatibus. Assumenda temporibus et consequuntur. Labore provident dolorum deleniti eligendi exercitationem. Ut ut excepturi ut. Est atque et possimus quam libero.",
            "confirmation_required": true,
            "to_send": false,
            "extra_cost_applied": false,
            "multi_factor_dentition": {
                "1": true,
                "2": true,
                "3": true,
                "4": true,
                "5": true,
                "6": true,
                "7": true
            },
            "users": []
        },
        {
            "id": 267,
            "name": "Ipsum qui quia quae harum.",
            "type": "gingie",
            "price_type": "fix",
            "min_duration": 35,
            "cost": 2553.95,
            "remake_cost": 7792.46,
            "special_cost": 2965.14,
            "description": "Distinctio ex laborum repellat impedit aut. Molestias qui facilis quo a dolores. Rem dolores debitis error ut magni. Quasi fuga qui est quod ut.",
            "confirmation_required": false,
            "to_send": true,
            "extra_cost_applied": true,
            "multi_factor_dentition": {
                "1": true,
                "2": true,
                "3": true,
                "4": true,
                "5": true,
                "6": true,
                "7": true
            },
            "users": []
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-work-stages" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-work-stages"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-work-stages"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-work-stages" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-work-stages"></code></pre>
</div>
<form id="form-GETapi-v1-ro-work-stages" data-method="GET" data-path="api/v1/ro/work-stages" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-work-stages', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-work-stages" onclick="tryItOut('GETapi-v1-ro-work-stages');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-work-stages" onclick="cancelTryOut('GETapi-v1-ro-work-stages');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-work-stages" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/work-stages</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-work-stages" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-work-stages" data-component="header"></label>
</p>
</form>


## Store a newly created work stage.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/work-stages" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"cupiditate","type":"normal","price_type":"elemente","min_duration":13,"cost":0.133219,"to_send":false,"remake_cost":76.054,"special_cost":5.062367803,"description":"laudantium","confirmation_required":false,"extra_cost_applied":false,"multi_factor_dentition":{"1":false,"2":false,"3":false,"4":false,"5":false,"6":false,"7":false}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "cupiditate",
    "type": "normal",
    "price_type": "elemente",
    "min_duration": 13,
    "cost": 0.133219,
    "to_send": false,
    "remake_cost": 76.054,
    "special_cost": 5.062367803,
    "description": "laudantium",
    "confirmation_required": false,
    "extra_cost_applied": false,
    "multi_factor_dentition": {
        "1": false,
        "2": false,
        "3": false,
        "4": false,
        "5": false,
        "6": false,
        "7": false
    }
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 268,
        "name": "Eos quo fugit error quam aut.",
        "type": "trial",
        "price_type": "fix",
        "min_duration": 83,
        "cost": 5963.22,
        "remake_cost": 1387.7,
        "special_cost": 422.2,
        "description": "Laudantium quas similique porro non. Et distinctio iusto natus adipisci. Iste rerum illo corporis quia enim.",
        "confirmation_required": true,
        "to_send": true,
        "extra_cost_applied": false,
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        },
        "users": []
    }
}
```
<div id="execution-results-POSTapi-v1-ro-work-stages" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-work-stages"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-work-stages"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-work-stages" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-work-stages"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-work-stages" data-method="POST" data-path="api/v1/ro/work-stages" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-work-stages', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-work-stages" onclick="tryItOut('POSTapi-v1-ro-work-stages');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-work-stages" onclick="cancelTryOut('POSTapi-v1-ro-work-stages');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-work-stages" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/work-stages</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-work-stages" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-work-stages" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="type" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>
The value must be one of <code>trial</code>, <code>normal</code>, <code>implant</code>, <code>special</code>, <code>external</code>, <code>bont</code>, <code>gingie</code>, or <code>extra</code>.
</p>
<p>
<b><code>price_type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="price_type" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>
The value must be one of <code>fix</code>, <code>elemente</code>, or <code>arcada</code>.
</p>
<p>
<b><code>min_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="min_duration" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="cost" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>to_send</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="to_send" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="to_send" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>remake_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="remake_cost" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>special_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="special_cost" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>description</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="description" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>confirmation_required</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="confirmation_required" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="confirmation_required" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>extra_cost_applied</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="extra_cost_applied" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="extra_cost_applied" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<details>
<summary>
<b><code>multi_factor_dentition</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>multi_factor_dentition.1</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.1" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.1" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.2</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.2" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.2" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.3</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.3" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.3" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.4</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.4" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.4" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.5</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.5" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.5" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.6</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.6" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.6" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.7</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.7" value="true" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-stages" hidden><input type="radio" name="multi_factor_dentition.7" value="false" data-endpoint="POSTapi-v1-ro-work-stages" data-component="body" required ><code>false</code></label>
<br>

</p>
</details>
</p>

</form>


## Display a work stages.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/work-stages/7" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages/7"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 269,
        "name": "Ipsum quo ea ducimus.",
        "type": "trial",
        "price_type": "elemente",
        "min_duration": 143,
        "cost": 8640.3,
        "remake_cost": 1491.99,
        "special_cost": 5258.95,
        "description": "Consequatur qui iste quia ea voluptatibus. Animi facere quas et. Ad sapiente eum occaecati asperiores ut non. Porro repudiandae sunt ducimus qui.",
        "confirmation_required": true,
        "to_send": true,
        "extra_cost_applied": false,
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        },
        "users": []
    }
}
```
<div id="execution-results-GETapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-work-stages--work_stage-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-work-stages--work_stage-" data-method="GET" data-path="api/v1/ro/work-stages/{work_stage}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-work-stages--work_stage-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-work-stages--work_stage-" onclick="tryItOut('GETapi-v1-ro-work-stages--work_stage-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-work-stages--work_stage-" onclick="cancelTryOut('GETapi-v1-ro-work-stages--work_stage-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-work-stages--work_stage-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/work-stages/{work_stage}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-work-stages--work_stage-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-work-stages--work_stage-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_stage</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage" data-endpoint="GETapi-v1-ro-work-stages--work_stage-" data-component="url" required  hidden>
<br>

</p>
</form>


## Update a work stages.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/work-stages/7" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"rerum","type":"implant","price_type":"fix","min_duration":4,"cost":3471777.9896913944,"to_send":false,"remake_cost":34774328.84,"special_cost":236.08,"description":"necessitatibus","confirmation_required":false,"extra_cost_applied":false,"multi_factor_dentition":{"1":false,"2":false,"3":false,"4":false,"5":false,"6":false,"7":false}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages/7"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "rerum",
    "type": "implant",
    "price_type": "fix",
    "min_duration": 4,
    "cost": 3471777.9896913944,
    "to_send": false,
    "remake_cost": 34774328.84,
    "special_cost": 236.08,
    "description": "necessitatibus",
    "confirmation_required": false,
    "extra_cost_applied": false,
    "multi_factor_dentition": {
        "1": false,
        "2": false,
        "3": false,
        "4": false,
        "5": false,
        "6": false,
        "7": false
    }
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 270,
        "name": "Qui tempora laborum omnis.",
        "type": "external",
        "price_type": "fix",
        "min_duration": 91,
        "cost": 8441.43,
        "remake_cost": 934.44,
        "special_cost": 8600.19,
        "description": "Praesentium voluptatem veniam architecto quo illum quia voluptatem perspiciatis. Alias dolorem et debitis veniam. Aut nemo voluptas commodi nobis.",
        "confirmation_required": false,
        "to_send": false,
        "extra_cost_applied": true,
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        },
        "users": []
    }
}
```
<div id="execution-results-PUTapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-work-stages--work_stage-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-work-stages--work_stage-" data-method="PUT" data-path="api/v1/ro/work-stages/{work_stage}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-work-stages--work_stage-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-work-stages--work_stage-" onclick="tryItOut('PUTapi-v1-ro-work-stages--work_stage-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-work-stages--work_stage-" onclick="cancelTryOut('PUTapi-v1-ro-work-stages--work_stage-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-work-stages--work_stage-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/work-stages/{work_stage}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/work-stages/{work_stage}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-work-stages--work_stage-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_stage</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="type" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>
The value must be one of <code>trial</code>, <code>normal</code>, <code>implant</code>, <code>special</code>, <code>external</code>, <code>bont</code>, <code>gingie</code>, or <code>extra</code>.
</p>
<p>
<b><code>price_type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="price_type" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>
The value must be one of <code>fix</code>, <code>elemente</code>, or <code>arcada</code>.
</p>
<p>
<b><code>min_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="min_duration" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="cost" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>to_send</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="to_send" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="to_send" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>remake_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="remake_cost" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>special_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="special_cost" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>description</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="description" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>confirmation_required</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="confirmation_required" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="confirmation_required" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>extra_cost_applied</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="extra_cost_applied" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="extra_cost_applied" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<details>
<summary>
<b><code>multi_factor_dentition</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>multi_factor_dentition.1</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.1" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.1" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.2</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.2" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.2" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.3</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.3" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.3" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.4</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.4" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.4" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.5</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.5" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.5" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.6</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.6" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.6" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.7</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.7" value="true" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" hidden><input type="radio" name="multi_factor_dentition.7" value="false" data-endpoint="PUTapi-v1-ro-work-stages--work_stage-" data-component="body" required ><code>false</code></label>
<br>

</p>
</details>
</p>

</form>


## Remove a work stages.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/work-stages/19" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages/19"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-work-stages--work_stage-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-work-stages--work_stage-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-work-stages--work_stage-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-work-stages--work_stage-" data-method="DELETE" data-path="api/v1/ro/work-stages/{work_stage}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-work-stages--work_stage-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-work-stages--work_stage-" onclick="tryItOut('DELETEapi-v1-ro-work-stages--work_stage-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-work-stages--work_stage-" onclick="cancelTryOut('DELETEapi-v1-ro-work-stages--work_stage-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-work-stages--work_stage-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/work-stages/{work_stage}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-work-stages--work_stage-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-work-stages--work_stage-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_stage</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_stage" data-endpoint="DELETEapi-v1-ro-work-stages--work_stage-" data-component="url" required  hidden>
<br>

</p>
</form>


## Reset all work stages

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/work-stages-reset" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-stages-reset"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-work-stages-reset" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-work-stages-reset"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-work-stages-reset"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-work-stages-reset" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-work-stages-reset"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-work-stages-reset" data-method="DELETE" data-path="api/v1/ro/work-stages-reset" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-work-stages-reset', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-work-stages-reset" onclick="tryItOut('DELETEapi-v1-ro-work-stages-reset');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-work-stages-reset" onclick="cancelTryOut('DELETEapi-v1-ro-work-stages-reset');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-work-stages-reset" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/work-stages-reset</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-work-stages-reset" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-work-stages-reset" data-component="header"></label>
</p>
</form>



