# Pacienti

APIs for managing patients

## Patients listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/patients" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/patients"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 266,
            "first_name": "Larisa",
            "last_name": "Aldea",
            "cnp": "4440524364318",
            "mobile": "0359008798",
            "phone_fax": "0312809293",
            "email": "ovaduva@example.com",
            "address": "Calea Cloșca nr. 9, bl. D, et. 17, ap. 73, Mun. Ungheni, Teleorman, CP 009166"
        },
        {
            "id": 267,
            "first_name": "Luca",
            "last_name": "Petre",
            "cnp": "6220430181583",
            "mobile": "0336509324",
            "phone_fax": "0256430381",
            "email": "fcucu@example.com",
            "address": "Calea Pădurii 265, Băicoi, Gorj, CP 596461"
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-patients" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-patients"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-patients"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-patients" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-patients"></code></pre>
</div>
<form id="form-GETapi-v1-ro-patients" data-method="GET" data-path="api/v1/ro/patients" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-patients', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-patients" onclick="tryItOut('GETapi-v1-ro-patients');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-patients" onclick="cancelTryOut('GETapi-v1-ro-patients');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-patients" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/patients</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-patients" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-patients" data-component="header"></label>
</p>
</form>


## Store a newly created patient.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/patients" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"last_name":"voluptatem","first_name":"","cnp":32.783,"email":"armstrong.max@example.net","mobile":"voluptates","phone_fax":"eaque","address":"et"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/patients"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "last_name": "voluptatem",
    "first_name": "",
    "cnp": 32.783,
    "email": "armstrong.max@example.net",
    "mobile": "voluptates",
    "phone_fax": "eaque",
    "address": "et"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 268,
        "first_name": "Luminița",
        "last_name": "Dragan",
        "cnp": "4850705166261",
        "mobile": "0265107973",
        "phone_fax": "0212657475",
        "email": "ariana12@example.com",
        "address": "P-ța Salcâmilor 6B, Sighetu Marmației, Maramureț, CP 702101"
    }
}
```
<div id="execution-results-POSTapi-v1-ro-patients" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-patients"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-patients"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-patients" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-patients"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-patients" data-method="POST" data-path="api/v1/ro/patients" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-patients', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-patients" onclick="tryItOut('POSTapi-v1-ro-patients');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-patients" onclick="cancelTryOut('POSTapi-v1-ro-patients');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-patients" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/patients</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-patients" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-patients" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="POSTapi-v1-ro-patients" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="POSTapi-v1-ro-patients" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cnp</code></b>&nbsp;&nbsp;<small>number</small>     <i>optional</i> &nbsp;
<input type="number" name="cnp" data-endpoint="POSTapi-v1-ro-patients" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="POSTapi-v1-ro-patients" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="POSTapi-v1-ro-patients" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="POSTapi-v1-ro-patients" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="POSTapi-v1-ro-patients" data-component="body"  hidden>
<br>

</p>

</form>


## Display a patient.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/patients/pariatur" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/patients/pariatur"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 269,
        "first_name": "Aurelian",
        "last_name": "Vintila",
        "cnp": "6751220528788",
        "mobile": "0243552867",
        "phone_fax": "0211703285",
        "email": "mirona78@example.org",
        "address": "B-dul. Păcurari nr. 4\/7, bl. A, et. 68, ap. 3, Mun. Răcari, Mehedinți, CP 515903"
    }
}
```
<div id="execution-results-GETapi-v1-ro-patients--patient-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-patients--patient-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-patients--patient-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-patients--patient-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-patients--patient-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-patients--patient-" data-method="GET" data-path="api/v1/ro/patients/{patient}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-patients--patient-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-patients--patient-" onclick="tryItOut('GETapi-v1-ro-patients--patient-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-patients--patient-" onclick="cancelTryOut('GETapi-v1-ro-patients--patient-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-patients--patient-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/patients/{patient}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-patients--patient-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-patients--patient-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>patient</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="patient" data-endpoint="GETapi-v1-ro-patients--patient-" data-component="url" required  hidden>
<br>

</p>
</form>


## Update a patient.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/patients/expedita" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"last_name":"et","first_name":"","cnp":35,"email":"bcole@example.net","mobile":"et","phone_fax":"hic","address":"earum"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/patients/expedita"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "last_name": "et",
    "first_name": "",
    "cnp": 35,
    "email": "bcole@example.net",
    "mobile": "et",
    "phone_fax": "hic",
    "address": "earum"
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 270,
        "first_name": "Horațiu",
        "last_name": "Patrascu",
        "cnp": "3960521271559",
        "mobile": "0341461984",
        "phone_fax": "0333610568",
        "email": "anamaria.manolache@example.org",
        "address": "B-dul. Constantin Brâncuși 5B, Mun. Târgoviște, Neamț, CP 245324"
    }
}
```
<div id="execution-results-PUTapi-v1-ro-patients--patient-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-patients--patient-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-patients--patient-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-patients--patient-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-patients--patient-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-patients--patient-" data-method="PUT" data-path="api/v1/ro/patients/{patient}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-patients--patient-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-patients--patient-" onclick="tryItOut('PUTapi-v1-ro-patients--patient-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-patients--patient-" onclick="cancelTryOut('PUTapi-v1-ro-patients--patient-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-patients--patient-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/patients/{patient}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/patients/{patient}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-patients--patient-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>patient</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="patient" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>cnp</code></b>&nbsp;&nbsp;<small>number</small>     <i>optional</i> &nbsp;
<input type="number" name="cnp" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="PUTapi-v1-ro-patients--patient-" data-component="body"  hidden>
<br>

</p>

</form>


## Remove a patient.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/patients/voluptate" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/patients/voluptate"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-patients--patient-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-patients--patient-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-patients--patient-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-patients--patient-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-patients--patient-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-patients--patient-" data-method="DELETE" data-path="api/v1/ro/patients/{patient}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-patients--patient-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-patients--patient-" onclick="tryItOut('DELETEapi-v1-ro-patients--patient-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-patients--patient-" onclick="cancelTryOut('DELETEapi-v1-ro-patients--patient-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-patients--patient-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/patients/{patient}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-patients--patient-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-patients--patient-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>patient</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="patient" data-endpoint="DELETEapi-v1-ro-patients--patient-" data-component="url"  hidden>
<br>
numeric required
</p>
</form>



