# Rapoarte comenzi

APIs for managing order additional prices

## Calculate current total value

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/orders-calculate-total" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"orders_ids":[{"order_id":1}]}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/orders-calculate-total"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "orders_ids": [
        {
            "order_id": 1
        }
    ]
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-orders-calculate-total" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-orders-calculate-total"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-orders-calculate-total"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-orders-calculate-total" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-orders-calculate-total"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-orders-calculate-total" data-method="POST" data-path="api/v1/ro/orders-calculate-total" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-orders-calculate-total', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-orders-calculate-total" onclick="tryItOut('POSTapi-v1-ro-orders-calculate-total');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-orders-calculate-total" onclick="cancelTryOut('POSTapi-v1-ro-orders-calculate-total');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-orders-calculate-total" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/orders-calculate-total</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-orders-calculate-total" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-orders-calculate-total" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<details>
<summary>
<b><code>orders_ids</code></b>&nbsp;&nbsp;<small>object[]</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>orders_ids[].order_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="orders_ids.0.order_id" data-endpoint="POSTapi-v1-ro-orders-calculate-total" data-component="body" required  hidden>
<br>

</p>
</details>
</p>

</form>


## Orders report.

<small class="badge badge-darkred">requires authentication</small>

<aside class="notice">Invoice filters combined could give wrong data. Use only one with true</aside>

> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/reports/orders/dolorem" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"filters":{"order_id":1,"dentist_id":13,"date_filtering":{"start_date":{"interval_start":"12-01-2022","interval_end":"12-01-2022"},"end_date":{"interval_start":"12-01-2022","interval_end":"12-01-2022"}},"status":{"is_complete":false},"invoice":{"only_fiscal":false,"only_proforma":false,"only_no_invoice":false},"is_paid_fully":false,"zero_value_orders":false}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/reports/orders/dolorem"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "filters": {
        "order_id": 1,
        "dentist_id": 13,
        "date_filtering": {
            "start_date": {
                "interval_start": "12-01-2022",
                "interval_end": "12-01-2022"
            },
            "end_date": {
                "interval_start": "12-01-2022",
                "interval_end": "12-01-2022"
            }
        },
        "status": {
            "is_complete": false
        },
        "invoice": {
            "only_fiscal": false,
            "only_proforma": false,
            "only_no_invoice": false
        },
        "is_paid_fully": false,
        "zero_value_orders": false
    }
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-reports-orders--collaborator-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-reports-orders--collaborator-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-reports-orders--collaborator-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-reports-orders--collaborator-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-reports-orders--collaborator-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-reports-orders--collaborator-" data-method="POST" data-path="api/v1/ro/reports/orders/{collaborator}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-reports-orders--collaborator-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-reports-orders--collaborator-" onclick="tryItOut('POSTapi-v1-ro-reports-orders--collaborator-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-reports-orders--collaborator-" onclick="cancelTryOut('POSTapi-v1-ro-reports-orders--collaborator-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-reports-orders--collaborator-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/reports/orders/{collaborator}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-reports-orders--collaborator-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>collaborator</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="collaborator" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<details>
<summary>
<b><code>filters</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.order_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="filters.order_id" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>filters.dentist_id</code></b>&nbsp;&nbsp;<small>integer</small>     <i>optional</i> &nbsp;
<input type="number" name="filters.dentist_id" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>

</p>
<p>
<details>
<summary>
<b><code>filters.date_filtering</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<details>
<summary>
<b><code>filters.date_filtering.start_date</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.date_filtering.start_date.interval_start</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.start_date.interval_start" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
<p>
<b><code>filters.date_filtering.start_date.interval_end</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.start_date.interval_end" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
</details>
</p>

<p>
<details>
<summary>
<b><code>filters.date_filtering.end_date</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.date_filtering.end_date.interval_start</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.end_date.interval_start" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
<p>
<b><code>filters.date_filtering.end_date.interval_end</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="filters.date_filtering.end_date.interval_end" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body"  hidden>
<br>
The value must be a valid date in the format d-m-Y.
</p>
</details>
</p>

</details>
</p>

<p>
<details>
<summary>
<b><code>filters.status</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.status.is_complete</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.status.is_complete" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.status.is_complete" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
</details>
</p>

<p>
<details>
<summary>
<b><code>filters.invoice</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>filters.invoice.only_fiscal</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_fiscal" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_fiscal" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>filters.invoice.only_proforma</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_proforma" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_proforma" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>filters.invoice.only_no_invoice</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_no_invoice" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.invoice.only_no_invoice" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
</details>
</p>

<p>
<b><code>filters.is_paid_fully</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.is_paid_fully" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.is_paid_fully" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>filters.zero_value_orders</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.zero_value_orders" value="true" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" hidden><input type="radio" name="filters.zero_value_orders" value="false" data-endpoint="POSTapi-v1-ro-reports-orders--collaborator-" data-component="body" ><code>false</code></label>
<br>

</p>
</details>
</p>

</form>


## Send an order to invoicing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/reports/send-to-invoicing/recusandae" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/reports/send-to-invoicing/recusandae"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "POST",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-reports-send-to-invoicing--order-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-reports-send-to-invoicing--order-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-reports-send-to-invoicing--order-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-reports-send-to-invoicing--order-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-reports-send-to-invoicing--order-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-reports-send-to-invoicing--order-" data-method="POST" data-path="api/v1/ro/reports/send-to-invoicing/{order}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-reports-send-to-invoicing--order-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-reports-send-to-invoicing--order-" onclick="tryItOut('POSTapi-v1-ro-reports-send-to-invoicing--order-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-reports-send-to-invoicing--order-" onclick="cancelTryOut('POSTapi-v1-ro-reports-send-to-invoicing--order-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-reports-send-to-invoicing--order-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/reports/send-to-invoicing/{order}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-reports-send-to-invoicing--order-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-reports-send-to-invoicing--order-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>order</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="order" data-endpoint="POSTapi-v1-ro-reports-send-to-invoicing--order-" data-component="url" required  hidden>
<br>

</p>
</form>



