# Roluri

APIs for managing roles

## Roles listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/roles" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/roles"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 253,
            "name": "role title",
            "permissions_names": [],
            "permissions": []
        },
        {
            "id": null,
            "name": "role title",
            "permissions_names": [],
            "permissions": []
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-roles" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-roles"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-roles"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-roles" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-roles"></code></pre>
</div>
<form id="form-GETapi-v1-ro-roles" data-method="GET" data-path="api/v1/ro/roles" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-roles', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-roles" onclick="tryItOut('GETapi-v1-ro-roles');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-roles" onclick="cancelTryOut('GETapi-v1-ro-roles');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-roles" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/roles</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-roles" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-roles" data-component="header"></label>
</p>
</form>


## Store a newly created role.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/roles" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"repellendus"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/roles"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "repellendus"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 255,
        "name": "role title",
        "permissions_names": [],
        "permissions": []
    }
}
```
<div id="execution-results-POSTapi-v1-ro-roles" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-roles"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-roles"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-roles" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-roles"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-roles" data-method="POST" data-path="api/v1/ro/roles" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-roles', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-roles" onclick="tryItOut('POSTapi-v1-ro-roles');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-roles" onclick="cancelTryOut('POSTapi-v1-ro-roles');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-roles" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/roles</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-roles" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-roles" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-roles" data-component="body" required  hidden>
<br>

</p>

</form>


## Display a role.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/roles/13" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/roles/13"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 256,
        "name": "role title",
        "permissions_names": [],
        "permissions": []
    }
}
```
<div id="execution-results-GETapi-v1-ro-roles--role-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-roles--role-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-roles--role-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-roles--role-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-roles--role-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-roles--role-" data-method="GET" data-path="api/v1/ro/roles/{role}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-roles--role-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-roles--role-" onclick="tryItOut('GETapi-v1-ro-roles--role-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-roles--role-" onclick="cancelTryOut('GETapi-v1-ro-roles--role-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-roles--role-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/roles/{role}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-roles--role-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-roles--role-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>role</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="role" data-endpoint="GETapi-v1-ro-roles--role-" data-component="url" required  hidden>
<br>

</p>
</form>


## Update  a role.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/roles/veniam" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"iure","permissions":["inventore","consequuntur"]}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/roles/veniam"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "iure",
    "permissions": [
        "inventore",
        "consequuntur"
    ]
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 257,
        "name": "role title",
        "permissions_names": [],
        "permissions": []
    }
}
```
<div id="execution-results-PUTapi-v1-ro-roles--role-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-roles--role-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-roles--role-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-roles--role-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-roles--role-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-roles--role-" data-method="PUT" data-path="api/v1/ro/roles/{role}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-roles--role-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-roles--role-" onclick="tryItOut('PUTapi-v1-ro-roles--role-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-roles--role-" onclick="cancelTryOut('PUTapi-v1-ro-roles--role-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-roles--role-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/roles/{role}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/roles/{role}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-roles--role-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-roles--role-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>role</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="role" data-endpoint="PUTapi-v1-ro-roles--role-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="PUTapi-v1-ro-roles--role-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>permissions</code></b>&nbsp;&nbsp;<small>string[]</small>  &nbsp;
<input type="text" name="permissions.0" data-endpoint="PUTapi-v1-ro-roles--role-" data-component="body" required  hidden>
<input type="text" name="permissions.1" data-endpoint="PUTapi-v1-ro-roles--role-" data-component="body" hidden>
<br>

</p>

</form>


## Remove  a role.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/roles/velit" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/roles/velit"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
1
```
<div id="execution-results-DELETEapi-v1-ro-roles--role-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-roles--role-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-roles--role-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-roles--role-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-roles--role-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-roles--role-" data-method="DELETE" data-path="api/v1/ro/roles/{role}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-roles--role-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-roles--role-" onclick="tryItOut('DELETEapi-v1-ro-roles--role-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-roles--role-" onclick="cancelTryOut('DELETEapi-v1-ro-roles--role-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-roles--role-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/roles/{role}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-roles--role-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-roles--role-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>role</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="role" data-endpoint="DELETEapi-v1-ro-roles--role-" data-component="url" required  hidden>
<br>

</p>
</form>


## Permissions names listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/permissions-list" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/permissions-list"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        "permissions1",
        "permissions2"
    ]
}
```
<div id="execution-results-GETapi-v1-ro-permissions-list" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-permissions-list"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-permissions-list"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-permissions-list" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-permissions-list"></code></pre>
</div>
<form id="form-GETapi-v1-ro-permissions-list" data-method="GET" data-path="api/v1/ro/permissions-list" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-permissions-list', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-permissions-list" onclick="tryItOut('GETapi-v1-ro-permissions-list');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-permissions-list" onclick="cancelTryOut('GETapi-v1-ro-permissions-list');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-permissions-list" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/permissions-list</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-permissions-list" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-permissions-list" data-component="header"></label>
</p>
</form>


## Permissions detailed listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/permissions-detailed" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/permissions-detailed"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "name": "Permission name",
            "shortName": "lang_permissions.Permission short description",
            "category": "lang_permissions.Permission category",
            "subcategory": "lang_permissions.Permission subcategory",
            "short_description": "lang_permissions.Permission short description",
            "description": "lang_permissions.Permission description",
            "guard": "api"
        },
        {
            "name": "Permission name",
            "shortName": "lang_permissions.Permission short description",
            "category": "lang_permissions.Permission category",
            "subcategory": "lang_permissions.Permission subcategory",
            "short_description": "lang_permissions.Permission short description",
            "description": "lang_permissions.Permission description",
            "guard": "api"
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-permissions-detailed" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-permissions-detailed"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-permissions-detailed"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-permissions-detailed" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-permissions-detailed"></code></pre>
</div>
<form id="form-GETapi-v1-ro-permissions-detailed" data-method="GET" data-path="api/v1/ro/permissions-detailed" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-permissions-detailed', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-permissions-detailed" onclick="tryItOut('GETapi-v1-ro-permissions-detailed');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-permissions-detailed" onclick="cancelTryOut('GETapi-v1-ro-permissions-detailed');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-permissions-detailed" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/permissions-detailed</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-permissions-detailed" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-permissions-detailed" data-component="header"></label>
</p>
</form>


## Permission detailed.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/permission/voluptas" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/permission/voluptas"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "name": "Permission name",
        "shortName": "lang_permissions.Permission short description",
        "category": "lang_permissions.Permission category",
        "subcategory": "lang_permissions.Permission subcategory",
        "short_description": "lang_permissions.Permission short description",
        "description": "lang_permissions.Permission description",
        "guard": "api"
    }
}
```
<div id="execution-results-GETapi-v1-ro-permission--permission_name-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-permission--permission_name-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-permission--permission_name-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-permission--permission_name-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-permission--permission_name-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-permission--permission_name-" data-method="GET" data-path="api/v1/ro/permission/{permission_name}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-permission--permission_name-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-permission--permission_name-" onclick="tryItOut('GETapi-v1-ro-permission--permission_name-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-permission--permission_name-" onclick="cancelTryOut('GETapi-v1-ro-permission--permission_name-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-permission--permission_name-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/permission/{permission_name}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-permission--permission_name-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-permission--permission_name-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>permission_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="permission_name" data-endpoint="GETapi-v1-ro-permission--permission_name-" data-component="url" required  hidden>
<br>

</p>
</form>



