# Sabloane

APIs for managing work templates

## Work template listing.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/work-templates" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 266,
            "name": "Veniam tempore nulla quia.",
            "min_duration": 1,
            "estimated_duration": 5,
            "cost": 3472.93,
            "extra_cost": 5118.09,
            "description": "Sint perspiciatis corrupti commodi assumenda sit. Qui aut quisquam omnis culpa minus soluta velit. Rem aut mollitia quaerat. Laboriosam nihil officia quidem optio est distinctio.",
            "type": "",
            "price_type": "elemente",
            "symbol": "aperiam",
            "multi_factor_dentition": {
                "1": true,
                "2": true,
                "3": true,
                "4": true,
                "5": true,
                "6": true,
                "7": true
            }
        },
        {
            "id": 267,
            "name": "Et ut et aut necessitatibus.",
            "min_duration": 9,
            "estimated_duration": 7,
            "cost": 3072.7,
            "extra_cost": 2362.93,
            "description": "Doloremque provident et totam deleniti eaque velit vitae. Repudiandae omnis incidunt dolores. Consectetur vel quod qui error. Earum incidunt aut similique neque.",
            "type": "",
            "price_type": "fix",
            "symbol": "pariatur",
            "multi_factor_dentition": {
                "1": true,
                "2": true,
                "3": true,
                "4": true,
                "5": true,
                "6": true,
                "7": true
            }
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-work-templates" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-work-templates"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-work-templates"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-work-templates" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-work-templates"></code></pre>
</div>
<form id="form-GETapi-v1-ro-work-templates" data-method="GET" data-path="api/v1/ro/work-templates" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-work-templates', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-work-templates" onclick="tryItOut('GETapi-v1-ro-work-templates');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-work-templates" onclick="cancelTryOut('GETapi-v1-ro-work-templates');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-work-templates" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/work-templates</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-work-templates" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-work-templates" data-component="header"></label>
</p>
</form>


## WT Store a newly created work template.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/work-templates" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"doloremque","min_duration":6,"estimated_duration":11,"symbol":"omnis","cost":0.007775341,"extra_cost":381474940.7,"description":"quia","type":"rerum","price_type":"arcada","multi_factor_dentition":{"1":false,"2":false,"3":false,"4":false,"5":false,"6":false,"7":false}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "doloremque",
    "min_duration": 6,
    "estimated_duration": 11,
    "symbol": "omnis",
    "cost": 0.007775341,
    "extra_cost": 381474940.7,
    "description": "quia",
    "type": "rerum",
    "price_type": "arcada",
    "multi_factor_dentition": {
        "1": false,
        "2": false,
        "3": false,
        "4": false,
        "5": false,
        "6": false,
        "7": false
    }
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 268,
        "name": "In unde quibusdam aut est.",
        "min_duration": 8,
        "estimated_duration": 9,
        "cost": 6217.78,
        "extra_cost": 5222.37,
        "description": "Facilis reiciendis eum nobis est. Veritatis accusamus recusandae vero praesentium praesentium nihil. Rem maxime tempora sed odio.",
        "type": "",
        "price_type": "elemente",
        "symbol": "nulla",
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        }
    }
}
```
<div id="execution-results-POSTapi-v1-ro-work-templates" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-work-templates"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-work-templates"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-work-templates" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-work-templates"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-work-templates" data-method="POST" data-path="api/v1/ro/work-templates" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-work-templates', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-work-templates" onclick="tryItOut('POSTapi-v1-ro-work-templates');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-work-templates" onclick="cancelTryOut('POSTapi-v1-ro-work-templates');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-work-templates" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/work-templates</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-work-templates" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-work-templates" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>min_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="min_duration" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>estimated_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="estimated_duration" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>symbol</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="symbol" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="cost" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>extra_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="extra_cost" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>description</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="description" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="type" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>price_type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="price_type" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required  hidden>
<br>
The value must be one of <code>fix</code>, <code>elemente</code>, or <code>arcada</code>.
</p>
<p>
<details>
<summary>
<b><code>multi_factor_dentition</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>multi_factor_dentition.1</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.1" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.1" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.2</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.2" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.2" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.3</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.3" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.3" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.4</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.4" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.4" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.5</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.5" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.5" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.6</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.6" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.6" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.7</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.7" value="true" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-work-templates" hidden><input type="radio" name="multi_factor_dentition.7" value="false" data-endpoint="POSTapi-v1-ro-work-templates" data-component="body" required ><code>false</code></label>
<br>

</p>
</details>
</p>

</form>


## WT  Display a work template.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/work-templates/5" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates/5"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 269,
        "name": "Quas id libero non dolores.",
        "min_duration": 4,
        "estimated_duration": 6,
        "cost": 2190.84,
        "extra_cost": 5269.8,
        "description": "Modi consequuntur velit omnis porro sunt quisquam. Amet non omnis repellendus. Dignissimos optio hic voluptatem velit fugit. Et quo saepe autem iusto velit sit.",
        "type": "",
        "price_type": "arcada",
        "symbol": "hic",
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        }
    }
}
```
<div id="execution-results-GETapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-work-templates--work_template-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-work-templates--work_template-" data-method="GET" data-path="api/v1/ro/work-templates/{work_template}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-work-templates--work_template-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-work-templates--work_template-" onclick="tryItOut('GETapi-v1-ro-work-templates--work_template-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-work-templates--work_template-" onclick="cancelTryOut('GETapi-v1-ro-work-templates--work_template-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-work-templates--work_template-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/work-templates/{work_template}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-work-templates--work_template-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-work-templates--work_template-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_template</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template" data-endpoint="GETapi-v1-ro-work-templates--work_template-" data-component="url" required  hidden>
<br>

</p>
</form>


## WT Update a work template.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/work-templates/9" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"name":"repellendus","min_duration":9,"estimated_duration":17,"symbol":"voluptates","cost":4348392.66114,"extra_cost":41548690.18900383,"description":"officiis","type":"et","price_type":"arcada","multi_factor_dentition":{"1":false,"2":false,"3":false,"4":false,"5":false,"6":false,"7":false}}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates/9"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "name": "repellendus",
    "min_duration": 9,
    "estimated_duration": 17,
    "symbol": "voluptates",
    "cost": 4348392.66114,
    "extra_cost": 41548690.18900383,
    "description": "officiis",
    "type": "et",
    "price_type": "arcada",
    "multi_factor_dentition": {
        "1": false,
        "2": false,
        "3": false,
        "4": false,
        "5": false,
        "6": false,
        "7": false
    }
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 270,
        "name": "Et saepe beatae unde magnam.",
        "min_duration": 6,
        "estimated_duration": 5,
        "cost": 9133.05,
        "extra_cost": 8634.53,
        "description": "Nesciunt officia eos sit. Beatae deleniti corrupti nam ut nulla id. Quae ipsum ipsam accusantium laborum quo doloribus dolores maxime.",
        "type": "",
        "price_type": "elemente",
        "symbol": "aliquid",
        "multi_factor_dentition": {
            "1": true,
            "2": true,
            "3": true,
            "4": true,
            "5": true,
            "6": true,
            "7": true
        }
    }
}
```
<div id="execution-results-PUTapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-work-templates--work_template-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-work-templates--work_template-" data-method="PUT" data-path="api/v1/ro/work-templates/{work_template}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-work-templates--work_template-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-work-templates--work_template-" onclick="tryItOut('PUTapi-v1-ro-work-templates--work_template-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-work-templates--work_template-" onclick="cancelTryOut('PUTapi-v1-ro-work-templates--work_template-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-work-templates--work_template-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/work-templates/{work_template}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/work-templates/{work_template}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-work-templates--work_template-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_template</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="name" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>min_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="min_duration" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>estimated_duration</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="estimated_duration" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>symbol</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="symbol" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="cost" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>extra_cost</code></b>&nbsp;&nbsp;<small>number</small>  &nbsp;
<input type="number" name="extra_cost" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>description</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="description" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>type</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="type" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>price_type</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="price_type" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required  hidden>
<br>
The value must be one of <code>fix</code>, <code>elemente</code>, or <code>arcada</code>.
</p>
<p>
<details>
<summary>
<b><code>multi_factor_dentition</code></b>&nbsp;&nbsp;<small>object</small>     <i>optional</i> &nbsp;
<br>

</summary>
<br>
<p>
<b><code>multi_factor_dentition.1</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.1" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.1" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.2</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.2" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.2" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.3</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.3" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.3" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.4</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.4" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.4" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.5</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.5" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.5" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.6</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.6" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.6" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
<p>
<b><code>multi_factor_dentition.7</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.7" value="true" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-work-templates--work_template-" hidden><input type="radio" name="multi_factor_dentition.7" value="false" data-endpoint="PUTapi-v1-ro-work-templates--work_template-" data-component="body" required ><code>false</code></label>
<br>

</p>
</details>
</p>

</form>


## WT Remove a work template.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/work-templates/11" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates/11"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-work-templates--work_template-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-work-templates--work_template-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-work-templates--work_template-"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-work-templates--work_template-" data-method="DELETE" data-path="api/v1/ro/work-templates/{work_template}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-work-templates--work_template-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-work-templates--work_template-" onclick="tryItOut('DELETEapi-v1-ro-work-templates--work_template-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-work-templates--work_template-" onclick="cancelTryOut('DELETEapi-v1-ro-work-templates--work_template-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-work-templates--work_template-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/work-templates/{work_template}</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-work-templates--work_template-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-work-templates--work_template-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>work_template</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template" data-endpoint="DELETEapi-v1-ro-work-templates--work_template-" data-component="url" required  hidden>
<br>

</p>
</form>


## WT Reset all work templates.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X DELETE \
    "https://api.dentalsystem.ro/api/v1/ro/work-templates-reset" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates-reset"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "DELETE",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-DELETEapi-v1-ro-work-templates-reset" hidden>
    <blockquote>Received response<span id="execution-response-status-DELETEapi-v1-ro-work-templates-reset"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-DELETEapi-v1-ro-work-templates-reset"></code></pre>
</div>
<div id="execution-error-DELETEapi-v1-ro-work-templates-reset" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-DELETEapi-v1-ro-work-templates-reset"></code></pre>
</div>
<form id="form-DELETEapi-v1-ro-work-templates-reset" data-method="DELETE" data-path="api/v1/ro/work-templates-reset" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('DELETEapi-v1-ro-work-templates-reset', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-DELETEapi-v1-ro-work-templates-reset" onclick="tryItOut('DELETEapi-v1-ro-work-templates-reset');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-DELETEapi-v1-ro-work-templates-reset" onclick="cancelTryOut('DELETEapi-v1-ro-work-templates-reset');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-DELETEapi-v1-ro-work-templates-reset" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-red">DELETE</small>
 <b><code>api/v1/ro/work-templates-reset</code></b>
</p>
<p>
<label id="auth-DELETEapi-v1-ro-work-templates-reset" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="DELETEapi-v1-ro-work-templates-reset" data-component="header"></label>
</p>
</form>


## Clone a work template.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/work-templates-clone" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"work_template_id":11}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/work-templates-clone"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "work_template_id": 11
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-work-templates-clone" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-work-templates-clone"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-work-templates-clone"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-work-templates-clone" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-work-templates-clone"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-work-templates-clone" data-method="POST" data-path="api/v1/ro/work-templates-clone" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-work-templates-clone', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-work-templates-clone" onclick="tryItOut('POSTapi-v1-ro-work-templates-clone');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-work-templates-clone" onclick="cancelTryOut('POSTapi-v1-ro-work-templates-clone');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-work-templates-clone" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/work-templates-clone</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-work-templates-clone" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-work-templates-clone" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>work_template_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="work_template_id" data-endpoint="POSTapi-v1-ro-work-templates-clone" data-component="body" required  hidden>
<br>

</p>

</form>



