# Utilizatori

APIs for managing users

## Login a user.




> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/login" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"username":"itaque","password":"tempore"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/login"
);

let headers = {
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "username": "itaque",
    "password": "tempore"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-login" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-login"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-login"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-login" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-login"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-login" data-method="POST" data-path="api/v1/ro/login" data-authed="0" data-hasfiles="0" data-headers='{"Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-login', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-login" onclick="tryItOut('POSTapi-v1-ro-login');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-login" onclick="cancelTryOut('POSTapi-v1-ro-login');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-login" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/login</code></b>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>username</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="username" data-endpoint="POSTapi-v1-ro-login" data-component="body"  hidden>
<br>
required.
</p>
<p>
<b><code>password</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="password" name="password" data-endpoint="POSTapi-v1-ro-login" data-component="body"  hidden>
<br>
required.
</p>

</form>


## Logout logged user token.

<small class="badge badge-darkred">requires authentication</small>

Deletes token

> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/logout" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/logout"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "POST",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-POSTapi-v1-ro-logout" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-logout"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-logout"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-logout" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-logout"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-logout" data-method="POST" data-path="api/v1/ro/logout" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-logout', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-logout" onclick="tryItOut('POSTapi-v1-ro-logout');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-logout" onclick="cancelTryOut('POSTapi-v1-ro-logout');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-logout" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/logout</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-logout" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-logout" data-component="header"></label>
</p>
</form>


## Refresh token.

<small class="badge badge-darkred">requires authentication</small>

Deletes current token for user and generate 1 new

> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/refresh" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/refresh"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-GETapi-v1-ro-refresh" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-refresh"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-refresh"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-refresh" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-refresh"></code></pre>
</div>
<form id="form-GETapi-v1-ro-refresh" data-method="GET" data-path="api/v1/ro/refresh" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-refresh', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-refresh" onclick="tryItOut('GETapi-v1-ro-refresh');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-refresh" onclick="cancelTryOut('GETapi-v1-ro-refresh');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-refresh" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/refresh</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-refresh" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-refresh" data-component="header"></label>
</p>
</form>


## End the collaboration with the given user.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/users/tempore/end-collaboration" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"end_collaboration":false}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/users/tempore/end-collaboration"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "end_collaboration": false
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (401):

```json
{
    "message": "Necesita autentificare"
}
```
<div id="execution-results-PUTapi-v1-ro-users--user--end-collaboration" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-users--user--end-collaboration"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-users--user--end-collaboration"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-users--user--end-collaboration" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-users--user--end-collaboration"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-users--user--end-collaboration" data-method="PUT" data-path="api/v1/ro/users/{user}/end-collaboration" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-users--user--end-collaboration', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-users--user--end-collaboration" onclick="tryItOut('PUTapi-v1-ro-users--user--end-collaboration');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-users--user--end-collaboration" onclick="cancelTryOut('PUTapi-v1-ro-users--user--end-collaboration');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-users--user--end-collaboration" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/users/{user}/end-collaboration</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-users--user--end-collaboration" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>user</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="user" data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>end_collaboration</code></b>&nbsp;&nbsp;<small>boolean</small>  &nbsp;
<label data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" hidden><input type="radio" name="end_collaboration" value="true" data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" data-component="body" required ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" hidden><input type="radio" name="end_collaboration" value="false" data-endpoint="PUTapi-v1-ro-users--user--end-collaboration" data-component="body" required ><code>false</code></label>
<br>

</p>

</form>


## All possible users on specific client

<small class="badge badge-darkred">requires authentication</small>

This endpoint allows you to see all possible users on specific client

> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/users?sort=-id%2Cfirst_name%2Clast_name" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/users"
);

let params = {
    "sort": "-id,first_name,last_name",
};
Object.keys(params)
    .forEach(key => url.searchParams.append(key, params[key]));

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": [
        {
            "id": 352,
            "username": "ene.aurica",
            "username_identifier": null,
            "username_suffix": "aurica",
            "first_name": "Dinu",
            "last_name": "Tataru",
            "department": null,
            "mobile": "0742971515",
            "phone_fax": "0374599281",
            "email": "alin66@example.org",
            "website": "http:\/\/toader.info\/repudiandae-vero-omnis-optio.html",
            "address": "Splaiul Memorandumului 0A, Scornicești, Argeș, CP 428782",
            "status": "vacation",
            "profile_pic": null,
            "use_profile_pic": false,
            "roles_ids": [],
            "roles": [],
            "permissions": []
        },
        {
            "id": 353,
            "username": "oancea.horia",
            "username_identifier": null,
            "username_suffix": "horia",
            "first_name": "Georgeta",
            "last_name": "Cristescu",
            "department": null,
            "mobile": "0736797059",
            "phone_fax": "0759848248",
            "email": "rica.alexe@example.net",
            "website": "http:\/\/ionescu.com\/velit-molestiae-dignissimos-eos-provident-vitae-ipsa",
            "address": "P-ța Sinaia nr. 7A, bl. C, sc. A, et. 67, ap. 7, Mun. Sighișoara, Galați, CP 525452",
            "status": "active",
            "profile_pic": null,
            "use_profile_pic": false,
            "roles_ids": [],
            "roles": [],
            "permissions": []
        }
    ]
}
```
<div id="execution-results-GETapi-v1-ro-users" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-users"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-users"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-users" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-users"></code></pre>
</div>
<form id="form-GETapi-v1-ro-users" data-method="GET" data-path="api/v1/ro/users" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-users', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-users" onclick="tryItOut('GETapi-v1-ro-users');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-users" onclick="cancelTryOut('GETapi-v1-ro-users');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-users" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/users</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-users" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-users" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Query Parameters</b></h4>
<p>
<b><code>sort</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="sort" data-endpoint="GETapi-v1-ro-users" data-component="query"  hidden>
<br>
Field to sort by. Sorting ASC id Sorting DESC -id
</p>
</form>


## Store a newly created user.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/users" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"username_suffix":"quia","first_name":"ex","last_name":"blanditiis","department_id":17,"phone_fax":"ut","mobile":"vel","email":"nova.metz@example.com","website":"http:\/\/www.blanda.info\/","address":"et","status":"vacation","use_profile_pic":false,"roles_ids":[15,19],"password":"sint","password_confirmation":"sit"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/users"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "username_suffix": "quia",
    "first_name": "ex",
    "last_name": "blanditiis",
    "department_id": 17,
    "phone_fax": "ut",
    "mobile": "vel",
    "email": "nova.metz@example.com",
    "website": "http:\/\/www.blanda.info\/",
    "address": "et",
    "status": "vacation",
    "use_profile_pic": false,
    "roles_ids": [
        15,
        19
    ],
    "password": "sint",
    "password_confirmation": "sit"
}

fetch(url, {
    method: "POST",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 354,
        "username": "mchirita",
        "username_identifier": null,
        "username_suffix": null,
        "first_name": "Gicu",
        "last_name": "Grigoras",
        "department": null,
        "mobile": "0340228904",
        "phone_fax": "0747131982",
        "email": "costache99@example.com",
        "website": "https:\/\/www.ichim.com\/ducimus-nemo-mollitia-magni-deleniti-quis-doloribus-omnis",
        "address": "Calea Cireșilor nr. 0A, bl. 8, et. 08, ap. 80, Mun. Rădăuți, Harghita, CP 300060",
        "status": "vacation",
        "profile_pic": null,
        "use_profile_pic": true,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-POSTapi-v1-ro-users" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-users"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-users"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-users" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-users"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-users" data-method="POST" data-path="api/v1/ro/users" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-users', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-users" onclick="tryItOut('POSTapi-v1-ro-users');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-users" onclick="cancelTryOut('POSTapi-v1-ro-users');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-users" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/users</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-users" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-users" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>username_suffix</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="username_suffix" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>department_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="department_id" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>website</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="website" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>
The value must be a valid URL.
</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>status</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="status" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>
The value must be one of <code>active</code> or <code>vacation</code>.
</p>
<p>
<b><code>use_profile_pic</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="POSTapi-v1-ro-users" hidden><input type="radio" name="use_profile_pic" value="true" data-endpoint="POSTapi-v1-ro-users" data-component="body" ><code>true</code></label>
<label data-endpoint="POSTapi-v1-ro-users" hidden><input type="radio" name="use_profile_pic" value="false" data-endpoint="POSTapi-v1-ro-users" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>roles_ids</code></b>&nbsp;&nbsp;<small>integer[]</small>  &nbsp;
<input type="number" name="roles_ids.0" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<input type="number" name="roles_ids.1" data-endpoint="POSTapi-v1-ro-users" data-component="body" hidden>
<br>

</p>
<p>
<b><code>password</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="password" name="password" data-endpoint="POSTapi-v1-ro-users" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>password_confirmation</code></b>&nbsp;&nbsp;<small>required</small>     <i>optional</i> &nbsp;
<input type="password" name="password_confirmation" data-endpoint="POSTapi-v1-ro-users" data-component="body"  hidden>
<br>

</p>

</form>


## Display a user.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/users/16" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/users/16"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 355,
        "username": "lorin22",
        "username_identifier": null,
        "username_suffix": null,
        "first_name": "Nichifor",
        "last_name": "Tataru",
        "department": null,
        "mobile": "0318407005",
        "phone_fax": "0253113528",
        "email": "nicoleta84@example.com",
        "website": "http:\/\/gherman.com\/corrupti-repellendus-exercitationem-dolores-fugit-et-aperiam.html",
        "address": "Calea Cloșca 5\/8, Brad, Bacău, CP 220125",
        "status": "active",
        "profile_pic": null,
        "use_profile_pic": true,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-GETapi-v1-ro-users--user-" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-users--user-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-users--user-"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-users--user-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-users--user-"></code></pre>
</div>
<form id="form-GETapi-v1-ro-users--user-" data-method="GET" data-path="api/v1/ro/users/{user}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-users--user-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-users--user-" onclick="tryItOut('GETapi-v1-ro-users--user-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-users--user-" onclick="cancelTryOut('GETapi-v1-ro-users--user-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-users--user-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/users/{user}</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-users--user-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-users--user-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>user</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="user" data-endpoint="GETapi-v1-ro-users--user-" data-component="url" required  hidden>
<br>

</p>
</form>


## Update  a user.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/users/2" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"username_suffix":"iure","first_name":"distinctio","last_name":"at","department_id":17,"phone_fax":"ut","mobile":"dignissimos","email":"dakota47@example.org","website":"http:\/\/moore.com\/aspernatur-autem-cum-nam-sunt-recusandae.html","address":"non","status":"active","use_profile_pic":false,"roles_ids":[18,17],"password":"qui","password_confirmation":"quisquam"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/users/2"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "username_suffix": "iure",
    "first_name": "distinctio",
    "last_name": "at",
    "department_id": 17,
    "phone_fax": "ut",
    "mobile": "dignissimos",
    "email": "dakota47@example.org",
    "website": "http:\/\/moore.com\/aspernatur-autem-cum-nam-sunt-recusandae.html",
    "address": "non",
    "status": "active",
    "use_profile_pic": false,
    "roles_ids": [
        18,
        17
    ],
    "password": "qui",
    "password_confirmation": "quisquam"
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 356,
        "username": "valter.moldoveanu",
        "username_identifier": null,
        "username_suffix": "moldoveanu",
        "first_name": "Pamfil",
        "last_name": "Stroe",
        "department": null,
        "mobile": "0232691363",
        "phone_fax": "0775299335",
        "email": "ostroe@example.com",
        "website": "http:\/\/manole.com\/quos-ea-est-alias-numquam-voluptatem",
        "address": "Str. Mihai Eminescu 3B, Mun. Făgăraș, Giurgiu, CP 640927",
        "status": "vacation",
        "profile_pic": null,
        "use_profile_pic": true,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-PUTapi-v1-ro-users--user-" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-users--user-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-users--user-"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-users--user-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-users--user-"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-users--user-" data-method="PUT" data-path="api/v1/ro/users/{user}" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-users--user-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-users--user-" onclick="tryItOut('PUTapi-v1-ro-users--user-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-users--user-" onclick="cancelTryOut('PUTapi-v1-ro-users--user-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-users--user-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/users/{user}</code></b>
</p>
<p>
<small class="badge badge-purple">PATCH</small>
 <b><code>api/v1/ro/users/{user}</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-users--user-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-users--user-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>user</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="user" data-endpoint="PUTapi-v1-ro-users--user-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>username_suffix</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="username_suffix" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>department_id</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="department_id" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>website</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="website" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>
The value must be a valid URL.
</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>status</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="status" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<br>
The value must be one of <code>active</code> or <code>vacation</code>.
</p>
<p>
<b><code>use_profile_pic</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="PUTapi-v1-ro-users--user-" hidden><input type="radio" name="use_profile_pic" value="true" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-users--user-" hidden><input type="radio" name="use_profile_pic" value="false" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>roles_ids</code></b>&nbsp;&nbsp;<small>integer[]</small>  &nbsp;
<input type="number" name="roles_ids.0" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" required  hidden>
<input type="number" name="roles_ids.1" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body" hidden>
<br>

</p>
<p>
<b><code>password</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="password" name="password" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>password_confirmation</code></b>&nbsp;&nbsp;<small>required</small>     <i>optional</i> &nbsp;
<input type="password" name="password_confirmation" data-endpoint="PUTapi-v1-ro-users--user-" data-component="body"  hidden>
<br>

</p>

</form>


## Logged user profile.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X GET \
    -G "https://api.dentalsystem.ro/api/v1/ro/user" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json"
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/user"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};


fetch(url, {
    method: "GET",
    headers,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 357,
        "username": "margareta.soare",
        "username_identifier": null,
        "username_suffix": "soare",
        "first_name": "Anemona",
        "last_name": "Nicolae",
        "department": null,
        "mobile": "0360262595",
        "phone_fax": "0215431802",
        "email": "clementina84@example.org",
        "website": "https:\/\/www.horvath.net\/quasi-laboriosam-dolor-minus-repudiandae-expedita-qui",
        "address": "B-dul. Zidarilor 6A, Jibou, Olt, CP 484382",
        "status": "vacation",
        "profile_pic": null,
        "use_profile_pic": false,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-GETapi-v1-ro-user" hidden>
    <blockquote>Received response<span id="execution-response-status-GETapi-v1-ro-user"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-GETapi-v1-ro-user"></code></pre>
</div>
<div id="execution-error-GETapi-v1-ro-user" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-GETapi-v1-ro-user"></code></pre>
</div>
<form id="form-GETapi-v1-ro-user" data-method="GET" data-path="api/v1/ro/user" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('GETapi-v1-ro-user', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-GETapi-v1-ro-user" onclick="tryItOut('GETapi-v1-ro-user');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-GETapi-v1-ro-user" onclick="cancelTryOut('GETapi-v1-ro-user');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-GETapi-v1-ro-user" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-green">GET</small>
 <b><code>api/v1/ro/user</code></b>
</p>
<p>
<label id="auth-GETapi-v1-ro-user" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="GETapi-v1-ro-user" data-component="header"></label>
</p>
</form>


## Update logged user profile.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X PUT \
    "https://api.dentalsystem.ro/api/v1/ro/user" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: application/json" \
    -H "Accept: application/json" \
    -d '{"first_name":"officiis","last_name":"velit","phone_fax":"laudantium","mobile":"illum","email":"kip79@example.com","website":"http:\/\/www.bahringer.com\/quas-rerum-qui-voluptas-consequuntur-expedita-labore","address":"hic","status":"vacation","use_profile_pic":false,"password":"autem","password_confirmation":"eius"}'

```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/user"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "application/json",
    "Accept": "application/json",
};

let body = {
    "first_name": "officiis",
    "last_name": "velit",
    "phone_fax": "laudantium",
    "mobile": "illum",
    "email": "kip79@example.com",
    "website": "http:\/\/www.bahringer.com\/quas-rerum-qui-voluptas-consequuntur-expedita-labore",
    "address": "hic",
    "status": "vacation",
    "use_profile_pic": false,
    "password": "autem",
    "password_confirmation": "eius"
}

fetch(url, {
    method: "PUT",
    headers,
    body: JSON.stringify(body),
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 358,
        "username": "micu.grigore",
        "username_identifier": null,
        "username_suffix": "grigore",
        "first_name": "Emilia",
        "last_name": "Nicolae",
        "department": null,
        "mobile": "0248260963",
        "phone_fax": "0364381992",
        "email": "ana45@example.org",
        "website": "http:\/\/www.botezatu.com\/earum-numquam-et-blanditiis-officia-voluptatem.html",
        "address": "Aleea Mihai Viteazul 96, Mun. Târgu Lăpuș, Cluj, CP 156815",
        "status": "active",
        "profile_pic": null,
        "use_profile_pic": false,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-PUTapi-v1-ro-user" hidden>
    <blockquote>Received response<span id="execution-response-status-PUTapi-v1-ro-user"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-PUTapi-v1-ro-user"></code></pre>
</div>
<div id="execution-error-PUTapi-v1-ro-user" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-PUTapi-v1-ro-user"></code></pre>
</div>
<form id="form-PUTapi-v1-ro-user" data-method="PUT" data-path="api/v1/ro/user" data-authed="1" data-hasfiles="0" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"application\/json","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('PUTapi-v1-ro-user', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-PUTapi-v1-ro-user" onclick="tryItOut('PUTapi-v1-ro-user');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-PUTapi-v1-ro-user" onclick="cancelTryOut('PUTapi-v1-ro-user');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-PUTapi-v1-ro-user" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-darkblue">PUT</small>
 <b><code>api/v1/ro/user</code></b>
</p>
<p>
<label id="auth-PUTapi-v1-ro-user" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="PUTapi-v1-ro-user" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>first_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="first_name" data-endpoint="PUTapi-v1-ro-user" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>last_name</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="last_name" data-endpoint="PUTapi-v1-ro-user" data-component="body" required  hidden>
<br>

</p>
<p>
<b><code>phone_fax</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="phone_fax" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>mobile</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="mobile" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>email</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="email" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>
Câmpul value trebuie să fie o adresă de e-mail validă.
</p>
<p>
<b><code>website</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="website" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>
The value must be a valid URL.
</p>
<p>
<b><code>address</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="text" name="address" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>status</code></b>&nbsp;&nbsp;<small>string</small>  &nbsp;
<input type="text" name="status" data-endpoint="PUTapi-v1-ro-user" data-component="body" required  hidden>
<br>
The value must be one of <code>active</code> or <code>vacation</code>.
</p>
<p>
<b><code>use_profile_pic</code></b>&nbsp;&nbsp;<small>boolean</small>     <i>optional</i> &nbsp;
<label data-endpoint="PUTapi-v1-ro-user" hidden><input type="radio" name="use_profile_pic" value="true" data-endpoint="PUTapi-v1-ro-user" data-component="body" ><code>true</code></label>
<label data-endpoint="PUTapi-v1-ro-user" hidden><input type="radio" name="use_profile_pic" value="false" data-endpoint="PUTapi-v1-ro-user" data-component="body" ><code>false</code></label>
<br>

</p>
<p>
<b><code>password</code></b>&nbsp;&nbsp;<small>string</small>     <i>optional</i> &nbsp;
<input type="password" name="password" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>

</p>
<p>
<b><code>password_confirmation</code></b>&nbsp;&nbsp;<small>required</small>     <i>optional</i> &nbsp;
<input type="password" name="password_confirmation" data-endpoint="PUTapi-v1-ro-user" data-component="body"  hidden>
<br>

</p>

</form>


## Update user&#039;s profile picture.

<small class="badge badge-darkred">requires authentication</small>



> Example request:

```bash
curl -X POST \
    "https://api.dentalsystem.ro/api/v1/ro/user-profile-photo/5" \
    -H "Authorization: Bearer {YOUR_TOKEN}" \
    -H "Content-Type: multipart/form-data" \
    -H "Accept: application/json" \
    -F "picture=@C:\Users\WORK\AppData\Local\Temp\phpBBCC.tmp" 
```

```javascript
const url = new URL(
    "https://api.dentalsystem.ro/api/v1/ro/user-profile-photo/5"
);

let headers = {
    "Authorization": "Bearer {YOUR_TOKEN}",
    "Content-Type": "multipart/form-data",
    "Accept": "application/json",
};

const body = new FormData();
body.append('picture', document.querySelector('input[name="picture"]').files[0]);

fetch(url, {
    method: "POST",
    headers,
    body,
}).then(response => response.json());
```


> Example response (200):

```json
{
    "data": {
        "id": 359,
        "username": "neagu.marian",
        "username_identifier": null,
        "username_suffix": "marian",
        "first_name": "Alina",
        "last_name": "Zamfir",
        "department": null,
        "mobile": "0758177509",
        "phone_fax": "0709474306",
        "email": "bartolomeu38@example.net",
        "website": "http:\/\/sirbu.com\/",
        "address": "Aleea Unirii 31, Arad, Neamț, CP 350178",
        "status": "active",
        "profile_pic": null,
        "use_profile_pic": false,
        "roles_ids": [],
        "roles": [],
        "permissions": []
    }
}
```
<div id="execution-results-POSTapi-v1-ro-user-profile-photo--user-" hidden>
    <blockquote>Received response<span id="execution-response-status-POSTapi-v1-ro-user-profile-photo--user-"></span>:</blockquote>
    <pre class="json"><code id="execution-response-content-POSTapi-v1-ro-user-profile-photo--user-"></code></pre>
</div>
<div id="execution-error-POSTapi-v1-ro-user-profile-photo--user-" hidden>
    <blockquote>Request failed with error:</blockquote>
    <pre><code id="execution-error-message-POSTapi-v1-ro-user-profile-photo--user-"></code></pre>
</div>
<form id="form-POSTapi-v1-ro-user-profile-photo--user-" data-method="POST" data-path="api/v1/ro/user-profile-photo/{user}" data-authed="1" data-hasfiles="1" data-headers='{"Authorization":"Bearer {YOUR_TOKEN}","Content-Type":"multipart\/form-data","Accept":"application\/json"}' onsubmit="event.preventDefault(); executeTryOut('POSTapi-v1-ro-user-profile-photo--user-', this);">
<h3>
    Request&nbsp;&nbsp;&nbsp;
        <button type="button" style="background-color: #8fbcd4; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-tryout-POSTapi-v1-ro-user-profile-photo--user-" onclick="tryItOut('POSTapi-v1-ro-user-profile-photo--user-');">Try it out ⚡</button>
    <button type="button" style="background-color: #c97a7e; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-canceltryout-POSTapi-v1-ro-user-profile-photo--user-" onclick="cancelTryOut('POSTapi-v1-ro-user-profile-photo--user-');" hidden>Cancel</button>&nbsp;&nbsp;
    <button type="submit" style="background-color: #6ac174; padding: 5px 10px; border-radius: 5px; border-width: thin;" id="btn-executetryout-POSTapi-v1-ro-user-profile-photo--user-" hidden>Send Request 💥</button>
    </h3>
<p>
<small class="badge badge-black">POST</small>
 <b><code>api/v1/ro/user-profile-photo/{user}</code></b>
</p>
<p>
<label id="auth-POSTapi-v1-ro-user-profile-photo--user-" hidden>Authorization header: <b><code>Bearer </code></b><input type="text" name="Authorization" data-prefix="Bearer " data-endpoint="POSTapi-v1-ro-user-profile-photo--user-" data-component="header"></label>
</p>
<h4 class="fancy-heading-panel"><b>URL Parameters</b></h4>
<p>
<b><code>user</code></b>&nbsp;&nbsp;<small>integer</small>  &nbsp;
<input type="number" name="user" data-endpoint="POSTapi-v1-ro-user-profile-photo--user-" data-component="url" required  hidden>
<br>

</p>
<h4 class="fancy-heading-panel"><b>Body Parameters</b></h4>
<p>
<b><code>picture</code></b>&nbsp;&nbsp;<small>file</small>     <i>optional</i> &nbsp;
<input type="file" name="picture" data-endpoint="POSTapi-v1-ro-user-profile-photo--user-" data-component="body"  hidden>
<br>

</p>

</form>



