<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <style>
        {{ include public_path() . '/pdf/css/invoice.css' }}

    </style>

    <style>
        @font-face {
            font-family: Roboto;
            src: url("{{ public_path('pdf/fonts/Roboto.ttf') }}") format("truetype");
        }

    </style>

    <title>Factura {{ $invoice->invoice_series }} {{ $invoice->invoice_no }}</title>
</head>

<body style="font-family: Roboto, sans-serif;">
    <div class="container wrapper">
        <div class="card stretch-card">
            <div class="card-body">
                <div id="invoice">
                    <div class="invoice">
                        <div class="invoice-wrapper" style="min-width: 600px">
                            <header>
                                <table width="100%">
                                    <tr>
                                        <td class="lab-logo">
                                            <img src="{{ public_path('pdf/images/dentallab_logo.png') }}" alt="">
                                        </td>
                                        <td class="company-details">
                                            <div class="text-gray-light">Furnizor:</div>
                                            <h2 class="name">
                                                {{ Str::upper($invoice->lab_invoice_profile_name) }}
                                            </h2>
                                            <div>Reg. com: {{ $invoice->lab_invoice_profile_nr_reg_comertului }}</div>
                                            <div>CIF: {{ $invoice->lab_invoice_profile_cui }}</div>
                                            <div>Adresa: {{ $invoice->lab_invoice_profile_address }},
                                                {{ $invoice->lab_invoice_profile_city }}
                                            </div>
                                            <div>IBAN: {{ $invoice->lab_invoice_profile_bank_account }}</div>
                                            <div>BANCA: {{ $invoice->lab_invoice_profile_bank }}</div>
                                        </td>
                                    </tr>
                                </table>

                                <div class="divider"></div>

                                <table class="contacts" width="100%">
                                    <tr>
                                        <td class="col invoice-to">
                                            <div class="text-gray-light">Client:</div>
                                            <h2 class="to">
                                                {{ Str::upper($invoice->collaborator_name) }}
                                            </h2>
                                            <div class="">Reg. com:
                                                {{ $invoice->collaborator_nr_reg_comertului }}
                                            </div>
                                            <div class="address">CIF: {{ $invoice->collaborator_cui }}</div>
                                            <div class="address">
                                                Adresa: {{ $invoice->collaborator_address }},
                                                {{ $invoice->collaborator_city }}
                                            </div>
                                        </td>
                                        <td class="col invoice-details">
                                            <div class="text-gray-light">Factura:</div>
                                            <h1 class="invoice-id">{{ $invoice->invoice_series }}
                                                {{ $invoice->invoice_no }}
                                            </h1>
                                            <div class="date">Date emiterii: {{ $date }}</div>
                                            <div class="date">TVA la incasare: {{ $vat * 100 }}%</div>
                                        </td>
                                    </tr>
                                </table>
                            </header>
                            <main>
                                <table class="table">
                                    <thead>
                                        <tr>
                                            <th>Nr.</th>
                                            <th class="text-left">Denumire produs/serviciu</th>
                                            <th class="text-right">Cant.</th>
                                            <th class="text-right">Preț unitar</th>
                                            <th class="text-right">Valoare</th>
                                            <th class="text-right">TVA</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($invoiceJson->services as $service)
                                            @if ($service->amount > 0)
                                                <tr>
                                                    <td class="no">{{ ++$i }}</td>
                                                    <td class="text-left">{{ $service->service_name }}</td>
                                                    <td class="qty">{{ $service->amount }}</td>
                                                    <td class="unit">{{ $service->unit_price }}</td>
                                                    <td class="value">
                                                        {{ number_format($service->unit_price * $service->amount, 2, '.', ',') }}
                                                    </td>
                                                    <td class="tva">
                                                        {{ number_format($service->unit_price * $service->amount * $vat, 2, '.', ',') }}
                                                    </td>
                                                </tr>
                                            @endif
                                        @endforeach

                                        @foreach ($discounts as $discount)
                                            @if ($discount->value > 0)
                                                <tr>
                                                    <td class="no">{{ ++$i }}</td>
                                                    <td class="text-left">{{ $discount->name }}</td>
                                                    <td class="qty"> 1 </td>
                                                    <td class="unit">
                                                        {{ number_format(-1 * abs($discount->value), 2, '.', ',') }}
                                                    </td>
                                                    <td class="value">
                                                        {{ number_format(-1 * abs($discount->value), 2, '.', ',') }}
                                                    </td>
                                                    <td class="tva">
                                                        {{ number_format(-1 * abs($discount->value) * $vat, 2, '.', ',') }}
                                                    </td>
                                                </tr>
                                            @endif
                                        @endforeach
                                    </tbody>

                                    <tfoot>
                                        <tr>
                                            <td colspan="3"></td>
                                            <td colspan="2">SUBTOTAL</td>
                                            <td>
                                                {{ number_format($total - $discounts->sum('value') ?? 0, 2, '.', ',') }}
                                            </td>
                                        </tr>
                                        <tr>
                                            <td colspan="3"></td>
                                            <td colspan="2">TVA {{ $vat * 100 }}%</td>
                                            <td>
                                                {{ number_format(($total - $discounts->sum('value') ?? 0) * $vat, 2, '.', ',') }}
                                            </td>
                                        </tr>
                                        <tr>
                                            <td colspan="3"></td>
                                            <td colspan="2">TOTAL PLATA</td>
                                            <td>
                                                {{ number_format(($total - $discounts->sum('value') ?? 0) + ($total - $discounts->sum('value') ?? 0) * $vat, 2, '.', ',') }}
                                            </td>
                                        </tr>
                                    </tfoot>
                                </table>
                            </main>

                            <footer>
                                <div class="divider"></div>
                                <span>
                                    Factura valabilă fără semnătură şi ştampilă cf. art.V, alin (2) din Ordonanţa
                                    nr.17/2015 şi art. 319 alin (29) din Legea nr. 227/2015 privind Codul fiscal.
                                </span>
                            </footer>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</body>

</html>
