<?php

declare(strict_types=1);

use App\Configuration\LabConfiguration;
use App\Http\Controllers\AdditionalPricesBrandController;
use App\Http\Controllers\AdditionalPricesCategoryController;
use App\Http\Controllers\AdditionalPricesProductController;
use App\Http\Controllers\Api\AuthController;
use App\Http\Controllers\CalendarOrderStagesController;
use App\Http\Controllers\CollaboratorController;
use App\Http\Controllers\CollaboratorPriceController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\DentistController;
use App\Http\Controllers\DentistPriceController;
use App\Http\Controllers\DepartmentController;
use App\Http\Controllers\DiscountTypeController;
use App\Http\Controllers\DiscountController;
use App\Http\Controllers\InvoiceSeriesController;
use App\Http\Controllers\ReceiptSeriesController;
use App\Http\Controllers\LabInvoiceProfileController;
use App\Http\Controllers\LabProfileController;
use App\Http\Controllers\OrderAdditionalPriceController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\OrderFilesController;
use App\Http\Controllers\OrderWorkStageController;
use App\Http\Controllers\OrderWorkTemplateController;
use App\Http\Controllers\PatientController;
use App\Http\Controllers\PaymentDocumentsController;
use App\Http\Controllers\PermissionController;
use App\Http\Controllers\RegionController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\WorkStageController;
use App\Http\Controllers\WorkStageUserController;
use App\Http\Controllers\WorkTemplateController;
use App\Http\Controllers\WorkTemplateStageController;
use App\Http\Controllers\WorkTemplateStageUserController;
use App\Http\Middleware\GetIdentifierFromLogin;
use App\Http\Middleware\GetIdentifierFromToken;
use Illuminate\Support\Facades\Route;
use Stancl\Tenancy\Middleware\InitializeTenancyByRequestData;
use Stancl\Tenancy\Middleware\PreventAccessFromCentralDomains;
use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\ReceiptController;

/*
|--------------------------------------------------------------------------
| Tenant Routes
|--------------------------------------------------------------------------
|
| Here you can register the tenant routes for your application.
| These routes are loaded by the TenantRouteServiceProvider.
|
| Feel free to customize them however you want. Good luck!
|
*/

//todo check if it needs deleted/accessible on limited IP's
//Route::get('api/possible-customers-usernames', [UserController::class, "allCustomersIdsIfDebugOn"]);

Route::middleware(
    [
        //   'debugbar',//in case you want extra profiling data about route you are visiting
        'api',
        GetIdentifierFromLogin::class,
        InitializeTenancyByRequestData::class,
        PreventAccessFromCentralDomains::class,
        //used to log user activity
        \App\Http\Middleware\Logging::class
    ]
)->prefix('api')->group(
    function () {
        Route::prefix('v1')->group(
            function () {
                Route::prefix('ro')->group(
                    function () {
                        Route::post("login", [AuthController::class, "login"]);
                        Route::post("register", [AuthController::class, "register"]);
                    }
                );
            }
        );
    }
);

Route::middleware(
    [
        //   'debugbar',//in case you want extra profiling data about route you are visiting
        'api',
        GetIdentifierFromToken::class,
        InitializeTenancyByRequestData::class,
        PreventAccessFromCentralDomains::class,
    ]
)->prefix('api')->group(
    function () {

        //v1
        Route::prefix('v1')->group(
            function () {

                //lang ro not implemented yet automatic change of language 29/04/2021
                Route::prefix('ro')->group(
                    function () {
                        Route::get(
                            '/',
                            function () {
                                return 'The current tenant is >>>> ' . tenant()->id . ' <<<<<<';
                            }
                        );

                        Route::group(
                            ['name' => ['configurations']],
                            function () {
                                Route::get("work-stage-types", [LabConfiguration::class, 'workStageTypes']);
                                Route::get("work-templates-price-types", [LabConfiguration::class, 'workTemplatesPriceTypes']);
                                Route::get("user-statuses", [LabConfiguration::class, 'userStatuses']);
                                Route::get("order-statuses", [LabConfiguration::class, 'orderStatuses']);
                                Route::get("ows-special-stages", [LabConfiguration::class, 'getOrderWorkStageSpecialStages']);
                                //todo to be clarified what statuses can have a stage and put them in configuration
                                //                                Route::get("owstage-statuses", [LabConfiguration::class, 'orderStageStatuses']);
                            }
                        );


                        Route::group(
                            ['middleware' => ['auth:sanctum']],
                            function () {
                                Route::post("logout", [AuthController::class, "logout"]);
                                Route::get("refresh", [AuthController::class, 'refresh']);
                                //roles
                                Route::apiResource('roles', RoleController::class);
                                //departments
                                Route::apiResource('departments', DepartmentController::class);
                                //permissions
                                Route::get('permissions-list', [PermissionController::class, 'indexList']);
                                Route::get('permissions-detailed', [PermissionController::class, 'indexDetailedParsed']);
                                Route::get('permission/{permission_name}', [PermissionController::class, 'showDetailed']);
                                //users
                                Route::put('users/{user}/end-collaboration', [UserController::class, 'endCollaboration']);
                                Route::apiResource('users', UserController::class)->except(['destroy']);
                                Route::get('user', [UserController::class, 'selfProfile']);
                                Route::put('user', [UserController::class, 'selfProfileUpdate']);
                                Route::post("user-profile-photo/{user}", [UserController::class, 'updateProfilePhoto']);
                                //regions
                                Route::apiResource('regions', RegionController::class)->except(['destroy']);
                                //patients
                                Route::apiResource('patients', PatientController::class);
                                //dentists
                                Route::apiResource('dentists', DentistController::class);
                                //dentist collaborators
                                Route::post('dentist-collaborators-listing', [DentistController::class, 'indexCollaborators']);
                                Route::post('dentist-collaborators', [DentistController::class, 'storeCollaborator']);
                                Route::delete('dentist-collaborators', [DentistController::class, 'destroyCollaborator']);
                                //dentist prices
                                Route::post('dentist-prices-listing', [DentistPriceController::class, 'index']);
                                Route::put('dentist-prices', [DentistPriceController::class, 'storeOrUpdate']);
                                Route::delete('dentist-prices', [DentistPriceController::class, 'destroy']);
                                //collaborators
                                Route::post('collaborators/import-collaborator', [CollaboratorController::class, 'importCollaborator']);
                                Route::apiResource('collaborators', CollaboratorController::class);
                                //collaborator prices
                                Route::post('collaborator-prices-listing', [CollaboratorPriceController::class, 'index']);
                                Route::put('collaborator-prices', [CollaboratorPriceController::class, 'storeOrUpdate']);
                                Route::delete('collaborator-prices', [CollaboratorPriceController::class, 'destroy']);

                                //work-stages
                                Route::apiResource('work-stages', WorkStageController::class);
                                Route::delete('work-stages-reset', [WorkStageController::class, 'resetWorkStages']);

                                //work-stage-users
                                Route::apiResource('work-stage-users', WorkStageUserController::class)->except(['index', 'show', 'update']);
                                Route::put('work-stage-users', [WorkStageUserController::class, 'updateWorkStageUsers'])->name(
                                    'work-stage-users.update'
                                );
                                Route::get('work-stage-users-listing/{work_stage}', [WorkStageUserController::class, 'index'])->name(
                                    'work-stage.work-stage-users'
                                );

                                //lab profile
                                Route::get("lab-profile", [LabProfileController::class, 'show']);
                                Route::put("lab-profile", [LabProfileController::class, 'update']);
                                Route::put("lab-profile-settings", [LabProfileController::class, 'updateSettings']);
                                Route::post("lab-profile-logo-and-cover", [LabProfileController::class, 'updateLogoAndCover']);
                                Route::post("lab-profile-additional-details", [LabProfileController::class, 'updateAdditionalDetails']);

                                //lab invoice profile
                                Route::apiResource("lab-invoice-profiles", LabInvoiceProfileController::class);
                                Route::post(
                                    "lab-invoice-profile-logo-and-cover/{lab_invoice_profile}",
                                    [LabInvoiceProfileController::class, 'updateLogoAndCover']
                                );
                                Route::post(
                                    "default-lab-invoice-profile/{lab_invoice_profile}",
                                    [LabInvoiceProfileController::class, 'makeDefaultInvoiceProfile']
                                )->name('lab-invoice-profile.make.default');

                                //work-templates
                                Route::apiResource('work-templates', WorkTemplateController::class);
                                Route::delete('work-templates-reset', [WorkTemplateController::class, 'resetWorkTemplates']);
                                Route::post('work-templates-clone', [WorkTemplateController::class, 'cloneWorkTemplates']);

                                //work templates stages
                                Route::post('work-template-stages-listing', [WorkTemplateStageController::class, 'index']);
                                Route::post('work-template-stages', [WorkTemplateStageController::class, 'store']);
                                Route::delete('work-template-stages', [WorkTemplateStageController::class, 'destroy']);
                                Route::put('work-template-stages', [WorkTemplateStageController::class, 'updateWorkTemplateStages'])->name(
                                    'work-template-stages.update'
                                );
                                Route::put('work-template-stages/update-day-number', [WorkTemplateStageController::class, 'updateWTStageDayNumber']);

                                //work templates stage users
                                Route::post('work-template-stage-users-listing', [WorkTemplateStageUserController::class, 'index']);
                                Route::post('work-template-stage-users', [WorkTemplateStageUserController::class, 'store']);
                                Route::delete('work-template-stage-users', [WorkTemplateStageUserController::class, 'destroy']);
                                Route::put('work-template-stage-users', [WorkTemplateStageUserController::class, 'updateWorkTemplateStageUsers'])->name('work-template-stage-users.update');

                                //discount types
                                Route::apiResource('discount-types', DiscountTypeController::class)->except(['destroy']);

                                //discounts
                                Route::post('payment-documents/discounts/{payment_document}', [DiscountController::class, 'store']);
                                Route::delete('payment-documents/discounts/{payment_document}', [DiscountController::class, 'destroy']);

                                //invoices
                                Route::apiResource('invoices', InvoiceController::class)->except(['update', 'destroy']);
                                Route::get('invoices/{invoice}/generate-pdf', [InvoiceController::class, 'generateInvoicePdf']);

                                //invoice series
                                Route::apiResource('invoice-series', InvoiceSeriesController::class)->except(['index', 'update', 'show']);
                                Route::get('invoice-series/{lab_invoice_profile_id?}', [InvoiceSeriesController::class, 'index']);
                                Route::post('invoice-series/activate/{invoice_series}', [InvoiceSeriesController::class, 'activate']);

                                // receipts
                                Route::apiResource('receipts', ReceiptController::class)->except(['update', 'destroy']);
                                Route::get('receipts/{payment}/generate-pdf', [ReceiptController::class, 'generateReceiptPdf']);

                                //receipt series
                                Route::apiResource('receipt-series', ReceiptSeriesController::class)->except(['index', 'update', 'show']);
                                Route::get('receipt-series/{lab_invoice_profile_id?}', [ReceiptSeriesController::class, 'index']);
                                Route::post('receipt-series/activate/{receipt_series}', [ReceiptSeriesController::class, 'activate']);

                                //payment documents
                                Route::apiResource('payment-documents', PaymentDocumentsController::class)->except(['update']);
                                Route::post(
                                    'payment-documents/available-orders/{payment_document}',
                                    [PaymentDocumentsController::class, 'getPaymentAvailableOrders']
                                );
                                Route::post('payment-documents/orders-details', [PaymentDocumentsController::class, 'getOrdersDetails']);
                                Route::post('payment-documents/add-orders/{payment_document}', [PaymentDocumentsController::class, 'addOrders']);
                                Route::delete('payment-documents/remove-orders/{payment_document}', [PaymentDocumentsController::class, 'removeOrder']);
                                Route::post('payment-documents/lock/{payment_document}', [PaymentDocumentsController::class, 'lockPaymentDocument']);
                                Route::post('payment-documents/paid/{payment_document}', [PaymentDocumentsController::class, 'markAsPaid']);
                                Route::post('payment-documents/add-payment/{payment_document}', [PaymentDocumentsController::class, 'addPayment']);
                                Route::delete('payment-documents/remove-payment/{payment_document}', [PaymentDocumentsController::class, 'removePayment']);
                                Route::get('payment-documents/payments/{payment_document}', [PaymentDocumentsController::class, 'getPayments']);
                                Route::post('payment-documents/generate-invoice/{payment_document}', [PaymentDocumentsController::class, 'generateInvoice']);
                                Route::post('payment-documents/generate-receipt/{payment_document}', [PaymentDocumentsController::class, 'generateReceipt']);

                                //dashboard orders
                                Route::get('orders-dashboard', [DashboardController::class, 'getDashboardOrders']);
                                //orders
                                Route::put('order-details/{order}', [OrderController::class, 'updateOrderDetails']);
                                Route::apiResource('orders', OrderController::class);
                                Route::get('canceled-orders', [OrderController::class, 'indexCancelled']);
                                Route::post('orders/possible-actions', [OrderController::class, 'ordersListPossibleActions']);
                                Route::post('orders/send-to-prod', [OrderController::class, 'sendOrderToProduction']);
                                Route::post('orders-finish/{order}', [OrderController::class, 'finishOrder']);
                                Route::put('cancel-order/{order}', [OrderController::class, 'cancelOrder']);
                                Route::post('order-overview-times', [OrderController::class, 'getOrderOverviewTimes']);
                                Route::post('orders-calculate-total', [\App\Http\Controllers\Reports\OrderController::class, 'calculateTotalPriceForOrdersIds']);
                                Route::post(
                                    'order-payments/{order}',
                                    [
                                        \App\Http\Controllers\OrderPaymentController::class,
                                        "create"
                                    ]
                                );
                                Route::delete(
                                    'order-payments/{order}/{paymentId}',
                                    [
                                        \App\Http\Controllers\OrderPaymentController::class,
                                        "delete"
                                    ]
                                )->where(['paymentId' => '[0-9]+']);;
                                Route::post(
                                    'order-discounts/{order}',
                                    [
                                        \App\Http\Controllers\OrderDiscountController::class,
                                        "create"
                                    ]
                                );
                                Route::delete(
                                    'order-discounts/{order}/{discountId}',
                                    [
                                        \App\Http\Controllers\OrderDiscountController::class,
                                        "delete"
                                    ]
                                )->where(['discountId' => '[0-9]+']);

                                Route::post('skip-technician/{orderWorkStage}', [DashboardController::class, 'skipOrderWorkStage']);


                                //order work templates
                                Route::post('order-work-templates-listing', [OrderWorkTemplateController::class, 'index']);
                                Route::apiResource('order-work-templates', OrderWorkTemplateController::class)->except(['index', 'show', 'update']);
                                Route::post('order-work-templates-combine', [OrderWorkTemplateController::class, 'combineWorks'])->name('order.work-template.combine');

                                Route::post('owt-settings', [OrderWorkTemplateController::class, 'updateSettings']);
                                Route::put('owt-dentition', [OrderWorkTemplateController::class, 'updateDentition']);

                                //order stages
                                Route::put('ows-reorder-stages', [OrderWorkStageController::class, 'reorderWorkStages']);
                                Route::post('ows-stages', [OrderWorkStageController::class, 'newOrderWorkStage']);
                                Route::delete('ows-stages', [OrderWorkStageController::class, 'deleteOrderWorkStage']);
                                Route::put('ows-special-stages', [OrderWorkStageController::class, 'updateSpecialStages']);
                                Route::put('ows-user/default-cost', [OrderWorkStageController::class, 'updateUserWithWorkTemplatePrice']);
                                Route::put('ows-user', [OrderWorkStageController::class, 'updateStageUser']);
                                Route::post('ows-stages/possible-actions', [OrderWorkStageController::class, 'stagesPossibleActions']);
                                Route::post('ows-stages/empty-special-stages', [OrderController::class, 'orderEmptySpecialStages']);
                                Route::delete('ows-stages/delete-empty-special-stages-ids', [OrderController::class, 'deleteOrderEmptySpecialStagesIds']);
                                Route::delete('ows-stages/delete-empty-special-stages', [OrderController::class, 'deleteOrderEmptySpecialStages']);
                                Route::post('ows-stages/update-date/{orderWorkStage}', [OrderWorkStageController::class, 'updateStageDateAndTime']);

                                //order stages user time
                                Route::put('ows-stages/start', [OrderWorkStageController::class, 'startStageTimer']);
                                Route::put('ows-stages/pause', [OrderWorkStageController::class, 'pauseStageTimer']);
                                Route::put('ows-stages/finish', [OrderWorkStageController::class, 'finishStageTimer']);

                                //remake
                                Route::post('ows-stages/remake', [OrderWorkStageController::class, 'remakeStage']);

                                //calendar
                                Route::get('calendar-exit-stages', [CalendarOrderStagesController::class, 'index']);
                                Route::get('calendar-order-stages/{order}', [CalendarOrderStagesController::class, 'showFinishedOrToSentOWS']);


                                //order additional prices
                                Route::apiResource('order-additional-prices', OrderAdditionalPriceController::class)->except(['index', 'show']);
                                Route::post('order-additional-prices/listing', [OrderAdditionalPriceController::class, 'getOrderAdditionalPrices']);
                                Route::apiResource('additional-prices-brands', AdditionalPricesBrandController::class);
                                Route::apiResource('additional-prices-categories', AdditionalPricesCategoryController::class);
                                Route::apiResource('additional-prices-products', AdditionalPricesProductController::class);
                                Route::post('order-additional-prices/product', [OrderAdditionalPriceController::class, 'addProductAsOrderAdditionalPrice']);

                                //order files
                                Route::get("order-files/{order}", [OrderFilesController::class, 'index']);
                                Route::post("order-files", [OrderFilesController::class, 'store']);
                                Route::get("order-file/{uuid}", [OrderFilesController::class, 'downloadFile'])->name('order.file.download');
                                Route::delete("order-file/{uuid}", [OrderFilesController::class, 'deleteFile'])->name('order.file.delete');

                                Route::get("order-file-remake/{order}", [OrderFilesController::class, 'remakeFile']);


                                Route::post("order-files-remake/{order}", [OrderFilesController::class, 'remake']);

                                // reports
                                Route::group(['prefix' => 'reports'], function () {
                                    Route::get(
                                        "trial-stages",
                                        [
                                            \App\Http\Controllers\Reports\TrialStagesChartController::class,
                                            'getTrialStagesChartData'
                                        ]
                                    );
                                    Route::get(
                                        "top-debtors",
                                        [
                                            \App\Http\Controllers\Reports\TopDebtorsChartController::class,
                                            'getTopDebtorsChartData'
                                        ]
                                    );
                                    Route::get(
                                        "orders-chart/{collaborator?}",
                                        [
                                            \App\Http\Controllers\Reports\OrdersChartController::class,
                                            'getOrdersChartData'
                                        ]
                                    );
                                    Route::get(
                                        "orders-chart-collaborators",
                                        [
                                            \App\Http\Controllers\Reports\OrdersChartController::class,
                                            'getOrdersChartCollaboratorsData'
                                        ]
                                    );
                                    Route::get(
                                        "works-chart/{workTemplate?}",
                                        [
                                            \App\Http\Controllers\Reports\WorksChartController::class,
                                            'getWorksChartData'
                                        ]
                                    );
                                    Route::get(
                                        "works-chart-orders",
                                        [
                                            \App\Http\Controllers\Reports\WorksChartController::class,
                                            'getWorksChartOrdersData'
                                        ]
                                    );
                                    Route::get(
                                        "completed-stages/technician/{user}",
                                        [
                                            \App\Http\Controllers\Reports\CompletedStagesChartController::class,
                                            'getUserTotalPerOrderWorkStageData'
                                        ]
                                    );
                                    Route::get(
                                        "completed-stages/technician/{user}/stages/{workStage?}/",
                                        [
                                            \App\Http\Controllers\Reports\CompletedStagesChartController::class,
                                            'getCompletedStagesChartData'
                                        ]
                                    );
                                    Route::get(
                                        "assigned-stages/technician/{user}",
                                        [
                                            \App\Http\Controllers\Reports\AssignedStagesChartController::class,
                                            'getUserTotalPerOrderAssignedWorkStage'
                                        ]
                                    );
                                    Route::post(
                                        'orders/{collaborator}',
                                        [
                                            \App\Http\Controllers\Reports\OrderController::class,
                                            "getCollaboratorOrdersNotCanceled"
                                        ]
                                    );
                                    Route::post(
                                        'send-to-invoicing/{order}',
                                        [
                                            \App\Http\Controllers\Reports\OrderController::class,
                                            "sendToInvoicing"
                                        ]
                                    );
                                });
                            }
                        );
                    }
                );
            }
        );
    }
);

Route::group(
    ['middleware' => ['api', 'throttle']],
    function () {
        Route::prefix('api/technical')->group(
            function () {
                require_once('technical_routes.php');
            }
        );
    }
);
